@@ -6,6 +6,7 @@
 
 #include <config.h>
 
+#include <limits.h>  // for INT_MAX
 #include <stdint.h>
 #include <string.h>
 
@@ -275,7 +276,8 @@ class UnownedInfo : public InfoOperations<UnownedInfo<TAG>, TAG> {
     using CStruct = typename detail::InfoTraits<TAG>::CStruct;
     CStruct* m_info;
     UnownedInfo() = delete;
-    explicit UnownedInfo(std::nullptr_t) = delete;
+    UnownedInfo(std::nullptr_t) = delete;  // NOLINT(runtime/explicit)
+    // https://github.com/cpplint/cpplint/issues/386
     // No need to delete move constructor; declaring a copy constructor prevents
     // it from being generated.
 
@@ -348,7 +350,8 @@ class OwnedInfo : public InfoOperations<OwnedInfo<TAG>, TAG> {
     CStruct* m_info;
 
     OwnedInfo() = delete;
-    explicit OwnedInfo(std::nullptr_t) = delete;
+    OwnedInfo(std::nullptr_t) = delete;  // NOLINT(runtime/explicit)
+    // https://github.com/cpplint/cpplint/issues/386
     explicit OwnedInfo(CStruct* info) : m_info(info) {
         static_assert(sizeof(CStruct*) == sizeof(OwnedInfo<TAG>),
                       "OwnedInfo<T> should be byte-compatible with T*");
@@ -883,7 +886,7 @@ class InfoOperations<Wrapper, InfoTag::CALLABLE>
         return gi_callable_info_can_throw_gerror(ptr());
     }
     [[nodiscard]]
-    void** closure_native_address(ffi_closure* closure) const {
+    void* closure_native_address(ffi_closure* closure) const {
         return gi_callable_info_get_closure_native_address(ptr(), closure);
     }
     [[nodiscard]]
@@ -1079,8 +1082,8 @@ class InfoOperations<Wrapper, InfoTag::FUNCTION>
     Gjs::GErrorResult<> invoke(const mozilla::Span<const GIArgument>& in_args,
                                const mozilla::Span<GIArgument>& out_args,
                                GIArgument* return_value) const {
-        g_assert(in_args.size() <= G_MAXINT);
-        g_assert(out_args.size() <= G_MAXINT);
+        g_assert(in_args.size() <= INT_MAX);
+        g_assert(out_args.size() <= INT_MAX);
         GError* error = nullptr;
         return this->bool_gerror(
             gi_function_info_invoke(ptr(), in_args.data(), in_args.size(),
@@ -1325,6 +1328,14 @@ class InfoOperations<Wrapper, InfoTag::UNION>
     }
 
  public:
+    using FieldsIterator =
+        InfoIterator<GIUnionInfo*, InfoTag::FIELD, gi_union_info_get_n_fields,
+                     gi_union_info_get_field>;
+    [[nodiscard]]
+    FieldsIterator fields() const {
+        return FieldsIterator{ptr()};
+    }
+
     using MethodsIterator =
         InfoIterator<GIUnionInfo*, InfoTag::FUNCTION,
                      gi_union_info_get_n_methods, gi_union_info_get_method>;
@@ -1802,7 +1813,7 @@ static_assert(sizeof(StackTypeInfo) == sizeof(GITypeInfo),
 
 }  // namespace GI
 
-/* For use of GI::OwnedInfo<TAG> in GC hash maps */
+// For use of GI::OwnedInfo<TAG> in GC hash maps
 namespace JS {
 template <GI::InfoTag TAG>
 struct GCPolicy<GI::OwnedInfo<TAG>>
