@@ -2,8 +2,7 @@
 // SPDX-License-Identifier: MIT OR LGPL-2.0-or-later
 // SPDX-FileCopyrightText: 2008 litl, LLC
 
-#ifndef GI_OBJECT_H_
-#define GI_OBJECT_H_
+#pragma once
 
 #include <config.h>
 
@@ -22,7 +21,6 @@
 #include <js/GCHashTable.h>  // for GCHashMap
 #include <js/HashTable.h>    // for DefaultHasher
 #include <js/Id.h>
-#include <js/PropertySpec.h>
 #include <js/RootingAPI.h>
 #include <js/TypeDecls.h>
 #include <mozilla/HashFunctions.h>  // for HashGeneric, HashNumber
@@ -39,6 +37,8 @@
 #include "util/log.h"
 
 class GjsAtoms;
+struct JSFunctionSpec;
+struct JSPropertySpec;
 class JSTracer;
 namespace JS {
 class CallArgs;
@@ -53,7 +53,7 @@ class ObjectPrototype;
 class ObjectPropertyInfoCaller;
 class ObjectPropertyPspecCaller;
 
-/*
+/**
  * ObjectBase:
  *
  * Specialization of GIWrapperBase for GObject instances. See the documentation
@@ -74,8 +74,8 @@ class ObjectBase
         : GIWrapperBase(proto) {}
 
  public:
-    using SignalMatchFunc = guint(gpointer, GSignalMatchType, guint, GQuark,
-                                  GClosure*, gpointer, gpointer);
+    using SignalMatchFunc = unsigned(void*, GSignalMatchType, unsigned, GQuark,
+                                     GClosure*, void*, void*);
     static constexpr GjsDebugTopic DEBUG_TOPIC = GJS_DEBUG_GOBJECT;
     static constexpr const char* DEBUG_TAG = "GObject";
 
@@ -84,12 +84,12 @@ class ObjectBase
     static JSFunctionSpec proto_methods[];
     static JSPropertySpec proto_properties[];
 
-    static GObject* to_c_ptr(JSContext* cx, JS::HandleObject obj) = delete;
+    static GObject* to_c_ptr(JSContext*, JS::HandleObject) = delete;
     GJS_JSAPI_RETURN_CONVENTION
-    static bool to_c_ptr(JSContext* cx, JS::HandleObject obj, GObject** ptr);
+    static bool to_c_ptr(JSContext*, JS::HandleObject, GObject** ptr);
     GJS_JSAPI_RETURN_CONVENTION
-    static bool transfer_to_gi_argument(JSContext* cx, JS::HandleObject obj,
-                                        GIArgument* arg,
+    static bool transfer_to_gi_argument(JSContext*, JS::HandleObject,
+                                        GIArgument*,
                                         GIDirection transfer_direction,
                                         GITransfer transfer_ownership,
                                         GType expected_gtype);
@@ -98,23 +98,22 @@ class ObjectBase
     // This is used in debug methods only.
     [[nodiscard]] const void* jsobj_addr() const;
 
-    /* Helper methods */
+    // Helper methods
 
  protected:
     void debug_lifecycle(const char* message) const {
         GIWrapperBase::debug_lifecycle(jsobj_addr(), message);
     }
 
-    [[nodiscard]] bool id_is_never_lazy(jsid name, const GjsAtoms& atoms);
+    [[nodiscard]] bool id_is_never_lazy(jsid name, const GjsAtoms&);
     [[nodiscard]] bool is_custom_js_class();
 
  public:
     // Overrides GIWrapperBase::typecheck(). We only override the overload that
     // throws, so that we can throw our own more informative error.
     template <typename T>
-    GJS_JSAPI_RETURN_CONVENTION static bool typecheck(JSContext* cx,
-                                                      JS::HandleObject obj,
-                                                      T expected) {
+    GJS_JSAPI_RETURN_CONVENTION
+    static bool typecheck(JSContext* cx, JS::HandleObject obj, T expected) {
         if (GIWrapperBase::typecheck(cx, obj, expected))
             return true;
 
@@ -131,64 +130,62 @@ class ObjectBase
         return GIWrapperBase::typecheck(cx, obj, expected, no_throw);
     }
 
-    /* JSClass operations */
+    // JSClass operations
 
-    static bool add_property(JSContext* cx, JS::HandleObject obj,
-                             JS::HandleId id, JS::HandleValue value);
+    static bool add_property(JSContext*, JS::HandleObject, JS::HandleId,
+                             JS::HandleValue);
 
-    /* JS property getters/setters */
+    // JS property getters/setters
 
  public:
     template <typename TAG = void>
-    GJS_JSAPI_RETURN_CONVENTION static bool prop_getter(JSContext*, unsigned,
-                                                        JS::Value*);
     GJS_JSAPI_RETURN_CONVENTION
-    static bool prop_getter_write_only(JSContext*, unsigned argc,
-                                       JS::Value* vp);
+    static bool prop_getter(JSContext*, unsigned, JS::Value*);
     GJS_JSAPI_RETURN_CONVENTION
-    static bool prop_getter_func(JSContext* cx, unsigned argc, JS::Value* vp);
+    static bool prop_getter_write_only(JSContext*, unsigned, JS::Value*);
+    GJS_JSAPI_RETURN_CONVENTION
+    static bool prop_getter_func(JSContext*, unsigned, JS::Value*);
     template <typename TAG, GITransfer TRANSFER = GI_TRANSFER_NOTHING>
-    GJS_JSAPI_RETURN_CONVENTION static bool prop_getter_simple_type_func(
-        JSContext*, unsigned argc, JS::Value* vp);
     GJS_JSAPI_RETURN_CONVENTION
-    static bool field_getter(JSContext* cx, unsigned argc, JS::Value* vp);
+    static bool prop_getter_simple_type_func(JSContext*, unsigned, JS::Value*);
+    GJS_JSAPI_RETURN_CONVENTION
+    static bool field_getter(JSContext*, unsigned, JS::Value*);
     template <typename TAG = void>
-    GJS_JSAPI_RETURN_CONVENTION static bool prop_setter(JSContext*, unsigned,
-                                                        JS::Value*);
     GJS_JSAPI_RETURN_CONVENTION
-    static bool prop_setter_read_only(JSContext*, unsigned argc, JS::Value* vp);
+    static bool prop_setter(JSContext*, unsigned, JS::Value*);
     GJS_JSAPI_RETURN_CONVENTION
-    static bool prop_setter_func(JSContext* cx, unsigned argc, JS::Value* vp);
+    static bool prop_setter_read_only(JSContext*, unsigned, JS::Value*);
+    GJS_JSAPI_RETURN_CONVENTION
+    static bool prop_setter_func(JSContext*, unsigned, JS::Value*);
     template <typename TAG, GITransfer TRANSFER = GI_TRANSFER_NOTHING>
-    GJS_JSAPI_RETURN_CONVENTION static bool prop_setter_simple_type_func(
-        JSContext*, unsigned argc, JS::Value* vp);
     GJS_JSAPI_RETURN_CONVENTION
-    static bool field_setter(JSContext* cx, unsigned argc, JS::Value* vp);
+    static bool prop_setter_simple_type_func(JSContext*, unsigned, JS::Value*);
+    GJS_JSAPI_RETURN_CONVENTION
+    static bool field_setter(JSContext*, unsigned, JS::Value*);
 
-    /* JS methods */
+    // JS methods
 
     GJS_JSAPI_RETURN_CONVENTION
-    static bool connect(JSContext* cx, unsigned argc, JS::Value* vp);
+    static bool connect(JSContext*, unsigned, JS::Value*);
     GJS_JSAPI_RETURN_CONVENTION
-    static bool connect_after(JSContext* cx, unsigned argc, JS::Value* vp);
+    static bool connect_after(JSContext*, unsigned, JS::Value*);
     GJS_JSAPI_RETURN_CONVENTION
-    static bool connect_object(JSContext* cx, unsigned argc, JS::Value* vp);
+    static bool connect_object(JSContext*, unsigned, JS::Value*);
     GJS_JSAPI_RETURN_CONVENTION
-    static bool emit(JSContext* cx, unsigned argc, JS::Value* vp);
+    static bool emit(JSContext*, unsigned, JS::Value*);
     GJS_JSAPI_RETURN_CONVENTION
-    static bool signal_find(JSContext* cx, unsigned argc, JS::Value* vp);
+    static bool signal_find(JSContext*, unsigned, JS::Value*);
     template <SignalMatchFunc(*MATCH_FUNC)>
-    GJS_JSAPI_RETURN_CONVENTION static bool signals_action(JSContext* cx,
-                                                           unsigned argc,
-                                                           JS::Value* vp);
     GJS_JSAPI_RETURN_CONVENTION
-    static bool to_string(JSContext* cx, unsigned argc, JS::Value* vp);
+    static bool signals_action(JSContext*, unsigned, JS::Value*);
     GJS_JSAPI_RETURN_CONVENTION
-    static bool init_gobject(JSContext* cx, unsigned argc, JS::Value* vp);
+    static bool to_string(JSContext*, unsigned, JS::Value*);
     GJS_JSAPI_RETURN_CONVENTION
-    static bool hook_up_vfunc(JSContext* cx, unsigned argc, JS::Value* vp);
+    static bool init_gobject(JSContext*, unsigned, JS::Value*);
+    GJS_JSAPI_RETURN_CONVENTION
+    static bool hook_up_vfunc(JSContext*, unsigned, JS::Value*);
 
-    /* Quarks */
+    // Quarks
 
  protected:
     [[nodiscard]] static GQuark instance_strings_quark();
@@ -231,41 +228,38 @@ class ObjectPrototype
     // by gjs_add_interface
     std::vector<GType> m_interface_gtypes;
 
-    ObjectPrototype(mozilla::Maybe<GI::ObjectInfo> info, GType gtype);
+    ObjectPrototype(mozilla::Maybe<GI::ObjectInfo>, GType);
     ~ObjectPrototype();
 
  public:
-    [[nodiscard]] static ObjectPrototype* for_gtype(GType gtype);
+    [[nodiscard]] static ObjectPrototype* for_gtype(GType);
 
-    /* Helper methods */
+    // Helper methods
  private:
     GJS_JSAPI_RETURN_CONVENTION
-    bool get_parent_proto(JSContext* cx, JS::MutableHandleObject proto) const;
+    bool get_parent_proto(JSContext*, JS::MutableHandleObject proto) const;
     GJS_JSAPI_RETURN_CONVENTION
-    bool get_parent_constructor(JSContext* cx,
+    bool get_parent_constructor(JSContext*,
                                 JS::MutableHandleObject constructor) const;
-    [[nodiscard]]
-    bool is_vfunc_unchanged(const GI::VFuncInfo) const;
-    static void vfunc_invalidated_notify(void* data, GClosure* closure);
+    [[nodiscard]] bool is_vfunc_unchanged(const GI::VFuncInfo) const;
+    static void vfunc_invalidated_notify(void* data, GClosure*);
 
     GJS_JSAPI_RETURN_CONVENTION
     bool lazy_define_gobject_property(
-        JSContext* cx, JS::HandleObject obj, JS::HandleId id, GParamSpec*,
-        bool* resolved, const char* name,
-        mozilla::Maybe<const GI::AutoPropertyInfo> = {});
+        JSContext*, JS::HandleObject, JS::HandleId, GParamSpec*, bool* resolved,
+        const char* name, mozilla::Maybe<const GI::AutoPropertyInfo> = {});
 
     enum ResolveWhat { ConsiderOnlyMethods, ConsiderMethodsAndProperties };
     GJS_JSAPI_RETURN_CONVENTION
-    bool resolve_no_info(JSContext* cx, JS::HandleObject obj, JS::HandleId id,
-                         bool* resolved, const char* name,
-                         ResolveWhat resolve_props);
+    bool resolve_no_info(JSContext*, JS::HandleObject, JS::HandleId,
+                         bool* resolved, const char* name, ResolveWhat);
     GJS_JSAPI_RETURN_CONVENTION
-    bool uncached_resolve(JSContext* cx, JS::HandleObject obj, JS::HandleId id,
+    bool uncached_resolve(JSContext*, JS::HandleObject, JS::HandleId,
                           const char* name, bool* resolved);
 
  public:
     void set_interfaces(GType* interface_gtypes, uint32_t n_interface_gtypes);
-    void set_type_qdata(void);
+    void set_type_qdata();
     GJS_JSAPI_RETURN_CONVENTION
     GParamSpec* find_param_spec_from_id(JSContext*,
                                         Gjs::AutoTypeClass<GObjectClass> const&,
@@ -278,38 +272,38 @@ class ObjectPrototype
                                AutoGValueVector* values);
 
     GJS_JSAPI_RETURN_CONVENTION
-    static bool define_class(JSContext* cx, JS::HandleObject in_object,
+    static bool define_class(JSContext*, JS::HandleObject in_object,
                              mozilla::Maybe<const GI::ObjectInfo>, GType,
                              GType* interface_gtypes,
                              uint32_t n_interface_gtypes,
                              JS::MutableHandleObject constructor,
                              JS::MutableHandleObject prototype);
 
-    void ref_vfuncs(void) {
+    void ref_vfuncs() {
         for (GClosure* closure : m_vfuncs)
             g_closure_ref(closure);
     }
-    void unref_vfuncs(void) {
+    void unref_vfuncs() {
         for (GClosure* closure : m_vfuncs)
             g_closure_unref(closure);
     }
 
-    /* JSClass operations */
+    // JSClass operations
  private:
     GJS_JSAPI_RETURN_CONVENTION
-    bool resolve_impl(JSContext* cx, JS::HandleObject obj, JS::HandleId id,
+    bool resolve_impl(JSContext*, JS::HandleObject, JS::HandleId,
                       bool* resolved);
 
     GJS_JSAPI_RETURN_CONVENTION
-    bool new_enumerate_impl(JSContext* cx, JS::HandleObject obj,
+    bool new_enumerate_impl(JSContext*, JS::HandleObject,
                             JS::MutableHandleIdVector properties,
                             bool only_enumerable);
-    void trace_impl(JSTracer* tracer);
+    void trace_impl(JSTracer*);
 
-    /* JS methods */
+    // JS methods
  public:
     GJS_JSAPI_RETURN_CONVENTION
-    bool hook_up_vfunc_impl(JSContext* cx, const JS::CallArgs& args);
+    bool hook_up_vfunc_impl(JSContext*, const JS::CallArgs&);
 };
 
 class ObjectInstance : public GIWrapperInstance<ObjectBase, ObjectPrototype,
@@ -332,27 +326,27 @@ class ObjectInstance : public GIWrapperInstance<ObjectBase, ObjectPrototype,
     bool m_gobj_finalized : 1;
 
     /* True if this object has visible JS state, and thus its lifecycle is
-     * managed using toggle references. False if this object just keeps a
-     * hard ref on the underlying GObject, and may be finalized at will. */
+     * managed using toggle references. False if this object just keeps a hard
+     * ref on the underlying GObject, and may be finalized at will. */
     bool m_uses_toggle_ref : 1;
 
     static bool s_weak_pointer_callback;
 
-    /* Constructors */
+    // Constructors
 
  private:
-    ObjectInstance(ObjectPrototype* prototype, JS::HandleObject obj);
+    ObjectInstance(ObjectPrototype*, JS::HandleObject);
     ~ObjectInstance();
 
     GJS_JSAPI_RETURN_CONVENTION
-    static ObjectInstance* new_for_gobject(JSContext* cx, GObject* gobj);
+    static ObjectInstance* new_for_gobject(JSContext*, GObject*);
 
     // Extra method to get an existing ObjectInstance from qdata
 
  public:
-    [[nodiscard]] static ObjectInstance* for_gobject(GObject* gobj);
+    [[nodiscard]] static ObjectInstance* for_gobject(GObject*);
 
-    /* Accessors */
+    // Accessors
 
  private:
     [[nodiscard]] bool has_wrapper() const { return !!m_wrapper; }
@@ -360,61 +354,62 @@ class ObjectInstance : public GIWrapperInstance<ObjectBase, ObjectPrototype,
  public:
     [[nodiscard]] JSObject* wrapper() const { return m_wrapper.get(); }
 
-    /* Methods to manipulate the JS object wrapper */
+    // Methods to manipulate the JS object wrapper
 
  private:
-    void discard_wrapper(void) { m_wrapper.reset(); }
+    void discard_wrapper() { m_wrapper.reset(); }
     void switch_to_rooted(JSContext* cx) { m_wrapper.switch_to_rooted(cx); }
     void switch_to_unrooted(JSContext* cx) { m_wrapper.switch_to_unrooted(cx); }
-    [[nodiscard]] bool update_after_gc(JSTracer* trc) {
+    [[nodiscard]]
+    bool update_after_gc(JSTracer* trc) {
         return m_wrapper.update_after_gc(trc);
     }
     [[nodiscard]] bool wrapper_is_rooted() const { return m_wrapper.rooted(); }
-    void release_native_object(void);
-    void associate_js_gobject(JSContext* cx, JS::HandleObject obj,
-                              GObject* gobj);
-    void disassociate_js_gobject(void);
-    void handle_context_dispose(void);
-    [[nodiscard]] bool weak_pointer_was_finalized(JSTracer* trc);
-    static void ensure_weak_pointer_callback(JSContext* cx);
-    static void update_heap_wrapper_weak_pointers(JSTracer* trc,
-                                                  JS::Compartment*, void* data);
+    void release_native_object();
+    void associate_js_gobject(JSContext*, JS::HandleObject, GObject*);
+    void disassociate_js_gobject();
+    void handle_context_dispose();
+    [[nodiscard]] bool weak_pointer_was_finalized(JSTracer*);
+    static void ensure_weak_pointer_callback(JSContext*);
+    static void update_heap_wrapper_weak_pointers(JSTracer*, JS::Compartment*,
+                                                  void* data);
 
  public:
-    void toggle_down(void);
-    void toggle_up(void);
+    void toggle_down();
+    void toggle_up();
 
     GJS_JSAPI_RETURN_CONVENTION
-    static JSObject* wrapper_from_gobject(JSContext* cx, GObject* ptr);
+    static JSObject* wrapper_from_gobject(JSContext*, GObject*);
 
     GJS_JSAPI_RETURN_CONVENTION
-    static bool set_value_from_gobject(JSContext* cx, GObject*,
+    static bool set_value_from_gobject(JSContext*, GObject*,
                                        JS::MutableHandleValue);
 
-    /* Methods to manipulate the list of closures */
+    // Methods to manipulate the list of closures
 
  private:
     void invalidate_closures();
-    static void closure_invalidated_notify(void* data, GClosure* closure);
+    static void closure_invalidated_notify(void* data, GClosure*);
 
  public:
-    GJS_JSAPI_RETURN_CONVENTION bool associate_closure(JSContext*, GClosure*);
+    GJS_JSAPI_RETURN_CONVENTION
+    bool associate_closure(JSContext*, GClosure*);
 
-    /* Helper methods */
+    // Helper methods
 
  private:
-    void set_object_qdata(void);
-    void unset_object_qdata(void);
+    void set_object_qdata();
+    void unset_object_qdata();
     void track_gobject_finalization();
     void ignore_gobject_finalization();
-    void check_js_object_finalized(void);
+    void check_js_object_finalized();
     void ensure_uses_toggle_ref(JSContext*);
-    [[nodiscard]] bool check_gobject_disposed_or_finalized(
-        const char* for_what) const;
+    [[nodiscard]]
+    bool check_gobject_disposed_or_finalized(const char* for_what) const;
     [[nodiscard]] bool check_gobject_finalized(const char* for_what) const;
     GJS_JSAPI_RETURN_CONVENTION
     bool signal_match_arguments_from_object(
-        JSContext* cx, JS::HandleObject props_obj, GSignalMatchType* mask_out,
+        JSContext*, JS::HandleObject props_obj, GSignalMatchType* mask_out,
         unsigned* signal_id_out, GQuark* detail_out,
         JS::MutableHandleObject callable_out);
 
@@ -424,100 +419,101 @@ class ObjectInstance : public GIWrapperInstance<ObjectBase, ObjectPrototype,
     }
 
     GJS_JSAPI_RETURN_CONVENTION
-    bool init_custom_class_from_gobject(JSContext* cx, JS::HandleObject wrapper,
-                                        GObject* gobj);
+    bool init_custom_class_from_gobject(JSContext*, JS::HandleObject wrapper,
+                                        GObject*);
 
-    static void associate_string(GObject* obj, char* str);
+    static void associate_string(GObject*, char* str);
 
-    /* Methods to manipulate the linked list of instances */
+    // Methods to manipulate the linked list of instances
 
  private:
     static std::unordered_set<ObjectInstance*> s_wrapped_gobject_list;
-    void link(void);
-    void unlink(void);
-    [[nodiscard]] static size_t num_wrapped_gobjects() {
+    void link();
+    void unlink();
+    [[nodiscard]]
+    static size_t num_wrapped_gobjects() {
         return s_wrapped_gobject_list.size();
     }
     using Action = std::function<void(ObjectInstance*)>;
     using Predicate = std::function<bool(ObjectInstance*)>;
-    static void remove_wrapped_gobjects_if(const Predicate& predicate,
-                                           const Action& action);
+    static void remove_wrapped_gobjects_if(const Predicate&, const Action&);
 
  public:
-    static void prepare_shutdown(void);
+    static void prepare_shutdown();
 
-    /* JSClass operations */
+    // JSClass operations
 
  private:
     GJS_JSAPI_RETURN_CONVENTION
-    bool add_property_impl(JSContext* cx, JS::HandleObject obj, JS::HandleId id,
-                           JS::HandleValue value);
-    void finalize_impl(JS::GCContext*, JSObject* obj);
-    void trace_impl(JSTracer* trc);
+    bool add_property_impl(JSContext*, JS::HandleObject, JS::HandleId,
+                           JS::HandleValue);
+    void finalize_impl(JS::GCContext*, JSObject*);
+    void trace_impl(JSTracer*);
 
-    /* JS property getters/setters */
+    // JS property getters/setters
 
  private:
     template <typename TAG>
-    GJS_JSAPI_RETURN_CONVENTION bool prop_getter_impl(
-        JSContext* cx, GParamSpec*, JS::MutableHandleValue rval);
     GJS_JSAPI_RETURN_CONVENTION
-    bool prop_getter_impl(JSContext* cx, ObjectPropertyInfoCaller*,
-                          JS::CallArgs const& args);
+    bool prop_getter_impl(JSContext*, GParamSpec*, JS::MutableHandleValue rval);
+    GJS_JSAPI_RETURN_CONVENTION
+    bool prop_getter_impl(JSContext*, ObjectPropertyInfoCaller*,
+                          JS::CallArgs const&);
     template <typename TAG, GITransfer TRANSFER = GI_TRANSFER_NOTHING>
-    GJS_JSAPI_RETURN_CONVENTION bool prop_getter_impl(
-        JSContext*, ObjectPropertyPspecCaller*, JS::CallArgs const&);
     GJS_JSAPI_RETURN_CONVENTION
-    bool field_getter_impl(JSContext* cx, GI::AutoFieldInfo const&,
+    bool prop_getter_impl(JSContext*, ObjectPropertyPspecCaller*,
+                          JS::CallArgs const&);
+    GJS_JSAPI_RETURN_CONVENTION
+    bool field_getter_impl(JSContext*, GI::AutoFieldInfo const&,
                            JS::MutableHandleValue rval);
     template <typename TAG>
-    GJS_JSAPI_RETURN_CONVENTION bool prop_setter_impl(JSContext*, GParamSpec*,
-                                                      JS::HandleValue);
     GJS_JSAPI_RETURN_CONVENTION
-    bool prop_setter_impl(JSContext* cx, ObjectPropertyInfoCaller*,
-                          JS::CallArgs const& args);
+    bool prop_setter_impl(JSContext*, GParamSpec*, JS::HandleValue);
+    GJS_JSAPI_RETURN_CONVENTION
+    bool prop_setter_impl(JSContext*, ObjectPropertyInfoCaller*,
+                          JS::CallArgs const&);
     template <typename TAG, GITransfer TRANSFER = GI_TRANSFER_NOTHING>
-    GJS_JSAPI_RETURN_CONVENTION bool prop_setter_impl(
-        JSContext*, ObjectPropertyPspecCaller*, JS::CallArgs const&);
     GJS_JSAPI_RETURN_CONVENTION
-    bool field_setter_not_impl(JSContext* cx, GI::AutoFieldInfo const&);
+    bool prop_setter_impl(JSContext*, ObjectPropertyPspecCaller*,
+                          JS::CallArgs const&);
+    GJS_JSAPI_RETURN_CONVENTION
+    bool field_setter_not_impl(JSContext*, GI::AutoFieldInfo const&);
 
     // JS constructor
 
     GJS_JSAPI_RETURN_CONVENTION
-    bool constructor_impl(JSContext* cx, JS::HandleObject obj,
-                          const JS::CallArgs& args);
+    bool constructor_impl(JSContext*, JS::HandleObject, const JS::CallArgs&);
 
-    /* JS methods */
+    // JS methods
 
  private:
     GJS_JSAPI_RETURN_CONVENTION
-    bool connect_impl(JSContext* cx, const JS::CallArgs& args, bool after,
+    bool connect_impl(JSContext*, const JS::CallArgs&, bool after,
                       bool object = false);
     GJS_JSAPI_RETURN_CONVENTION
-    bool emit_impl(JSContext* cx, const JS::CallArgs& args);
+    bool emit_impl(JSContext*, const JS::CallArgs&);
     GJS_JSAPI_RETURN_CONVENTION
-    bool signal_find_impl(JSContext* cx, const JS::CallArgs& args);
+    bool signal_find_impl(JSContext*, const JS::CallArgs&);
     template <SignalMatchFunc(*MATCH_FUNC)>
-    GJS_JSAPI_RETURN_CONVENTION bool signals_action_impl(
-        JSContext* cx, const JS::CallArgs& args);
     GJS_JSAPI_RETURN_CONVENTION
-    bool init_impl(JSContext* cx, const JS::CallArgs& args,
-                   JS::HandleObject obj);
+    bool signals_action_impl(JSContext*, const JS::CallArgs&);
+    GJS_JSAPI_RETURN_CONVENTION
+    bool init_impl(JSContext*, const JS::CallArgs&, JS::HandleObject);
     [[nodiscard]] const char* to_string_kind() const;
 
     // Overrides GIWrapperInstance::typecheck_impl()
     template <typename T>
-    GJS_JSAPI_RETURN_CONVENTION bool typecheck_impl(T expected) const {
+    GJS_JSAPI_RETURN_CONVENTION
+    bool typecheck_impl(T expected) const {
         g_assert(m_gobj_disposed || !m_ptr ||
-                 gtype() == G_OBJECT_TYPE(m_ptr.as<GObject*>()));
+                 g_type_is_a(gtype(), G_OBJECT_TYPE(m_ptr.as<GObject*>())));
         return GIWrapperInstance::typecheck_impl(expected);
     }
 
-    /* Notification callbacks */
-    void gobj_dispose_notify(void);
+    // Notification callbacks
+    void gobj_dispose_notify();
     static void wrapped_gobj_dispose_notify(void* data, GObject*);
-    static void wrapped_gobj_toggle_notify(void* instance, GObject* gobj,
+    static void wrapped_gobj_toggle_notify(void* instance, GObject*,
                                            gboolean is_last_ref);
 
  public:
@@ -526,11 +522,7 @@ class ObjectInstance : public GIWrapperInstance<ObjectBase, ObjectPrototype,
 };
 
 GJS_JSAPI_RETURN_CONVENTION
-bool gjs_lookup_object_constructor(JSContext             *context,
-                                   GType                  gtype,
-                                   JS::MutableHandleValue value_p);
+bool gjs_lookup_object_constructor(JSContext*, GType, JS::MutableHandleValue);
 
-void gjs_object_clear_toggles(void);
-void gjs_object_shutdown_toggle_queue(void);
-
-#endif  // GI_OBJECT_H_
+void gjs_object_clear_toggles();
+void gjs_object_shutdown_toggle_queue();
