@@ -27,10 +27,10 @@
 #include <js/ValueArray.h>
 #include <js/Warnings.h>
 #include <jsapi.h>  // for JS_NewPlainObject, JS_NewObject
+#include <mozilla/Maybe.h>
 #include <mozilla/ScopeExit.h>
 
 #include "gi/arg.h"
-#include "gi/boxed.h"
 #include "gi/enumeration.h"
 #include "gi/function.h"
 #include "gi/fundamental.h"
@@ -41,10 +41,12 @@
 #include "gi/object.h"
 #include "gi/param.h"
 #include "gi/repo.h"
+#include "gi/struct.h"
 #include "gi/union.h"
 #include "gjs/atoms.h"
 #include "gjs/auto.h"
 #include "gjs/context-private.h"
+#include "gjs/gerror-result.h"
 #include "gjs/global.h"
 #include "gjs/jsapi-util.h"
 #include "gjs/macros.h"
@@ -54,42 +56,41 @@
 using mozilla::Maybe;
 
 GJS_JSAPI_RETURN_CONVENTION
-static bool lookup_override_function(JSContext *, JS::HandleId,
+static bool lookup_override_function(JSContext*, JS::HandleId,
                                      JS::MutableHandleValue);
 
 GJS_JSAPI_RETURN_CONVENTION
-static bool get_version_for_ns(JSContext* context, JS::HandleObject repo_obj,
+static bool get_version_for_ns(JSContext* cx, JS::HandleObject repo_obj,
                                JS::HandleId ns_id, JS::UniqueChars* version) {
-    JS::RootedObject versions(context);
+    JS::RootedObject versions{cx};
     bool found;
-    const GjsAtoms& atoms = GjsContextPrivate::atoms(context);
+    const GjsAtoms& atoms = GjsContextPrivate::atoms(cx);
 
-    if (!gjs_object_require_property(context, repo_obj, "GI repository object",
+    if (!gjs_object_require_property(cx, repo_obj, "GI repository object",
                                      atoms.versions(), &versions))
         return false;
 
-    if (!JS_AlreadyHasOwnPropertyById(context, versions, ns_id, &found))
+    if (!JS_AlreadyHasOwnPropertyById(cx, versions, ns_id, &found))
         return false;
 
     if (!found)
         return true;
 
-    return gjs_object_require_property(context, versions, NULL, ns_id, version);
+    return gjs_object_require_property(cx, versions, nullptr, ns_id, version);
 }
 
 GJS_JSAPI_RETURN_CONVENTION
-static bool resolve_namespace_object(JSContext* context,
-                                     JS::HandleObject repo_obj,
+static bool resolve_namespace_object(JSContext* cx, JS::HandleObject repo_obj,
                                      JS::HandleId ns_id) {
     JS::UniqueChars version;
-    if (!get_version_for_ns(context, repo_obj, ns_id, &version))
+    if (!get_version_for_ns(cx, repo_obj, ns_id, &version))
         return false;
 
     JS::UniqueChars ns_name;
-    if (!gjs_get_string_id(context, ns_id, &ns_name))
+    if (!gjs_get_string_id(cx, ns_id, &ns_name))
         return false;
     if (!ns_name) {
-        gjs_throw(context, "Requiring invalid namespace on imports.gi");
+        gjs_throw(cx, "Requiring invalid namespace on imports.gi");
         return false;
     }
 
@@ -98,7 +99,7 @@ static bool resolve_namespace_object(JSContext* context,
     Gjs::AutoStrv versions{repo.enumerate_versions(ns_name.get(), &nversions)};
     if (nversions > 1 && !version &&
         !repo.is_registered(ns_name.get(), nullptr) &&
-        !JS::WarnUTF8(context,
+        !JS::WarnUTF8(cx,
                       "Requiring %s but it has %zu versions available; use "
                       "imports.gi.versions to pick one",
                       ns_name.get(), nversions))
@@ -118,7 +119,7 @@ static bool resolve_namespace_object(JSContext* context,
             g_strconcat(ns_name.get(), platform, nullptr)};
         auto required = repo.require(platform_specific, version.get());
         if (!required.isOk()) {
-            gjs_throw(context, "Failed to require %s %s: %s",
+            gjs_throw(cx, "Failed to require %s %s: %s",
                       platform_specific.get(), version.get(),
                       required.inspectErr()->message);
             return false;
@@ -128,39 +129,36 @@ static bool resolve_namespace_object(JSContext* context,
 
     auto required = repo.require(ns_name.get(), version.get());
     if (!required.isOk()) {
-        gjs_throw(context, "Requiring %s, version %s: %s", ns_name.get(),
+        gjs_throw(cx, "Requiring %s, version %s: %s", ns_name.get(),
                   version ? version.get() : "none",
                   required.inspectErr()->message);
         return false;
     }
 
-    /* Defines a property on "obj" (the javascript repo object)
-     * with the given namespace name, pointing to that namespace
-     * in the repo.
+    /* Defines a property on "obj" (the javascript repo object) with the given
+     * namespace name, pointing to that namespace in the repo.
      */
-    JS::RootedObject gi_namespace(context,
-                                  gjs_create_ns(context, ns_name.get()));
+    JS::RootedObject gi_namespace{cx, gjs_create_ns(cx, ns_name.get())};
 
-    JS::RootedValue override(context);
-    if (!lookup_override_function(context, ns_id, &override) ||
+    JS::RootedValue override{cx};
+    if (!lookup_override_function(cx, ns_id, &override) ||
         // Define the property early, to avoid reentrancy issues if the override
         // module looks for namespaces that import this
-        !JS_DefinePropertyById(context, repo_obj, ns_id, gi_namespace,
+        !JS_DefinePropertyById(cx, repo_obj, ns_id, gi_namespace,
                                GJS_MODULE_PROP_FLAGS))
         return false;
 
-    JS::RootedValue result(context);
+    JS::RootedValue result{cx};
     if (!override.isUndefined() &&
-        !JS_CallFunctionValue (context, gi_namespace, /* thisp */
-                               override, /* callee */
-                               JS::HandleValueArray::empty(), &result))
+        !JS_CallFunctionValue(cx, /* this_obj = */ gi_namespace, override,
+                              JS::HandleValueArray::empty(), &result))
         return false;
 
     gjs_debug(GJS_DEBUG_GNAMESPACE,
               "Defined namespace '%s' %p in GIRepository %p", ns_name.get(),
               gi_namespace.get(), repo_obj.get());
 
-    GjsContextPrivate* gjs = GjsContextPrivate::from_cx(context);
+    GjsContextPrivate* gjs = GjsContextPrivate::from_cx(cx);
     gjs->schedule_gc_if_needed();
     return true;
 }
@@ -170,19 +168,15 @@ static bool resolve_namespace_object(JSContext* context,
  * was not resolved; and true if id was resolved.
  */
 GJS_JSAPI_RETURN_CONVENTION
-static bool
-repo_resolve(JSContext       *context,
-             JS::HandleObject obj,
-             JS::HandleId     id,
-             bool            *resolved)
-{
+static bool repo_resolve(JSContext* cx, JS::HandleObject obj, JS::HandleId id,
+                         bool* resolved) {
     if (!id.isString()) {
         *resolved = false;
-        return true; /* not resolved, but no error */
+        return true;  // not resolved, but no error
     }
 
-    /* let Object.prototype resolve these */
-    const GjsAtoms& atoms = GjsContextPrivate::atoms(context);
+    // let Object.prototype resolve these
+    const GjsAtoms& atoms = GjsContextPrivate::atoms(cx);
     if (id == atoms.to_string() || id == atoms.value_of()) {
         *resolved = false;
         return true;
@@ -191,7 +185,7 @@ repo_resolve(JSContext       *context,
     gjs_debug_jsprop(GJS_DEBUG_GREPO, "Resolve prop '%s' hook, obj %s",
                      gjs_debug_id(id).c_str(), gjs_debug_object(obj).c_str());
 
-    if (!resolve_namespace_object(context, obj, id))
+    if (!resolve_namespace_object(cx, obj, id))
         return false;
 
     *resolved = true;
@@ -213,60 +207,53 @@ struct JSClass gjs_repo_class = {
 };
 
 GJS_JSAPI_RETURN_CONVENTION
-static JSObject*
-repo_new(JSContext *context)
-{
-    JS::RootedObject repo(context, JS_NewObject(context, &gjs_repo_class));
+static JSObject* repo_new(JSContext* cx) {
+    JS::RootedObject repo{cx, JS_NewObject(cx, &gjs_repo_class)};
     if (repo == nullptr)
         return nullptr;
 
     gjs_debug_lifecycle(GJS_DEBUG_GREPO, "repo constructor, obj %p",
                         repo.get());
 
-    const GjsAtoms& atoms = GjsContextPrivate::atoms(context);
-    JS::RootedObject versions(context, JS_NewPlainObject(context));
-    if (!JS_DefinePropertyById(context, repo, atoms.versions(), versions,
+    const GjsAtoms& atoms = GjsContextPrivate::atoms(cx);
+    JS::RootedObject versions{cx, JS_NewPlainObject(cx)};
+    if (!JS_DefinePropertyById(cx, repo, atoms.versions(), versions,
                                JSPROP_PERMANENT | JSPROP_RESOLVING))
         return nullptr;
 
-    /* GLib/GObject/Gio are fixed at 2.0, since we depend on them
-     * internally.
-     */
-    JS::RootedString two_point_oh(context, JS_NewStringCopyZ(context, "2.0"));
-    if (!JS_DefinePropertyById(context, versions, atoms.glib(), two_point_oh,
+    // GLib/GObject/Gio are fixed at 2.0, since we depend on them internally.
+    JS::RootedString two_point_oh{cx, JS_NewStringCopyZ(cx, "2.0")};
+    if (!JS_DefinePropertyById(cx, versions, atoms.glib(), two_point_oh,
                                JSPROP_PERMANENT) ||
-        !JS_DefinePropertyById(context, versions, atoms.gobject(), two_point_oh,
+        !JS_DefinePropertyById(cx, versions, atoms.gobject(), two_point_oh,
                                JSPROP_PERMANENT) ||
-        !JS_DefinePropertyById(context, versions, atoms.gio(), two_point_oh,
+        !JS_DefinePropertyById(cx, versions, atoms.gio(), two_point_oh,
                                JSPROP_PERMANENT))
         return nullptr;
 
 #    if defined(G_OS_UNIX)
-    if (!JS_DefineProperty(context, versions, "GLibUnix", two_point_oh,
+    if (!JS_DefineProperty(cx, versions, "GLibUnix", two_point_oh,
                            JSPROP_PERMANENT) ||
-        !JS_DefineProperty(context, versions, "GioUnix", two_point_oh,
+        !JS_DefineProperty(cx, versions, "GioUnix", two_point_oh,
                            JSPROP_PERMANENT))
         return nullptr;
 #    elif defined(G_OS_WIN32)
-    if (!JS_DefineProperty(context, versions, "GLibWin32", two_point_oh,
+    if (!JS_DefineProperty(cx, versions, "GLibWin32", two_point_oh,
                            JSPROP_PERMANENT) ||
-        !JS_DefineProperty(context, versions, "GioWin32", two_point_oh,
+        !JS_DefineProperty(cx, versions, "GioWin32", two_point_oh,
                            JSPROP_PERMANENT))
         return nullptr;
 #    endif  // G_OS_UNIX/G_OS_WIN32
 
-    JS::RootedObject private_ns(context, JS_NewPlainObject(context));
-    if (!JS_DefinePropertyById(context, repo, atoms.private_ns_marker(),
-                               private_ns, JSPROP_PERMANENT | JSPROP_RESOLVING))
+    JS::RootedObject private_ns{cx, JS_NewPlainObject(cx)};
+    if (!JS_DefinePropertyById(cx, repo, atoms.private_ns_marker(), private_ns,
+                               JSPROP_PERMANENT | JSPROP_RESOLVING))
         return nullptr;
 
     return repo;
 }
 
-bool
-gjs_define_repo(JSContext              *cx,
-                JS::MutableHandleObject repo)
-{
+bool gjs_define_repo(JSContext* cx, JS::MutableHandleObject repo) {
     repo.set(repo_new(cx));
     return true;
 }
@@ -284,14 +271,14 @@ static bool gjs_value_from_constant_info(JSContext* cx,
 }
 
 GJS_JSAPI_RETURN_CONVENTION
-static bool gjs_define_constant(JSContext* context, JS::HandleObject in_object,
+static bool gjs_define_constant(JSContext* cx, JS::HandleObject in_object,
                                 const GI::ConstantInfo info) {
-    JS::RootedValue value(context);
+    JS::RootedValue value{cx};
 
-    if (!gjs_value_from_constant_info(context, info, &value))
+    if (!gjs_value_from_constant_info(cx, info, &value))
         return false;
 
-    return JS_DefineProperty(context, in_object, info.name(), value,
+    return JS_DefineProperty(cx, in_object, info.name(), value,
                              GJS_MODULE_PROP_FLAGS);
 }
 
@@ -337,14 +324,15 @@ bool gjs_define_info(JSContext* cx, JS::HandleObject in_object,
     }
 
     if (struct_info)
-        return BoxedPrototype::define_class(cx, in_object, struct_info.value());
+        return StructPrototype::define_class(cx, in_object,
+                                             struct_info.value());
 
     if (auto union_info = info.as<GI::InfoTag::UNION>())
         return UnionPrototype::define_class(cx, in_object, union_info.value());
 
     if (auto enum_info = info.as<GI::InfoTag::ENUM>()) {
         if (!info.is_flags() && enum_info->error_domain()) {
-            /* define as GError subclass */
+            // define as GError subclass
             return ErrorPrototype::define_class(cx, in_object,
                                                 enum_info.value());
         }
@@ -367,36 +355,32 @@ bool gjs_define_info(JSContext* cx, JS::HandleObject in_object,
     return false;
 }
 
-/* Get the "unknown namespace", which should be used for unnamespaced types */
-JSObject*
-gjs_lookup_private_namespace(JSContext *context)
-{
-    const GjsAtoms& atoms = GjsContextPrivate::atoms(context);
-    return gjs_lookup_namespace_object_by_name(context,
-                                               atoms.private_ns_marker());
+// Get the "unknown namespace", which should be used for unnamespaced types
+JSObject* gjs_lookup_private_namespace(JSContext* cx) {
+    const GjsAtoms& atoms = GjsContextPrivate::atoms(cx);
+    return gjs_lookup_namespace_object_by_name(cx, atoms.private_ns_marker());
 }
 
-/* Get the namespace object that the GIBaseInfo should be inside */
-JSObject* gjs_lookup_namespace_object(JSContext* context,
-                                      const GI::BaseInfo info) {
+// Get the namespace object that the GIBaseInfo should be inside
+JSObject* gjs_lookup_namespace_object(JSContext* cx, const GI::BaseInfo info) {
     const char* ns = info.ns();
-    if (ns == NULL) {
-        gjs_throw(context, "%s '%s' does not have a namespace",
-                  info.type_string(), info.name());
+    if (ns == nullptr) {
+        gjs_throw(cx, "%s '%s' does not have a namespace", info.type_string(),
+                  info.name());
 
-        return NULL;
+        return nullptr;
     }
 
-    JS::RootedId ns_name(context, gjs_intern_string_to_id(context, ns));
+    JS::RootedId ns_name{cx, gjs_intern_string_to_id(cx, ns)};
     if (ns_name.isVoid())
         return nullptr;
-    return gjs_lookup_namespace_object_by_name(context, ns_name);
+    return gjs_lookup_namespace_object_by_name(cx, ns_name);
 }
 
-/* Check if an exception's 'name' property is equal to ImportError. Ignores
- * all errors that might arise. */
-[[nodiscard]] static bool is_import_error(JSContext* cx,
-                                          JS::HandleValue thrown_value) {
+/* Check if an exception's 'name' property is equal to ImportError. Ignores all
+ * errors that might arise. */
+[[nodiscard]]
+static bool is_import_error(JSContext* cx, JS::HandleValue thrown_value) {
     if (!thrown_value.isObject())
         return false;
 
@@ -415,11 +399,8 @@ JSObject* gjs_lookup_namespace_object(JSContext* context,
 }
 
 GJS_JSAPI_RETURN_CONVENTION
-static bool
-lookup_override_function(JSContext             *cx,
-                         JS::HandleId           ns_name,
-                         JS::MutableHandleValue function)
-{
+static bool lookup_override_function(JSContext* cx, JS::HandleId ns_name,
+                                     JS::MutableHandleValue function) {
     JS::AutoSaveExceptionState saved_exc(cx);
 
     JS::RootedObject global{cx, JS::CurrentGlobalOrNull(cx)};
@@ -440,8 +421,8 @@ lookup_override_function(JSContext             *cx,
         JS::RootedValue exc(cx);
         JS_GetPendingException(cx, &exc);
 
-        /* If the exception was an ImportError (i.e., module not found) then
-         * we simply didn't have an override, don't throw an exception */
+        /* If the exception was an ImportError (i.e., module not found) then we
+         * simply didn't have an override, don't throw an exception */
         if (is_import_error(cx, exc)) {
             saved_exc.restore();
             return true;
@@ -466,8 +447,7 @@ GJS_JSAPI_RETURN_CONVENTION
 static JSObject* lookup_namespace(JSContext* cx, JSObject* global,
                                   JS::HandleId ns_name) {
     JS::RootedObject native_registry(cx, gjs_get_native_registry(global));
-    auto priv = GjsContextPrivate::from_cx(cx);
-    const GjsAtoms& atoms = priv->atoms();
+    const GjsAtoms& atoms = GjsContextPrivate::atoms(cx);
     JS::RootedObject gi(cx);
 
     if (!gjs_global_registry_get(cx, native_registry, atoms.gi(), &gi))
@@ -481,7 +461,7 @@ static JSObject* lookup_namespace(JSContext* cx, JSObject* global,
     JS::RootedObject retval(cx);
     if (!gjs_object_require_property(cx, gi, "GI repository object", ns_name,
                                      &retval))
-        return NULL;
+        return nullptr;
 
     return retval;
 }
@@ -494,16 +474,11 @@ JSObject* gjs_lookup_namespace_object_by_name(JSContext* cx,
     return lookup_namespace(cx, global, ns_name);
 }
 
-char*
-gjs_hyphen_from_camel(const char *camel_name)
-{
-    GString *s;
-    const char *p;
+char* gjs_hyphen_from_camel(const char* camel_name) {
+    // four hyphens should be reasonable guess
+    GString* s = g_string_sized_new(strlen(camel_name) + 4 + 1);
 
-    /* four hyphens should be reasonable guess */
-    s = g_string_sized_new(strlen(camel_name) + 4 + 1);
-
-    for (p = camel_name; *p; ++p) {
+    for (const char* p = camel_name; *p; ++p) {
         if (g_ascii_isupper(*p)) {
             g_string_append_c(s, '-');
             g_string_append_c(s, g_ascii_tolower(*p));
@@ -515,46 +490,43 @@ gjs_hyphen_from_camel(const char *camel_name)
     return g_string_free(s, false);
 }
 
-JSObject* gjs_lookup_generic_constructor(JSContext* context,
+JSObject* gjs_lookup_generic_constructor(JSContext* cx,
                                          const GI::BaseInfo info) {
-    JS::RootedObject in_object{context,
-        gjs_lookup_namespace_object(context, info)};
+    JS::RootedObject in_object{cx, gjs_lookup_namespace_object(cx, info)};
     const char* constructor_name = info.name();
 
     if (G_UNLIKELY (!in_object))
-        return NULL;
+        return nullptr;
 
-    JS::RootedValue value(context);
-    if (!JS_GetProperty(context, in_object, constructor_name, &value))
-        return NULL;
+    JS::RootedValue value{cx};
+    if (!JS_GetProperty(cx, in_object, constructor_name, &value))
+        return nullptr;
 
     if (G_UNLIKELY(!value.isObject())) {
-        gjs_throw(context,
+        gjs_throw(cx,
                   "Constructor of %s.%s was the wrong type, expected an object",
                   info.ns(), constructor_name);
-        return NULL;
+        return nullptr;
     }
 
     return &value.toObject();
 }
 
-JSObject* gjs_lookup_generic_prototype(JSContext* context,
-                                       const GI::BaseInfo info) {
-    JS::RootedObject constructor(context,
-                                 gjs_lookup_generic_constructor(context, info));
+JSObject* gjs_lookup_generic_prototype(JSContext* cx, const GI::BaseInfo info) {
+    JS::RootedObject constructor{cx, gjs_lookup_generic_constructor(cx, info)};
     if (G_UNLIKELY(!constructor))
-        return NULL;
+        return nullptr;
 
-    const GjsAtoms& atoms = GjsContextPrivate::atoms(context);
-    JS::RootedValue value(context);
-    if (!JS_GetPropertyById(context, constructor, atoms.prototype(), &value))
-        return NULL;
+    const GjsAtoms& atoms = GjsContextPrivate::atoms(cx);
+    JS::RootedValue value{cx};
+    if (!JS_GetPropertyById(cx, constructor, atoms.prototype(), &value))
+        return nullptr;
 
     if (G_UNLIKELY(!value.isObject())) {
-        gjs_throw(context,
+        gjs_throw(cx,
                   "Prototype of %s.%s was the wrong type, expected an object",
                   info.ns(), info.name());
-        return NULL;
+        return nullptr;
     }
 
     return &value.toObject();
