@@ -3,13 +3,13 @@
 // SPDX-FileCopyrightText: 2008 litl, LLC
 // SPDX-FileCopyrightText: 2018 Philip Chimento <philip.chimento@gmail.com>
 
-#ifndef GI_WRAPPERUTILS_H_
-#define GI_WRAPPERUTILS_H_
+#pragma once
 
 #include <config.h>
 
 #include <stdint.h>
 
+#include <new>  // for operator new
 #include <string>
 #include <type_traits>
 
@@ -48,12 +48,13 @@ struct JSPropertySpec;
 class JSTracer;
 
 GJS_JSAPI_RETURN_CONVENTION
-bool gjs_wrapper_to_string_func(JSContext* cx, JSObject* this_obj,
+bool gjs_wrapper_to_string_func(JSContext*, JSObject* this_obj,
                                 const char* objtype,
-                                mozilla::Maybe<const GI::BaseInfo> info,
-                                GType gtype, const void* native_address,
+                                mozilla::Maybe<const GI::BaseInfo>, GType,
+                                const void* native_address,
                                 JS::MutableHandleValue ret);
 
+// Needed because some of the templates don't have Maybe as their info() type
 GJS_JSAPI_RETURN_CONVENTION
 static inline bool gjs_wrapper_to_string_func(JSContext* cx, JSObject* this_obj,
                                               const char* objtype,
@@ -65,10 +66,10 @@ static inline bool gjs_wrapper_to_string_func(JSContext* cx, JSObject* this_obj,
         cx, this_obj, objtype, mozilla::Some(info), gtype, native_address, ret);
 }
 
-bool gjs_wrapper_throw_nonexistent_field(JSContext* cx, GType gtype,
+bool gjs_wrapper_throw_nonexistent_field(JSContext*, GType,
                                          const char* field_name);
 
-bool gjs_wrapper_throw_readonly_field(JSContext* cx, GType gtype,
+bool gjs_wrapper_throw_readonly_field(JSContext*, GType,
                                       const char* field_name);
 
 namespace MemoryUse {
@@ -88,26 +89,27 @@ struct is_maybe : std::false_type {};
 template <typename T>
 struct is_maybe<mozilla::Maybe<T>> : std::true_type {};
 
-/*
+/**
  * gjs_define_static_methods:
  *
  * Defines all static methods from @info on @constructor. Also includes class
  * methods for GI::ObjectInfo, and interface methods for GI::InterfaceInfo.
  */
 template <GI::InfoTag TAG>
-GJS_JSAPI_RETURN_CONVENTION bool gjs_define_static_methods(
-    JSContext*, JS::HandleObject constructor, GType,
-    const GI::UnownedInfo<TAG>);
+GJS_JSAPI_RETURN_CONVENTION
+bool gjs_define_static_methods(JSContext*, JS::HandleObject constructor, GType,
+                               const GI::UnownedInfo<TAG>);
 
 template <GI::InfoTag TAG>
-GJS_JSAPI_RETURN_CONVENTION inline bool gjs_define_static_methods(
-    JSContext* cx, JS::HandleObject constructor, GType gtype,
-    const GI::OwnedInfo<TAG>& info) {
+GJS_JSAPI_RETURN_CONVENTION
+inline bool gjs_define_static_methods(JSContext* cx,
+                                      JS::HandleObject constructor, GType gtype,
+                                      const GI::OwnedInfo<TAG>& info) {
     return gjs_define_static_methods(cx, constructor, gtype,
                                      GI::UnownedInfo<TAG>{info});
 }
 
-/*
+/**
  * GIWrapperBase:
  *
  * In most different kinds of C pointer that we expose to JS through GObject
@@ -162,7 +164,7 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
     // use standard C++ polymorphism because that would occupy another 8 bytes
     // for a vtable.
 
-    /*
+    /**
      * GIWrapperBase::is_prototype:
      *
      * Returns whether this Base is actually a Prototype (true) or an Instance
@@ -170,7 +172,7 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
      */
     [[nodiscard]] bool is_prototype() const { return !m_proto; }
 
-    /*
+    /**
      * GIWrapperBase::to_prototype:
      * GIWrapperBase::to_instance:
      *
@@ -178,24 +180,28 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
      * don't want to assert, then either check beforehand with is_prototype(),
      * or use get_prototype().
      */
-    [[nodiscard]] Prototype* to_prototype() {
+    [[nodiscard]]
+    Prototype* to_prototype() {
         g_assert(is_prototype());
         return reinterpret_cast<Prototype*>(this);
     }
-    [[nodiscard]] const Prototype* to_prototype() const {
+    [[nodiscard]]
+    const Prototype* to_prototype() const {
         g_assert(is_prototype());
         return reinterpret_cast<const Prototype*>(this);
     }
-    [[nodiscard]] Instance* to_instance() {
+    [[nodiscard]]
+    Instance* to_instance() {
         g_assert(!is_prototype());
         return reinterpret_cast<Instance*>(this);
     }
-    [[nodiscard]] const Instance* to_instance() const {
+    [[nodiscard]]
+    const Instance* to_instance() const {
         g_assert(!is_prototype());
         return reinterpret_cast<const Instance*>(this);
     }
 
-    /*
+    /**
      * GIWrapperBase::get_prototype:
      *
      * get_prototype() doesn't assert. If you call it on a Prototype, it returns
@@ -203,10 +209,12 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
      * Instance, it returns you the Prototype belonging to the corresponding JS
      * prototype.
      */
-    [[nodiscard]] [[gnu::const]] Prototype* get_prototype() {
+    [[nodiscard]] [[gnu::const]]
+    Prototype* get_prototype() {
         return is_prototype() ? to_prototype() : m_proto;
     }
-    [[nodiscard]] const Prototype* get_prototype() const {
+    [[nodiscard]]
+    const Prototype* get_prototype() const {
         return is_prototype() ? to_prototype() : m_proto;
     }
 
@@ -220,7 +228,8 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
     // The next three methods are operations derived from the GIFooInfo.
 
     [[nodiscard]] const char* type_name() const { return g_type_name(gtype()); }
-    [[nodiscard]] const char* ns() const {
+    [[nodiscard]]
+    const char* ns() const {
         if constexpr (Prototype::may_not_have_info) {
             const auto i = info();
             return i ? i->ns() : "";
@@ -228,7 +237,8 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
             return info().ns();
         }
     }
-    [[nodiscard]] const char* name() const {
+    [[nodiscard]]
+    const char* name() const {
         if constexpr (Prototype::may_not_have_info) {
             const auto i = info();
             return i ? i->name() : type_name();
@@ -237,7 +247,8 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
         }
     }
 
-    [[nodiscard]] std::string format_name() const {
+    [[nodiscard]]
+    std::string format_name() const {
         std::string retval = ns();
         if (!retval.empty())
             retval += '.';
@@ -247,7 +258,8 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
 
  private:
     // Accessor for Instance member. Used only in debug methods and toString().
-    [[nodiscard]] const void* ptr_addr() const {
+    [[nodiscard]]
+    const void* ptr_addr() const {
         return is_prototype() ? nullptr : to_instance()->ptr();
     }
 
@@ -296,12 +308,12 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
 
     // JS class operations, used only in the JSClassOps struct
 
-    /*
+    /**
      * GIWrapperBase::new_enumerate:
      *
-     * Include this in the Base::klass vtable if the class should support
-     * lazy enumeration (listing all of the lazy properties that can be defined
-     * in resolve().) If it is included, then there must be a corresponding
+     * Include this in the Base::klass vtable if the class should support lazy
+     * enumeration (listing all of the lazy properties that can be defined in
+     * resolve().) If it is included, then there must be a corresponding
      * Prototype::new_enumerate_impl() method.
      */
     GJS_JSAPI_RETURN_CONVENTION
@@ -313,8 +325,8 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
         priv->debug_jsprop("Enumerate hook", "(all)", obj);
 
         if (!priv->is_prototype()) {
-            // Instances don't have any methods or properties.
-            // Spidermonkey will call new_enumerate on the prototype next.
+            // Instances don't have any methods or properties. Spidermonkey will
+            // call new_enumerate on the prototype next.
             return true;
         }
 
@@ -323,7 +335,7 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
     }
 
  private:
-    /*
+    /**
      * GIWrapperBase::id_is_never_lazy:
      *
      * Returns true if @id should never be treated as a lazy property. The
@@ -336,7 +348,8 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
      * Base::proto_methods. You should add any identifiers in the override that
      * you have added to the prototype object.
      */
-    [[nodiscard]] static bool id_is_never_lazy(jsid id, const GjsAtoms& atoms) {
+    [[nodiscard]]
+    static bool id_is_never_lazy(jsid id, const GjsAtoms& atoms) {
         // toString() is always defined somewhere on the prototype chain, so it
         // is never a lazy property.
         return id == atoms.to_string();
@@ -346,8 +359,8 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
     /**
      * GIWrapperBase::resolve_prototype:
      */
-    [[nodiscard]] static Prototype* resolve_prototype(JSContext* cx,
-                                                      JS::HandleObject proto) {
+    [[nodiscard]]
+    static Prototype* resolve_prototype(JSContext* cx, JS::HandleObject proto) {
         if (JS::GetClass(proto) == &Base::klass)
             return Prototype::for_js(cx, proto);
 
@@ -381,7 +394,7 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
         return Prototype::for_js(cx, obj);
     }
 
-    /*
+    /**
      * GIWrapperBase::resolve:
      *
      * Include this in the Base::klass vtable if the class should support lazy
@@ -430,7 +443,7 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
         return priv->to_prototype()->resolve_impl(cx, obj, id, resolved);
     }
 
-    /*
+    /**
      * GIWrapperBase::finalize:
      *
      * This should always be included in the Base::klass vtable. The destructors
@@ -455,7 +468,7 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
         Base::unset_private(obj);
     }
 
-    /*
+    /**
      * GIWrapperBase::trace:
      *
      * This should be included in the Base::klass vtable if any of the Base,
@@ -479,7 +492,7 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
         priv->trace_impl(trc);
     }
 
-    /*
+    /**
      * GIWrapperBase::trace_impl:
      * Override if necessary. See trace().
      */
@@ -487,7 +500,7 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
 
     // JSNative methods
 
-    /*
+    /**
      * GIWrapperBase::constructor:
      *
      * C++ implementation of the JS constructor passed to JS_InitClass(). Only
@@ -542,7 +555,7 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
         return true;
     }
 
-    /*
+    /**
      * GIWrapperBase::to_string:
      *
      * JSNative method connected to the toString() method in JS.
@@ -558,7 +571,7 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
     // Helper methods
 
  public:
-    /*
+    /**
      * GIWrapperBase::check_is_instance:
      * @for_what: string used in the exception message if an exception is thrown
      *
@@ -575,7 +588,7 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
         return false;
     }
 
-    /*
+    /**
      * GIWrapperBase::to_c_ptr:
      *
      * Returns the underlying C pointer of the wrapped object, or throws a JS
@@ -588,8 +601,8 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
      * method.)
      */
     template <typename T = void>
-    GJS_JSAPI_RETURN_CONVENTION static T* to_c_ptr(JSContext* cx,
-                                                   JS::HandleObject obj) {
+    GJS_JSAPI_RETURN_CONVENTION
+    static T* to_c_ptr(JSContext* cx, JS::HandleObject obj) {
         Base* priv;
         if (!Base::for_js_typecheck(cx, obj, &priv) ||
             !priv->check_is_instance(cx, "get a C pointer"))
@@ -598,7 +611,7 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
         return static_cast<T*>(priv->to_instance()->ptr());
     }
 
-    /*
+    /**
      * GIWrapperBase::transfer_to_gi_argument:
      * @arg: #GIArgument to fill with the value from @obj
      * @transfer_direction: Either %GI_DIRECTION_IN or %GI_DIRECTION_OUT
@@ -651,7 +664,7 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
 
     // Public typecheck API
 
-    /*
+    /**
      * GIWrapperBase::typecheck:
      * @expected_info: (nullable): GI info to check
      * @expected_type: (nullable): GType to check
@@ -717,7 +730,7 @@ class GIWrapperBase : public CWrapperPointerOps<Base> {
     GIWrapperBase& operator=(GIWrapperBase&& other) = delete;
 };
 
-/*
+/**
  * GIWrapperPrototype:
  *
  * The specialization of GIWrapperBase which becomes the private data of JS
@@ -735,10 +748,10 @@ class GIWrapperPrototype : public Base {
         Gjs::AutoPointer<Prototype, void, g_atomic_rc_box_release>;
 
  protected:
-    // m_info may be null in the case of JS-defined types, or internal types
-    // not exposed through introspection, such as GLocalFile. Not all subclasses
-    // of GIWrapperPrototype support this. Object and Interface support it in
-    // any case.
+    // m_info may be null in the case of JS-defined types, or internal types not
+    // exposed through introspection, such as GLocalFile. Not all subclasses of
+    // GIWrapperPrototype support this. Object and Interface support it in any
+    // case.
     OwnedInfo m_info;
     GType m_gtype;
 
@@ -747,7 +760,7 @@ class GIWrapperPrototype : public Base {
         Base::debug_lifecycle("Prototype constructor");
     }
 
-    /*
+    /**
      * GIWrapperPrototype::init:
      *
      * Performs any initialization that cannot be done in the constructor of
@@ -764,7 +777,7 @@ class GIWrapperPrototype : public Base {
     // create_class().
 
  private:
-    /*
+    /**
      * GIWrapperPrototype::parent_proto:
      *
      * Returns in @proto the parent class's prototype object, or nullptr if
@@ -780,14 +793,14 @@ class GIWrapperPrototype : public Base {
         return true;
     }
 
-    /*
+    /**
      * GIWrapperPrototype::constructor_nargs:
      *
      * Override this if the type's constructor takes other than 1 argument.
      */
     [[nodiscard]] unsigned constructor_nargs() const { return 1; }
 
-    /*
+    /**
      * GIWrapperPrototype::define_jsclass:
      * @in_object: JSObject on which to define the class constructor as a
      *   property
@@ -877,7 +890,7 @@ class GIWrapperPrototype : public Base {
         return true;
     }
 
-    /*
+    /**
      * GIWrapperPrototype::define_static_methods:
      *
      * Defines all introspectable static methods on @constructor, including
@@ -1019,25 +1032,26 @@ class GIWrapperPrototype : public Base {
 
     // Methods to get an existing Prototype
 
-    /*
+    /**
      * GIWrapperPrototype::for_js:
      *
      * Like Base::for_js(), but asserts that the returned private struct is a
      * Prototype and not an Instance.
      */
-    [[nodiscard]] static Prototype* for_js(JSContext* cx,
-                                           JS::HandleObject wrapper) {
+    [[nodiscard]]
+    static Prototype* for_js(JSContext* cx, JS::HandleObject wrapper) {
         return Base::for_js(cx, wrapper)->to_prototype();
     }
 
-    /*
+    /**
      * GIWrapperPrototype::for_js_prototype:
      *
      * Gets the Prototype private data from to @wrapper.prototype. Cannot return
      * null, and asserts so.
      */
-    [[nodiscard]] static Prototype* for_js_prototype(JSContext* cx,
-                                                     JS::HandleObject wrapper) {
+    [[nodiscard]]
+    static Prototype* for_js_prototype(JSContext* cx,
+                                       JS::HandleObject wrapper) {
         JS::RootedObject proto(cx);
         JS_GetPrototype(cx, wrapper, &proto);
         Base* retval = Base::for_js(cx, proto);
@@ -1059,12 +1073,12 @@ class GIWrapperPrototype : public Base {
     }
 
  public:
-    Prototype* acquire(void) {
+    Prototype* acquire() {
         g_atomic_rc_box_acquire(this);
         return static_cast<Prototype*>(this);
     }
 
-    void release(void) { g_atomic_rc_box_release_full(this, &destroy_notify); }
+    void release() { g_atomic_rc_box_release_full(this, &destroy_notify); }
 
     // JSClass operations
 
@@ -1084,7 +1098,7 @@ struct SmartPointer<GIWrappedUnowned>
 };
 }  // namespace Gjs
 
-/*
+/**
  * GIWrapperInstance:
  *
  * The specialization of GIWrapperBase which becomes the private data of JS
@@ -1107,17 +1121,17 @@ class GIWrapperInstance : public Base {
         Base::GIWrapperBase::debug_lifecycle(obj, "Instance constructor");
     }
 
-    ~GIWrapperInstance(void) { Base::m_proto->release(); }
+    ~GIWrapperInstance() { Base::m_proto->release(); }
 
  public:
-    /*
+    /**
      * GIWrapperInstance::new_for_js_object:
      *
      * Creates a GIWrapperInstance and associates it with @obj as its private
      * data. This is called by the JS constructor.
      */
-    [[nodiscard]] static Instance* new_for_js_object(JSContext* cx,
-                                                     JS::HandleObject obj) {
+    [[nodiscard]]
+    static Instance* new_for_js_object(JSContext* cx, JS::HandleObject obj) {
         Prototype* prototype = Prototype::for_js_prototype(cx, obj);
         auto* priv = new Instance(prototype, obj);
 
@@ -1129,8 +1143,9 @@ class GIWrapperInstance : public Base {
         return priv;
     }
 
-    [[nodiscard]] static Instance* new_for_js_object(Prototype* prototype,
-                                                     JS::HandleObject obj) {
+    [[nodiscard]]
+    static Instance* new_for_js_object(Prototype* prototype,
+                                       JS::HandleObject obj) {
         auto* priv = new Instance(prototype, obj);
 
         Instance::init_private(obj, priv);
@@ -1140,26 +1155,27 @@ class GIWrapperInstance : public Base {
 
     // Method to get an existing Instance
 
-    /*
+    /**
      * GIWrapperInstance::for_js:
      *
      * Like Base::for_js(), but asserts that the returned private struct is an
      * Instance and not a Prototype.
      */
-    [[nodiscard]] static Instance* for_js(JSContext* cx,
-                                          JS::HandleObject wrapper) {
+    [[nodiscard]]
+    static Instance* for_js(JSContext* cx, JS::HandleObject wrapper) {
         return Base::for_js(cx, wrapper)->to_instance();
     }
 
     // Accessors
 
     [[nodiscard]] Wrapped* ptr() const { return m_ptr; }
-    /*
+    /**
      * GIWrapperInstance::raw_ptr:
      *
      * Like ptr(), but returns a byte pointer for use in byte arithmetic.
      */
-    [[nodiscard]] uint8_t* raw_ptr() const {
+    [[nodiscard]]
+    uint8_t* raw_ptr() const {
         return reinterpret_cast<uint8_t*>(ptr());
     }
 
@@ -1175,7 +1191,7 @@ class GIWrapperInstance : public Base {
 
     // Helper methods
 
-    /*
+    /**
      * GIWrapperInstance::typecheck_impl:
      *
      * See GIWrapperBase::typecheck(). Checks that the instance's wrapped
@@ -1202,5 +1218,3 @@ class GIWrapperInstance : public Base {
         return g_type_is_a(Base::gtype(), expected_gtype);
     }
 };
-
-#endif  // GI_WRAPPERUTILS_H_
