@@ -29,9 +29,13 @@
 #include <js/Warnings.h>
 #include <js/experimental/SourceHook.h>
 #include <jsapi.h>  // for JS_SetGlobalJitCompilerOption
-#include <mozilla/Atomics.h>  // for Atomic in JSPrincipals
+#include <jsfriendapi.h>      // for SetDOMCallbacks, DOMCallbacks
 #include <mozilla/UniquePtr.h>
 
+#ifndef G_DISABLE_ASSERT
+#    include <mozilla/Atomics.h>  // for Atomic::operator==
+#endif
+
 #include "gi/gerror.h"
 #include "gjs/context-private.h"
 #include "gjs/engine.h"
@@ -40,8 +44,6 @@
 #include "gjs/profiler-private.h"
 #include "util/log.h"
 
-struct JSStructuredCloneWriter;
-
 static void gjs_finalize_callback(JS::GCContext*, JSFinalizeStatus status,
                                   void* data) {
     auto* gjs = static_cast<GjsContextPrivate*>(data);
@@ -52,11 +54,11 @@ static void gjs_finalize_callback(JS::GCContext*, JSFinalizeStatus status,
 static void on_promise_unhandled_rejection(
     JSContext* cx, bool mutedErrors [[maybe_unused]], JS::HandleObject promise,
     JS::PromiseRejectionHandlingState state, void* data) {
-    auto gjs = static_cast<GjsContextPrivate*>(data);
+    auto* gjs = static_cast<GjsContextPrivate*>(data);
     uint64_t id = JS::GetPromiseID(promise);
 
     if (state == JS::PromiseRejectionHandlingState::Handled) {
-        /* This happens when catching an exception from an await expression. */
+        // This happens when catching an exception from an await expression.
         gjs->unregister_unhandled_promise_rejection(id);
         return;
     }
@@ -115,9 +117,8 @@ BOOL WINAPI DllMain(HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved) {
             JS_ShutDown();
             break;
 
-        default:
-            /* do nothing */
-            ;
+        default: {
+        }
     }
 
     return TRUE;
@@ -125,7 +126,7 @@ BOOL WINAPI DllMain(HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved) {
 
 #else
 class GjsInit {
-public:
+ public:
     GjsInit() {
         const char* reason = JS_InitWithFailureDiagnostic();
         if (reason)
@@ -197,7 +198,7 @@ static const js::DOMCallbacks dom_callbacks = {
 
 JSContext* gjs_create_js_context(GjsContextPrivate* uninitialized_gjs) {
     g_assert(gjs_is_inited);
-    JSContext *cx = JS_NewContext(32 * 1024 * 1024 /* max bytes */);
+    JSContext* cx = JS_NewContext(/* max bytes = */ 32 * 1024 * 1024);
     if (!cx)
         return nullptr;
 
@@ -211,9 +212,9 @@ JSContext* gjs_create_js_context(GjsContextPrivate* uninitialized_gjs) {
     JS_SetNativeStackQuota(cx, 1024 * 1024);
     JS_SetGCParameter(cx, JSGC_MAX_BYTES, -1);
     JS_SetGCParameter(cx, JSGC_INCREMENTAL_GC_ENABLED, 1);
-    JS_SetGCParameter(cx, JSGC_SLICE_TIME_BUDGET_MS, 10); /* ms */
+    JS_SetGCParameter(cx, JSGC_SLICE_TIME_BUDGET_MS, 10);
 
-    /* set ourselves as the private data */
+    // set ourselves as the private data
     JS_SetContextPrivate(cx, uninitialized_gjs);
 
     JS_SetSecurityCallbacks(cx, &security_callbacks);
@@ -253,7 +254,8 @@ JSContext* gjs_create_js_context(GjsContextPrivate* uninitialized_gjs) {
     JS_SetGlobalJitCompilerOption(
         cx, JSJitCompilerOption::JSJITCOMPILER_BASELINE_ENABLE, value);
     JS_SetGlobalJitCompilerOption(
-        cx, JSJitCompilerOption::JSJITCOMPILER_BASELINE_INTERPRETER_ENABLE, value);
+        cx, JSJitCompilerOption::JSJITCOMPILER_BASELINE_INTERPRETER_ENABLE,
+        value);
 
     return cx;
 }
