@@ -3,8 +3,7 @@
 // SPDX-FileCopyrightText: 2016 Endless Mobile, Inc.
 // SPDX-FileContributor: Authored by: Philip Chimento <philip@endlessm.com>
 
-#ifndef GJS_JSAPI_UTIL_ARGS_H_
-#define GJS_JSAPI_UTIL_ARGS_H_
+#pragma once
 
 #include <config.h>
 
@@ -32,15 +31,15 @@
 
 namespace detail {
 
-[[nodiscard]] GJS_ALWAYS_INLINE static inline bool check_nullable(
-    const char*& fchar, const char*& fmt_string) {
+[[nodiscard]] GJS_ALWAYS_INLINE
+static inline bool check_nullable(const char*& fchar, const char*& fmt_string) {
     if (*fchar != '?')
         return false;
 
     fchar++;
     fmt_string++;
-    g_assert(((void) "Invalid format string, parameter required after '?'",
-              *fchar != '\0'));
+    g_assert(*fchar != '\0' &&
+             "Invalid format string, parameter required after '?'");
     return true;
 }
 
@@ -167,7 +166,7 @@ static inline ParseArgsResult assign(JSContext* cx, char c, bool nullable,
         return Err("Invalid format string combination ?u");
     if (!value.isNumber() || !JS::ToNumber(cx, value, &num))
         return Err("Couldn't convert to unsigned integer");
-    if (num > G_MAXUINT32 || num < 0)
+    if (num > INT32_MAX || num < 0)
         return Err("Value %f is out of range", num);
     *ref = num;
     return JS::Ok();
@@ -200,14 +199,14 @@ static inline ParseArgsResult assign(JSContext* cx, char c, bool nullable,
 /* Special case: treat pointer-to-enum as pointer-to-int, but use enable_if to
  * prevent instantiation for any other types besides pointer-to-enum */
 template <typename T, typename std::enable_if_t<std::is_enum_v<T>, int> = 0>
-GJS_ALWAYS_INLINE static inline ParseArgsResult assign(JSContext* cx, char c,
-                                                       bool nullable,
-                                                       JS::HandleValue value,
-                                                       T* ref) {
+GJS_ALWAYS_INLINE
+static inline ParseArgsResult assign(JSContext* cx, char c, bool nullable,
+                                     JS::HandleValue value, T* ref) {
     /* Sadly, we cannot use std::underlying_type<T> here; the underlying type of
      * an enum is implementation-defined, so it would not be clear what letter
      * to use in the format string. For the same reason, we can only support
      * enum types that are the same width as int.
+     *
      * Additionally, it would be nice to be able to check whether the resulting
      * value was in range for the enum, but that is not possible (yet?) */
     static_assert(sizeof(T) == sizeof(int),
@@ -219,8 +218,8 @@ template <typename T>
 static inline void free_if_necessary(T param_ref [[maybe_unused]]) {}
 
 template <typename T>
-GJS_ALWAYS_INLINE static inline void free_if_necessary(
-    JS::Rooted<T>* param_ref) {
+GJS_ALWAYS_INLINE
+static inline void free_if_necessary(JS::Rooted<T>* param_ref) {
     // This is not exactly right, since before we consumed a JS::Value there may
     // have been something different inside the handle. But it has already been
     // clobbered at this point anyhow.
@@ -228,12 +227,14 @@ GJS_ALWAYS_INLINE static inline void free_if_necessary(
 }
 
 template <typename T>
-GJS_JSAPI_RETURN_CONVENTION static bool parse_call_args_helper(
-    JSContext* cx, const char* function_name, const JS::CallArgs& args,
-    const char*& fmt_required, const char*& fmt_optional, unsigned param_ix,
-    const char* param_name, T param_ref) {
+GJS_JSAPI_RETURN_CONVENTION
+static bool parse_call_args_helper(JSContext* cx, const char* function_name,
+                                   const JS::CallArgs& args,
+                                   const char*& fmt_required,
+                                   const char*& fmt_optional, unsigned param_ix,
+                                   const char* param_name, T param_ref) {
     bool nullable = false;
-    const char *fchar = fmt_required;
+    const char* fchar = fmt_required;
 
     g_return_val_if_fail(param_name, false);
 
@@ -241,13 +242,13 @@ GJS_JSAPI_RETURN_CONVENTION static bool parse_call_args_helper(
         nullable = check_nullable(fchar, fmt_required);
         fmt_required++;
     } else {
-        /* No more args passed in JS, only optional formats left */
+        // No more args passed in JS, only optional formats left
         if (args.length() <= param_ix)
             return true;
 
         fchar = fmt_optional;
-        g_assert(((void) "Wrong number of parameters passed to gjs_parse_call_args()",
-                  *fchar != '\0'));
+        g_assert(*fchar != '\0' &&
+                 "Wrong number of parameters passed to gjs_parse_call_args()");
         nullable = check_nullable(fchar, fmt_optional);
         fmt_optional++;
     }
@@ -268,10 +269,13 @@ GJS_JSAPI_RETURN_CONVENTION static bool parse_call_args_helper(
 }
 
 template <typename T, typename... Args>
-GJS_JSAPI_RETURN_CONVENTION static bool parse_call_args_helper(
-    JSContext* cx, const char* function_name, const JS::CallArgs& args,
-    const char*& fmt_required, const char*& fmt_optional, unsigned param_ix,
-    const char* param_name, T param_ref, Args... params) {
+GJS_JSAPI_RETURN_CONVENTION
+static bool parse_call_args_helper(JSContext* cx, const char* function_name,
+                                   const JS::CallArgs& args,
+                                   const char*& fmt_required,
+                                   const char*& fmt_optional, unsigned param_ix,
+                                   const char* param_name, T param_ref,
+                                   Args... params) {
     if (!parse_call_args_helper(cx, function_name, args, fmt_required,
                                 fmt_optional, param_ix, param_name, param_ref))
         return false;
@@ -287,10 +291,10 @@ GJS_JSAPI_RETURN_CONVENTION static bool parse_call_args_helper(
 
 }  // namespace detail
 
-/* Empty-args version of the template */
-GJS_JSAPI_RETURN_CONVENTION [[maybe_unused]] static bool gjs_parse_call_args(
-    JSContext* cx, const char* function_name, const JS::CallArgs& args,
-    const char* format) {
+// Empty-args version of the template
+GJS_JSAPI_RETURN_CONVENTION [[maybe_unused]]
+static bool gjs_parse_call_args(JSContext* cx, const char* function_name,
+                                const JS::CallArgs& args, const char* format) {
     bool ignore_trailing_args = false;
 
     if (*format == '!') {
@@ -298,8 +302,8 @@ GJS_JSAPI_RETURN_CONVENTION [[maybe_unused]] static bool gjs_parse_call_args(
         format++;
     }
 
-    g_assert(((void) "Wrong number of parameters passed to gjs_parse_call_args()",
-              *format == '\0'));
+    g_assert(*format == '\0' &&
+             "Wrong number of parameters passed to gjs_parse_call_args()");
 
     if (!ignore_trailing_args && args.length() > 0) {
         gjs_throw(cx, "Error invoking %s: Expected 0 arguments, got %d",
@@ -312,47 +316,46 @@ GJS_JSAPI_RETURN_CONVENTION [[maybe_unused]] static bool gjs_parse_call_args(
 
 /**
  * gjs_parse_call_args:
- * @context:
+ * @cx:
  * @function_name: The name of the function being called
  * @args: #JS::CallArgs from #JSNative function
  * @format: Printf-like format specifier containing the expected arguments
  * @params: for each character in @format, a pair of const char * which is the
- * name of the argument, and a location to store the value. The type of
- * location argument depends on the format character, as described below.
+ * name of the argument, and a location to store the value. The type of location
+ * argument depends on the format character, as described below.
  *
- * This function is inspired by Python's PyArg_ParseTuple for those
- * familiar with it.  It takes a format specifier which gives the
- * types of the expected arguments, and a list of argument names and
- * value location pairs.  The currently accepted format specifiers are:
+ * This function is inspired by Python's PyArg_ParseTuple for those familiar
+ * with it.  It takes a format specifier which gives the types of the expected
+ * arguments, and a list of argument names and value location pairs.  The
+ * currently accepted format specifiers are:
  *
- * b: A boolean (pass a bool *)
- * s: A string, converted into UTF-8 (pass a JS::UniqueChars*)
- * F: A string, converted into "filename encoding" (i.e. active locale) (pass
+ * - b: A boolean (pass a bool *)
+ * - s: A string, converted into UTF-8 (pass a JS::UniqueChars*)
+ * - F: A string, converted into "filename encoding" (i.e. active locale) (pass
  *   a Gjs::AutoChar *)
- * S: A string, no conversion (pass a JS::MutableHandleString)
- * i: A number, will be converted to a 32-bit int (pass an int32_t * or a
+ * - S: A string, no conversion (pass a JS::MutableHandleString)
+ * - i: A number, will be converted to a 32-bit int (pass an int32_t * or a
  *   pointer to an enum type)
- * u: A number, converted into a 32-bit unsigned int (pass a uint32_t *)
- * t: A 64-bit number, converted into a 64-bit int (pass an int64_t *)
- * f: A number, will be converted into a double (pass a double *)
- * o: A JavaScript object (pass a JS::MutableHandleObject)
+ * - u: A number, converted into a 32-bit unsigned int (pass a uint32_t *)
+ * - t: A 64-bit number, converted into a 64-bit int (pass an int64_t *)
+ * - f: A number, will be converted into a double (pass a double *)
+ * - o: A JavaScript object (pass a JS::MutableHandleObject)
  *
- * If the first character in the format string is a '!', then JS is allowed
- * to pass extra arguments that are ignored, to the function.
+ * If the first character in the format string is a '!', then JS is allowed to
+ * pass extra arguments that are ignored, to the function.
  *
- * The '|' character introduces optional arguments.  All format specifiers
- * after a '|' when not specified, do not cause any changes in the C
- * value location.
+ * The '|' character introduces optional arguments.  All format specifiers after
+ * a '|' when not specified, do not cause any changes in the C value location.
  *
  * A prefix character '?' in front of 's', 'F', 'S', or 'o' means that the next
  * value may be null. For 's' or 'F' a null pointer is returned, for 'S' or 'o'
  * the handle is set to null.
  */
 template <typename... Args>
-GJS_JSAPI_RETURN_CONVENTION static bool gjs_parse_call_args(
-    JSContext* cx, const char* function_name, const JS::CallArgs& args,
-    const char* format, Args... params) {
-    const char *fmt_iter, *fmt_required, *fmt_optional;
+GJS_JSAPI_RETURN_CONVENTION
+static bool gjs_parse_call_args(JSContext* cx, const char* function_name,
+                                const JS::CallArgs& args, const char* format,
+                                Args... params) {
     unsigned n_required = 0, n_total = 0;
     bool optional_args = false, ignore_trailing_args = false;
 
@@ -361,24 +364,24 @@ GJS_JSAPI_RETURN_CONVENTION static bool gjs_parse_call_args(
         format++;
     }
 
-    for (fmt_iter = format; *fmt_iter; fmt_iter++) {
+    for (const char* fmt_iter = format; *fmt_iter; fmt_iter++) {
         switch (*fmt_iter) {
-        case '|':
-            n_required = n_total;
-            optional_args = true;
-            continue;
-        case '?':
-            continue;
-        default:
-            n_total++;
+            case '|':
+                n_required = n_total;
+                optional_args = true;
+                continue;
+            case '?':
+                continue;
+            default:
+                n_total++;
         }
     }
 
     if (!optional_args)
         n_required = n_total;
 
-    g_assert(((void) "Wrong number of parameters passed to gjs_parse_call_args()",
-              sizeof...(Args) / 2 == n_total));
+    g_assert(sizeof...(Args) / 2 == n_total &&
+             "Wrong number of parameters passed to gjs_parse_call_args()");
 
     if (!args.requireAtLeast(cx, function_name, n_required))
         return false;
@@ -388,7 +391,8 @@ GJS_JSAPI_RETURN_CONVENTION static bool gjs_parse_call_args(
                       function_name, n_required, args.length());
         } else {
             gjs_throw(cx,
-                      "Error invoking %s: Expected minimum %d arguments (and %d optional), got %d",
+                      "Error invoking %s: Expected minimum %d arguments (and "
+                      "%d optional), got %d",
                       function_name, n_required, n_total - n_required,
                       args.length());
         }
@@ -396,11 +400,9 @@ GJS_JSAPI_RETURN_CONVENTION static bool gjs_parse_call_args(
     }
 
     Gjs::AutoStrv parts{g_strsplit(format, "|", 2)};
-    fmt_required = parts.get()[0];
-    fmt_optional = parts.get()[1];  // may be null
+    const char* fmt_required = parts.get()[0];
+    const char* fmt_optional = parts.get()[1];  // may be null
 
     return detail::parse_call_args_helper(cx, function_name, args, fmt_required,
                                           fmt_optional, 0, params...);
 }
-
-#endif  // GJS_JSAPI_UTIL_ARGS_H_
