@@ -3,8 +3,7 @@
 // SPDX-FileCopyrightText: 2008 litl, LLC
 // SPDX-FileCopyrightText: 2021 Canonical, Ltd
 
-#ifndef GJS_MEM_PRIVATE_H_
-#define GJS_MEM_PRIVATE_H_
+#pragma once
 
 #include <config.h>
 
@@ -94,5 +93,3 @@ static constexpr const char GJS_COUNTER_DESCRIPTIONS[GJS_N_COUNTERS][52] = {
     (Gjs::Memory::Counters::dec<&Gjs::Memory::Counters::name>());
 
 #define GJS_GET_COUNTER(name) (Gjs::Memory::Counters::name.value.load())
-
-#endif  // GJS_MEM_PRIVATE_H_
