@@ -4,11 +4,11 @@
 
 #include <config.h>
 
-#include <stdint.h>
+#include <inttypes.h>
 
 #include <glib.h>
 
-#include "gjs/mem-private.h"
+#include "gjs/mem-private.h"  // IWYU pragma: associated
 #include "gjs/mem.h"
 #include "util/log.h"
 
@@ -28,22 +28,15 @@ GJS_FOR_EACH_COUNTER(GJS_DEFINE_COUNTER)
 static Gjs::Memory::Counter* counters[] = {
     GJS_FOR_EACH_COUNTER(GJS_LIST_COUNTER)};
 
-void
-gjs_memory_report(const char *where,
-                  bool        die_if_leaks)
-{
-    int i;
-    int n_counters;
-    int64_t total_objects;
-
+void gjs_memory_report(const char* where, bool die_if_leaks) {
     gjs_debug(GJS_DEBUG_MEMORY,
               "Memory report: %s",
               where);
 
-    n_counters = G_N_ELEMENTS(counters);
+    size_t n_counters = G_N_ELEMENTS(counters);
 
-    total_objects = 0;
-    for (i = 0; i < n_counters; ++i) {
+    int64_t total_objects = 0;
+    for (size_t i = 0; i < n_counters; ++i) {
         total_objects += counters[i]->value;
     }
 
@@ -52,13 +45,12 @@ gjs_memory_report(const char *where,
                   "Object counts don't add up!");
     }
 
-    gjs_debug(GJS_DEBUG_MEMORY,
-              "  %" G_GINT64_FORMAT " objects currently alive",
+    gjs_debug(GJS_DEBUG_MEMORY, "  %" PRId64 " objects currently alive",
               GJS_GET_COUNTER(everything));
 
     if (GJS_GET_COUNTER(everything) != 0) {
-        for (i = 0; i < n_counters; ++i) {
-            gjs_debug(GJS_DEBUG_MEMORY, "    %24s = %" G_GINT64_FORMAT,
+        for (size_t i = 0; i < n_counters; ++i) {
+            gjs_debug(GJS_DEBUG_MEMORY, "    %24s = %" PRId64,
                       counters[i]->name, counters[i]->value.load());
         }
 
