@@ -8,7 +8,9 @@
 #endif
 
 #ifdef ENABLE_PROFILER
-#    include <alloca.h>
+// IWYU has a weird loop where if this is present, it asks for it to be removed,
+// and if absent, asks for it to be added
+#    include <alloca.h>  // IWYU pragma: keep
 #    include <errno.h>
 #    include <stdint.h>
 #    include <stdio.h>        // for sscanf
@@ -41,37 +43,37 @@
 #include "gjs/context.h"
 #include "gjs/jsapi-util.h"  // for gjs_explain_gc_reason
 #include "gjs/mem-private.h"
-#include "gjs/profiler-private.h"
+#include "gjs/profiler-private.h"  // IWYU pragma: associated
 #include "gjs/profiler.h"
 
 #define FLUSH_DELAY_SECONDS 3
 
 /*
- * This is mostly non-exciting code wrapping the builtin Profiler in
- * mozjs. In particular, the profiler consumer is required to "bring your
- * own sampler".  We do the very non-surprising thing of using POSIX
- * timers to deliver SIGPROF to the thread containing the JSContext.
+ * This is mostly non-exciting code wrapping the builtin Profiler in mozjs. In
+ * particular, the profiler consumer is required to "bring your own sampler".
+ * We do the very non-surprising thing of using POSIX timers to deliver SIGPROF
+ * to the thread containing the JSContext.
  *
- * However, we do use a Linux'ism that allows us to deliver the signal
- * to only a single thread. Doing this in a generic fashion would
- * require thread-registration so that we can mask SIGPROF from all
- * threads except the JS thread. The gecko engine uses tgkill() to do
- * this with a secondary thread instead of using POSIX timers. We could
- * do this too, but it would still be Linux-only.
+ * However, we do use a Linux'ism that allows us to deliver the signal to only a
+ * single thread. Doing this in a generic fashion would require
+ * thread-registration so that we can mask SIGPROF from all threads except the
+ * JS thread. The gecko engine uses tgkill() to do this with a secondary thread
+ * instead of using POSIX timers. We could do this too, but it would still be
+ * Linux-only.
  *
- * Another option might be to use pthread_kill() and a secondary thread
- * to perform the notification.
+ * Another option might be to use pthread_kill() and a secondary thread to
+ * perform the notification.
  *
- * From within the signal handler, we process the current stack as
- * delivered to us from the JSContext. Any pointer data that comes from
- * the runtime has to be copied, so we keep our own dedup'd string
- * pointers for JavaScript file/line information. Non-JS instruction
- * pointers are just fine, as they can be resolved by parsing the ELF for
- * the file mapped on disk containing that address.
+ * From within the signal handler, we process the current stack as delivered to
+ * us from the JSContext. Any pointer data that comes from the runtime has to be
+ * copied, so we keep our own dedup'd string pointers for JavaScript file/line
+ * information. Non-JS instruction pointers are just fine, as they can be
+ * resolved by parsing the ELF for the file mapped on disk containing that
+ * address.
  *
- * As much of this code has to run from signal handlers, it is very
- * important that we don't use anything that can malloc() or lock, or
- * deadlocks are very likely. Most of GjsProfilerCapture is signal-safe.
+ * As much of this code has to run from signal handlers, it is very important
+ * that we don't use anything that can malloc() or lock, or deadlocks are very
+ * likely. Most of GjsProfilerCapture is signal-safe.
  */
 
 #define SAMPLES_PER_SEC G_GUINT64_CONSTANT(1000)
@@ -81,16 +83,15 @@ G_DEFINE_POINTER_TYPE(GjsProfiler, gjs_profiler)
 
 struct _GjsProfiler {
 #ifdef ENABLE_PROFILER
-    /* The stack for the JSContext profiler to use for current stack
-     * information while executing. We will look into this during our
-     * SIGPROF handler.
+    /* The stack for the JSContext profiler to use for current stack information
+     * while executing. We will look into this during our SIGPROF handler.
      */
     ProfilingStack stack;
 
-    /* The context being profiled */
-    JSContext *cx;
+    // The context being profiled
+    JSContext* cx;
 
-    /* Buffers and writes our sampled stacks */
+    // Buffers and writes our sampled stacks
     SysprofCaptureWriter* capture;
     GSource* periodic_flush;
 
@@ -99,54 +100,54 @@ struct _GjsProfiler {
     // Cache previous values of counters so that we don't overrun the output
     // with counters that don't change very often
     uint64_t last_counter_values[GJS_N_COUNTERS];
-#endif  /* ENABLE_PROFILER */
+#endif  // ENABLE_PROFILER
 
-    /* The filename to write to */
-    char *filename;
+    // The filename to write to
+    char* filename;
 
-    /* An FD to capture to */
+    // An FD to capture to
     int fd;
 
 #ifdef ENABLE_PROFILER
-    /* Our POSIX timer to wakeup SIGPROF */
+    // Our POSIX timer to wakeup SIGPROF
     timer_t timer;
 
-    /* Cached copy of our pid */
+    // Cached copy of our pid
     GPid pid;
 
-    /* Timing information */
+    // Timing information
     int64_t gc_begin_time;
     int64_t sweep_begin_time;
     int64_t group_sweep_begin_time;
     const char* gc_reason;  // statically allocated
 
-    /* GLib signal handler ID for SIGUSR2 */
+    // GLib signal handler ID for SIGUSR2
     unsigned sigusr2_id;
     unsigned counter_base;  // index of first GObject memory counter
     unsigned gc_counter_base;  // index of first GC stats counter
-#endif  /* ENABLE_PROFILER */
+#endif  // ENABLE_PROFILER
 
-    /* If we are currently sampling */
+    // If we are currently sampling
     unsigned running : 1;
 };
 
-static GjsContext *profiling_context;
+static GjsContext* profiling_context;
 
 #ifdef ENABLE_PROFILER
-/*
+/**
  * gjs_profiler_extract_maps:
  *
- * This function will write the mapped section information to the
- * capture file so that the callgraph builder can generate symbols
- * from the stack addresses provided.
+ * This function will write the mapped section information to the capture file
+ * so that the callgraph builder can generate symbols from the stack addresses
+ * provided.
  *
- * Returns: %TRUE if successful; otherwise %FALSE and the profile
- *   should abort.
+ * Returns: true if successful; otherwise false and the profile should abort.
  */
-[[nodiscard]] static bool gjs_profiler_extract_maps(GjsProfiler* self) {
+[[nodiscard]]
+static bool gjs_profiler_extract_maps(GjsProfiler* self) {
     int64_t now = g_get_monotonic_time() * 1000L;
 
-    g_assert(((void) "Profiler must be set up before extracting maps", self));
+    g_assert(self && "Profiler must be set up before extracting maps");
 
     Gjs::AutoChar path{g_strdup_printf("/proc/%jd/maps", intmax_t(self->pid))};
 
@@ -191,12 +192,13 @@ static void setup_counter_helper(SysprofCaptureCounter* counter,
     g_snprintf(counter->name, sizeof counter->name, "%s", counter_name);
     g_snprintf(counter->description, sizeof counter->description, "%s",
                GJS_COUNTER_DESCRIPTIONS[ix]);
-    counter->id = uint32_t(counter_base + ix);
+    counter->id = static_cast<uint32_t>(counter_base + ix);
     counter->type = SYSPROF_CAPTURE_COUNTER_INT64;
     counter->value.v64 = 0;
 }
 
-[[nodiscard]] static bool gjs_profiler_define_counters(GjsProfiler* self) {
+[[nodiscard]]
+static bool gjs_profiler_define_counters(GjsProfiler* self) {
     int64_t now = g_get_monotonic_time() * 1000L;
 
     g_assert(self && "Profiler must be set up before defining counters");
@@ -225,7 +227,7 @@ static void setup_counter_helper(SysprofCaptureCounter* counter,
 
     for (size_t ix = 0; ix < Gjs::GCCounters::N_COUNTERS; ix++) {
         g_snprintf(gc_counters[ix].category, category_size, "GJS");
-        gc_counters[ix].id = uint32_t(self->gc_counter_base + ix);
+        gc_counters[ix].id = static_cast<uint32_t>(self->gc_counter_base + ix);
         gc_counters[ix].type = SYSPROF_CAPTURE_COUNTER_INT64;
         gc_counters[ix].value.v64 = 0;
     }
@@ -245,58 +247,58 @@ static void setup_counter_helper(SysprofCaptureCounter* counter,
 
 #endif  /* ENABLE_PROFILER */
 
-/*
+/**
  * _gjs_profiler_new:
- * @context: The #GjsContext to profile
+ * @gjs_context: The #GjsContext to profile
  *
- * This creates a new profiler for the #JSContext. It is important that
- * this instance is freed with _gjs_profiler_free() before the context is
- * destroyed.
+ * This creates a new profiler for the #JSContext. It is important that this
+ * instance is freed with _gjs_profiler_free() before the context is destroyed.
  *
  * Call gjs_profiler_start() to enable the profiler, and gjs_profiler_stop()
  * when you have finished.
  *
- * The profiler works by enabling the JS profiler in spidermonkey so that
- * sample information is available. A POSIX timer is used to signal SIGPROF
- * to the process on a regular interval to collect the most recent profile
- * sample and stash it away. It is a programming error to mask SIGPROF from
- * the thread controlling the JS context.
+ * The profiler works by enabling the JS profiler in spidermonkey so that sample
+ * information is available. A POSIX timer is used to signal SIGPROF to the
+ * process on a regular interval to collect the most recent profile sample and
+ * stash it away. It is a programming error to mask SIGPROF from the thread
+ * controlling the JS context.
  *
  * If another #GjsContext already has a profiler, or @context already has one,
  * then returns %NULL instead.
  *
  * Returns: (transfer full) (nullable): A newly allocated #GjsProfiler
  */
-GjsProfiler *
-_gjs_profiler_new(GjsContext *context)
-{
-    g_return_val_if_fail(context, nullptr);
+GjsProfiler* _gjs_profiler_new(GjsContext* gjs_context) {
+    g_return_val_if_fail(gjs_context, nullptr);
 
-    if (profiling_context == context) {
+    if (profiling_context == gjs_context) {
         g_critical("You can only create one profiler at a time.");
         return nullptr;
     }
 
     if (profiling_context) {
-        g_message("Not going to profile GjsContext %p; you can only profile "
-                  "one context at a time.", context);
+        g_message(
+            "Not going to profile GjsContext %p; you can only profile one "
+            "context at a time.",
+            gjs_context);
         return nullptr;
     }
 
-    GjsProfiler *self = g_new0(GjsProfiler, 1);
+    GjsProfiler* self = g_new0(GjsProfiler, 1);
 
 #ifdef ENABLE_PROFILER
-    self->cx = static_cast<JSContext *>(gjs_context_get_native_context(context));
+    self->cx =
+        static_cast<JSContext*>(gjs_context_get_native_context(gjs_context));
     self->pid = getpid();
 #endif
     self->fd = -1;
 
-    profiling_context = context;
+    profiling_context = gjs_context;
 
     return self;
 }
 
-/*
+/**
  * _gjs_profiler_free:
  * @self: A #GjsProfiler
  *
@@ -305,9 +307,7 @@ _gjs_profiler_new(GjsContext *context)
  * If the profiler is running, it will be stopped. This may result in blocking
  * to write the contents of the buffer to the underlying file-descriptor.
  */
-void
-_gjs_profiler_free(GjsProfiler *self)
-{
+void _gjs_profiler_free(GjsProfiler* self) {
     if (!self)
         return;
 
@@ -330,18 +330,16 @@ _gjs_profiler_free(GjsProfiler *self)
     g_free(self);
 }
 
-/*
+/**
  * _gjs_profiler_is_running:
  * @self: A #GjsProfiler
  *
  * Checks if the profiler is currently running. This means that the JS
  * profiler is enabled and POSIX signal timers are registered.
  *
- * Returns: %TRUE if the profiler is active.
+ * Returns: true if the profiler is active.
  */
-bool
-_gjs_profiler_is_running(GjsProfiler *self)
-{
+bool _gjs_profiler_is_running(GjsProfiler* self) {
     g_return_val_if_fail(self, false);
 
     return self->running;
@@ -351,11 +349,11 @@ _gjs_profiler_is_running(GjsProfiler *self)
 
 static void gjs_profiler_sigprof(int signum [[maybe_unused]], siginfo_t* info,
                                  void*) {
-    GjsProfiler *self = gjs_context_get_profiler(profiling_context);
+    GjsProfiler* self = gjs_context_get_profiler(profiling_context);
 
-    g_assert(((void) "SIGPROF handler called with invalid signal info", info));
-    g_assert(((void) "SIGPROF handler called with other signal",
-              info->si_signo == SIGPROF));
+    g_assert(info && "SIGPROF handler called with invalid signal info");
+    g_assert(info->si_signo == SIGPROF &&
+             "SIGPROF handler called with other signal");
 
     /*
      * NOTE:
@@ -374,9 +372,9 @@ static void gjs_profiler_sigprof(int signum [[maybe_unused]], siginfo_t* info,
 
     int64_t now = g_get_monotonic_time() * 1000L;
 
-    /* NOTE: cppcheck warns that alloca() is not recommended since it can
-     * easily overflow the stack; however, dynamic allocation is not an option
-     * here since we are in a signal handler.
+    /* NOTE: cppcheck warns that alloca() is not recommended since it can easily
+     * overflow the stack; however, dynamic allocation is not an option here
+     * since we are in a signal handler.
      */
     SysprofCaptureAddress* addrs =
         // cppcheck-suppress allocaCalled
@@ -384,30 +382,28 @@ static void gjs_profiler_sigprof(int signum [[maybe_unused]], siginfo_t* info,
 
     for (uint32_t ix = 0; ix < depth; ix++) {
         js::ProfilingStackFrame& entry = self->stack.frames[ix];
-        const char *label = entry.label();
-        const char *dynamic_string = entry.dynamicString();
+        const char* label = entry.label();
+        const char* dynamic_string = entry.dynamicString();
         uint32_t flipped = depth - 1 - ix;
         size_t label_length = strlen(label);
 
-        /*
-         * 512 is an arbitrarily large size, very likely to be enough to
-         * hold the final string.
+        /* 512 is an arbitrarily large size, very likely to be enough to hold
+         * the final string.
          */
         char final_string[512];
-        char *position = final_string;
+        char* position = final_string;
         size_t available_length = sizeof (final_string) - 1;
 
         if (label_length > 0) {
             label_length = MIN(label_length, available_length);
 
-            /* Start copying the label to the final string */
+            // Start copying the label to the final string
             memcpy(position, label, label_length);
             available_length -= label_length;
             position += label_length;
 
-            /*
-             * Add a space in between the label and the dynamic string,
-             * if there is one.
+            /* Add a space in between the label and the dynamic string, if there
+             * is one.
              */
             if (dynamic_string && available_length > 0) {
                 *position++ = ' ';
@@ -422,7 +418,8 @@ static void gjs_profiler_sigprof(int signum [[maybe_unused]], siginfo_t* info,
             size_t dynamic_string_length = strlen(dynamic_string);
 
             if (dynamic_string_length > 0) {
-                size_t remaining_length = MIN(available_length, dynamic_string_length);
+                size_t remaining_length =
+                    MIN(available_length, dynamic_string_length);
                 memcpy(position, dynamic_string, remaining_length);
                 position += remaining_length;
             }
@@ -430,9 +427,8 @@ static void gjs_profiler_sigprof(int signum [[maybe_unused]], siginfo_t* info,
 
         *position = 0;
 
-        /*
-         * GeckoProfiler will put "js::RunScript" on the stack, but it has
-         * a stack address of "this", which is not terribly useful since
+        /* GeckoProfiler will put "js::RunScript" on the stack, but it has a
+         * stack address of "this", which is not terribly useful since
          * everything will show up as [stack] when building callgraphs.
          */
         if (final_string[0] != '\0')
@@ -482,7 +478,7 @@ static gboolean profiler_auto_flush_cb(void* user_data) {
     return G_SOURCE_CONTINUE;
 }
 
-#endif  /* ENABLE_PROFILER */
+#endif  // ENABLE_PROFILER
 
 /**
  * gjs_profiler_start:
@@ -499,9 +495,7 @@ static gboolean profiler_auto_flush_cb(void* user_data) {
  *
  * You should call gjs_profiler_stop() when the profiler is no longer needed.
  */
-void
-gjs_profiler_start(GjsProfiler *self)
-{
+void gjs_profiler_start(GjsProfiler* self) {
     g_return_if_fail(self);
     if (self->running)
         return;
@@ -533,7 +527,7 @@ gjs_profiler_start(GjsProfiler *self)
         return;
     }
 
-    /* Automatically flush to be resilient against SIGINT, etc */
+    // Automatically flush to be resilient against SIGINT, etc
     if (!self->periodic_flush) {
         self->periodic_flush =
             g_timeout_source_new_seconds(FLUSH_DELAY_SECONDS);
@@ -561,13 +555,14 @@ gjs_profiler_start(GjsProfiler *self)
         return;
     }
 
-    /* Setup our signal handler for SIGPROF delivery */
+    // Setup our signal handler for SIGPROF delivery
     sa.sa_flags = SA_RESTART | SA_SIGINFO;
     sa.sa_sigaction = gjs_profiler_sigprof;
     sigemptyset(&sa.sa_mask);
 
     if (sigaction(SIGPROF, &sa, nullptr) == -1) {
-        g_warning("Failed to register sigaction handler: %s", g_strerror(errno));
+        g_warning("Failed to register sigaction handler: %s",
+                  g_strerror(errno));
         g_clear_pointer(&self->capture, sysprof_capture_writer_unref);
         g_clear_pointer(&self->periodic_flush, g_source_destroy);
         return;
@@ -576,12 +571,12 @@ gjs_profiler_start(GjsProfiler *self)
     /*
      * Create our SIGPROF timer
      *
-     * We want to receive a SIGPROF signal on the JS thread using our
-     * configured sampling frequency. Instead of allowing any thread to be
-     * notified, we set the _tid value to ensure that only our thread gets
-     * delivery of the signal. This feature is generally just for
-     * threading implementations, but it works for us as well and ensures
-     * that the thread is blocked while we capture the stack.
+     * We want to receive a SIGPROF signal on the JS thread using our configured
+     * sampling frequency. Instead of allowing any thread to be notified, we set
+     * the _tid value to ensure that only our thread gets delivery of the
+     * signal. This feature is generally just for threading implementations, but
+     * it works for us as well and ensures that the thread is blocked while we
+     * capture the stack.
      */
     sev.sigev_notify = SIGEV_THREAD_ID;
     sev.sigev_signo = SIGPROF;
@@ -594,13 +589,13 @@ gjs_profiler_start(GjsProfiler *self)
         return;
     }
 
-    /* Calculate sampling interval */
+    // Calculate sampling interval
     its.it_interval.tv_sec = 0;
     its.it_interval.tv_nsec = NSEC_PER_SEC / SAMPLES_PER_SEC;
     its.it_value.tv_sec = 0;
     its.it_value.tv_nsec = NSEC_PER_SEC / SAMPLES_PER_SEC;
 
-    /* Now start this timer */
+    // Now start this timer
     if (timer_settime(self->timer, 0, &its, &old_its) != 0) {
         g_warning("Failed to enable profiler timer: %s", g_strerror(errno));
         timer_delete(self->timer);
@@ -611,40 +606,38 @@ gjs_profiler_start(GjsProfiler *self)
 
     self->running = true;
 
-    /* Notify the JS runtime of where to put stack info */
+    // Notify the JS runtime of where to put stack info
     js::SetContextProfilingStack(self->cx, &self->stack);
 
-    /* Start recording stack info */
+    // Start recording stack info
     js::EnableContextProfilingStack(self->cx, true);
 
     g_message("Profiler started");
 
-#else  /* !ENABLE_PROFILER */
+#else  // !ENABLE_PROFILER
 
     self->running = true;
     g_message("Profiler is disabled. Recompile with it enabled to use.");
 
-#endif  /* ENABLE_PROFILER */
+#endif  // ENABLE_PROFILER
 }
 
 /**
  * gjs_profiler_stop:
  * @self: A #GjsProfiler
  *
- * Stops a currently running #GjsProfiler. If the profiler is not running,
- * this function will do nothing.
+ * Stops a currently running #GjsProfiler. If the profiler is not running, this
+ * function will do nothing.
  *
  * Some work may be delayed until the end of the capture. Such delayed work
  * includes flushing the resulting samples and file location information to
  * disk.
  *
- * This may block while writing to disk. Generally, the writes are delivered
- * to a tmpfs device, and are therefore negligible.
+ * This may block while writing to disk. Generally, the writes are delivered to
+ * a tmpfs device, and are therefore negligible.
  */
-void
-gjs_profiler_stop(GjsProfiler *self)
-{
-    /* Note: can be called from a signal handler */
+void gjs_profiler_stop(GjsProfiler* self) {
+    // Note: can be called from a signal handler
 
     g_assert(self);
 
@@ -667,18 +660,16 @@ gjs_profiler_stop(GjsProfiler *self)
 
     g_message("Profiler stopped");
 
-#endif  /* ENABLE_PROFILER */
+#endif  // ENABLE_PROFILER
 
     self->running = false;
 }
 
 #ifdef ENABLE_PROFILER
 
-static gboolean
-gjs_profiler_sigusr2(void *data)
-{
-    GjsContext* context = GJS_CONTEXT(data);
-    GjsProfiler *current_profiler = gjs_context_get_profiler(context);
+static gboolean gjs_profiler_sigusr2(void* data) {
+    GjsContext* gjs_context = GJS_CONTEXT(data);
+    GjsProfiler* current_profiler = gjs_context_get_profiler(gjs_context);
 
     if (current_profiler) {
         if (_gjs_profiler_is_running(current_profiler))
@@ -690,45 +681,43 @@ gjs_profiler_sigusr2(void *data)
     return G_SOURCE_CONTINUE;
 }
 
-#endif  /* ENABLE_PROFILER */
+#endif  // ENABLE_PROFILER
 
-/*
+/**
  * _gjs_profiler_setup_signals:
- * @context: a #GjsContext with a profiler attached
+ * @gjs_context: a #GjsContext with a profiler attached
  *
- * If you want to simply allow profiling of your process with minimal
- * fuss, simply call gjs_profiler_setup_signals(). This will allow
- * enabling and disabling the profiler with SIGUSR2. You must call
- * this from main() immediately when your program starts and must not
- * block SIGUSR2 from your signal mask.
+ * If you want to simply allow profiling of your process with minimal fuss,
+ * simply call gjs_profiler_setup_signals(). This will allow enabling and
+ * disabling the profiler with SIGUSR2. You must call this from main()
+ * immediately when your program starts and must not block SIGUSR2 from your
+ * signal mask.
  *
- * If this is not sufficient, use gjs_profiler_chain_signal() from your
- * own signal handler to pass the signal to a GjsProfiler.
+ * If this is not sufficient, use gjs_profiler_chain_signal() from your own
+ * signal handler to pass the signal to a GjsProfiler.
  */
-void
-_gjs_profiler_setup_signals(GjsProfiler *self,
-                            GjsContext  *context)
-{
-    g_return_if_fail(context == profiling_context);
+void _gjs_profiler_setup_signals(GjsProfiler* self, GjsContext* gjs_context) {
+    g_return_if_fail(gjs_context == profiling_context);
 
 #ifdef ENABLE_PROFILER
 
     if (self->sigusr2_id != 0)
         return;
 
-    self->sigusr2_id = g_unix_signal_add(SIGUSR2, gjs_profiler_sigusr2, context);
+    self->sigusr2_id =
+        g_unix_signal_add(SIGUSR2, gjs_profiler_sigusr2, gjs_context);
 
-#else  /* !ENABLE_PROFILER */
+#else  // !ENABLE_PROFILER
 
     g_message("Profiler is disabled. Not setting up signals.");
     (void)self;
 
-#endif  /* ENABLE_PROFILER */
+#endif  // ENABLE_PROFILER
 }
 
 /**
  * gjs_profiler_chain_signal:
- * @context: a #GjsContext with a profiler attached
+ * @gjs_context: a #GjsContext with a profiler attached
  * @info: #siginfo_t passed in to signal handler
  *
  * Use this to pass a signal info caught by another signal handler to a
@@ -737,12 +726,9 @@ _gjs_profiler_setup_signals(GjsProfiler *self,
  *
  * This function should only be called from the JS thread.
  *
- * Returns: %TRUE if the signal was handled.
+ * Returns: true if the signal was handled.
  */
-bool
-gjs_profiler_chain_signal(GjsContext *context,
-                          siginfo_t *info)
-{
+bool gjs_profiler_chain_signal(GjsContext* gjs_context, siginfo_t* info) {
 #ifdef ENABLE_PROFILER
 
     if (info) {
@@ -752,17 +738,17 @@ gjs_profiler_chain_signal(GjsContext *context,
         }
 
         if (info->si_signo == SIGUSR2) {
-            gjs_profiler_sigusr2(context);
+            gjs_profiler_sigusr2(gjs_context);
             return true;
         }
     }
 
 #else  // !ENABLE_PROFILER
 
-    (void)context;
+    (void)gjs_context;
     (void)info;
 
-#endif  /* ENABLE_PROFILER */
+#endif  // ENABLE_PROFILER
 
     return false;
 }
@@ -772,10 +758,10 @@ gjs_profiler_chain_signal(GjsContext *context,
  * @self: A #GjsProfiler
  * @capture: (nullable): A #SysprofCaptureWriter
  *
- * Set the capture writer to which profiling data is written when the @self
- * is stopped.
+ * Set the capture writer to which profiling data is written when the @self is
+ * stopped.
  */
-void gjs_profiler_set_capture_writer(GjsProfiler* self, gpointer capture) {
+void gjs_profiler_set_capture_writer(GjsProfiler* self, void* capture) {
     g_return_if_fail(self);
     g_return_if_fail(!self->running);
 
@@ -784,7 +770,7 @@ void gjs_profiler_set_capture_writer(GjsProfiler* self, gpointer capture) {
     self->target_capture =
         capture ? sysprof_capture_writer_ref(
                       reinterpret_cast<SysprofCaptureWriter*>(capture))
-                : NULL;
+                : nullptr;
 #else
     // Unused in the no-profiler case
     (void)capture;
@@ -796,13 +782,10 @@ void gjs_profiler_set_capture_writer(GjsProfiler* self, gpointer capture) {
  * @self: A #GjsProfiler
  * @filename: string containing a filename
  *
- * Set the file to which profiling data is written when the @self is stopped.
- * By default, this is `gjs-$PID.syscap` in the current directory.
+ * Set the file to which profiling data is written when the @self is stopped. By
+ * default, this is `gjs-$PID.syscap` in the current directory.
  */
-void
-gjs_profiler_set_filename(GjsProfiler *self,
-                          const char  *filename)
-{
+void gjs_profiler_set_filename(GjsProfiler* self, const char* filename) {
     g_return_if_fail(self);
     g_return_if_fail(!self->running);
 
@@ -879,20 +862,25 @@ void _gjs_profiler_set_finalize_status(GjsProfiler* self,
     // Implementation note for mozjs-140:
     //
     // Sweeping happens in three phases:
+    //
     // 1st phase (JSFINALIZE_GROUP_PREPARE): the collector prepares to sweep a
-    // group of zones. 2nd phase (JSFINALIZE_GROUP_START): weak references to
-    // unmarked things have been removed, but no GC thing has been swept. 3rd
-    // Phase (JSFINALIZE_GROUP_END): all dead GC things for a group of zones
+    // group of zones.
+    //
+    // 2nd phase (JSFINALIZE_GROUP_START): weak references to unmarked things
+    // have been removed, but no GC thing has been swept.
+    //
+    // 3rd Phase (JSFINALIZE_GROUP_END): all dead GC things for a group of zones
     // have been swept. The above repeats for each sweep group.
+    //
     // JSFINALIZE_COLLECTION_END occurs at the end of all GC. (see
     // js/src/gc/GC.cpp, GCRuntime::beginSweepPhase, beginSweepingSweepGroup,
     // and endSweepPhase, all called from incrementalSlice).
     //
     // Incremental GC muddies the waters, because BeginSweepPhase is always run
     // to entirety, but SweepPhase can be run incrementally and mixed with JS
-    // code runs or even native code, when MaybeGC/IncrementalGC return.
-    // After GROUP_START, the collector may yield to the mutator meaning JS code
-    // can run between the callback for GROUP_START and GROUP_END.
+    // code runs or even native code, when MaybeGC/IncrementalGC return. After
+    // GROUP_START, the collector may yield to the mutator meaning JS code can
+    // run between the callback for GROUP_START and GROUP_END.
 
     int64_t now = g_get_monotonic_time() * 1000L;
 
