@@ -9,11 +9,11 @@
 
 #ifdef G_OS_UNIX
 #    include <errno.h>
-#    include <fcntl.h> /* for FD_CLOEXEC */
+#    include <fcntl.h>  // for FD_CLOEXEC
 #    include <stdarg.h>
-#    include <unistd.h> /* for close, write */
+#    include <unistd.h>  // for close, write
 
-#    include <glib-unix.h> /* for g_unix_open_pipe */
+#    include <glib-unix.h>  // for g_unix_open_pipe
 #endif
 
 #include "gjs/auto.h"
@@ -57,7 +57,7 @@ static void monitor_object_finalization(GObject* object) {
 void gjs_test_tools_delayed_ref(GObject* object, int interval) {
     g_timeout_add(
         interval,
-        [](void *data) {
+        [](void* data) {
             g_object_ref(G_OBJECT(data));
             return G_SOURCE_REMOVE;
         },
@@ -67,7 +67,7 @@ void gjs_test_tools_delayed_ref(GObject* object, int interval) {
 void gjs_test_tools_delayed_unref(GObject* object, int interval) {
     g_timeout_add(
         interval,
-        [](void *data) {
+        [](void* data) {
             g_object_unref(G_OBJECT(data));
             return G_SOURCE_REMOVE;
         },
@@ -77,7 +77,7 @@ void gjs_test_tools_delayed_unref(GObject* object, int interval) {
 void gjs_test_tools_delayed_dispose(GObject* object, int interval) {
     g_timeout_add(
         interval,
-        [](void *data) {
+        [](void* data) {
             g_object_run_dispose(G_OBJECT(data));
             return G_SOURCE_REMOVE;
         },
@@ -96,7 +96,7 @@ void gjs_test_tools_save_object_unreffed(GObject* object) {
 
 void gjs_test_tools_clear_saved() {
     if (!FinalizedObjectsLocked()->count(s_tmp_object)) {
-        auto* object = s_tmp_object.exchange(nullptr);
+        GObject* object = s_tmp_object.exchange(nullptr);
         g_clear_object(&object);
     } else {
         s_tmp_object = nullptr;
@@ -104,20 +104,21 @@ void gjs_test_tools_clear_saved() {
 }
 
 void gjs_test_tools_ref_other_thread(GObject* object, GError** error) {
-    auto* thread = g_thread_try_new("ref_object", g_object_ref, object, error);
+    GThread* thread =
+        g_thread_try_new("ref_object", g_object_ref, object, error);
     if (thread)
         g_thread_join(thread);
     // cppcheck-suppress memleak
 }
 
-static gpointer emit_test_signal_other_thread_func(gpointer data) {
+static void* emit_test_signal_other_thread_func(void* data) {
     g_signal_emit_by_name(data, "test");
     return nullptr;
 }
 
 void gjs_test_tools_emit_test_signal_other_thread(GObject* object,
                                                   GError** error) {
-    auto* thread =
+    GThread* thread =
         g_thread_try_new("emit_signal_object",
                          emit_test_signal_other_thread_func, object, error);
     if (thread)
@@ -181,7 +182,7 @@ static void* ref_thread_func(void* data) {
 }
 
 void gjs_test_tools_unref_other_thread(GObject* object, GError** error) {
-    auto* thread =
+    GThread* thread =
         g_thread_try_new("unref_object", ref_thread_func,
                          ref_thread_data_new(object, -1, UNREF), error);
     if (thread)
@@ -226,7 +227,7 @@ GThread* gjs_test_tools_delayed_ref_unref_other_thread(GObject* object,
 }
 
 void gjs_test_tools_run_dispose_other_thread(GObject* object, GError** error) {
-    auto* thread = g_thread_try_new(
+    GThread* thread = g_thread_try_new(
         "run_dispose",
         [](void* object) -> void* {
             g_object_run_dispose(G_OBJECT(object));
@@ -288,9 +289,9 @@ GObject* gjs_test_tools_get_weak() {
  * Returns: (transfer full)
  */
 GObject* gjs_test_tools_get_weak_other_thread(GError** error) {
-    auto* thread = g_thread_try_new(
+    GThread* thread = g_thread_try_new(
         "weak_get", [](void*) -> void* { return gjs_test_tools_get_weak(); },
-        NULL, error);
+        nullptr, error);
     if (!thread)
         return nullptr;
 
@@ -311,7 +312,7 @@ GObject* gjs_test_tools_get_disposed(GObject* object) {
 #ifdef G_OS_UNIX
 
 // Adapted from glnx_throw_errno_prefix()
-static gboolean throw_errno_prefix(GError** error, const char* prefix) {
+static void throw_errno_prefix(GError** error, const char* prefix) {
     int errsv = errno;
 
     g_set_error_literal(error, G_IO_ERROR, g_io_error_from_errno(errsv),
@@ -319,15 +320,14 @@ static gboolean throw_errno_prefix(GError** error, const char* prefix) {
     g_prefix_error(error, "%s: ", prefix);
 
     errno = errsv;
-    return FALSE;
 }
 
-#endif /* G_OS_UNIX */
+#endif  // G_OS_UNIX
 
 /**
  * gjs_open_bytes:
  * @bytes: bytes to send to the pipe
- * @error: Return location for a #GError, or %NULL
+ * @error: Return location for a #GError, or nullptr
  *
  * Creates a pipe and sends @bytes to it, such that it is suitable for passing
  * to g_subprocess_launcher_take_fd().
@@ -335,31 +335,28 @@ static gboolean throw_errno_prefix(GError** error, const char* prefix) {
  * Returns: file descriptor, or -1 on error
  */
 int gjs_test_tools_open_bytes(GBytes* bytes, GError** error) {
-    int pipefd[2], result;
-    size_t count;
-    const void* buf;
-    ssize_t bytes_written;
-
     g_return_val_if_fail(bytes, -1);
-    g_return_val_if_fail(error == NULL || *error == NULL, -1);
+    g_return_val_if_fail(error == nullptr || *error == nullptr, -1);
 
 #ifdef G_OS_UNIX
+    int pipefd[2];
     if (!g_unix_open_pipe(pipefd, FD_CLOEXEC, error))
         return -1;
 
-    buf = g_bytes_get_data(bytes, &count);
+    size_t count;
+    const void* buf = g_bytes_get_data(bytes, &count);
 
-    bytes_written = write(pipefd[1], buf, count);
+    ssize_t bytes_written = write(pipefd[1], buf, count);
     if (bytes_written < 0) {
         throw_errno_prefix(error, "write");
         return -1;
     }
 
-    if ((size_t)bytes_written != count)
+    if (static_cast<size_t>(bytes_written) != count)
         g_warning("%s: %zu bytes sent, only %zd bytes written", __func__, count,
                   bytes_written);
 
-    result = close(pipefd[1]);
+    int result = close(pipefd[1]);
     if (result == -1) {
         throw_errno_prefix(error, "close");
         return -1;
