@@ -1,7 +1,10 @@
 // SPDX-License-Identifier: MIT OR LGPL-2.0-or-later
 // SPDX-FileCopyrightText: 2008 litl, LLC
 
-const {Gio, GjsTestTools, GLib, GioUnix} = imports.gi;
+import Gio from 'gi://Gio';
+import GjsTestTools from 'gi://GjsTestTools';
+import GLib from 'gi://GLib';
+import GioUnix from 'gi://GioUnix';
 
 /* The methods list with their signatures.
  *
@@ -21,6 +24,24 @@ var TestIface = `<node>
     <arg type="a{sv}" direction="in"/>
     <arg type="a{sv}" direction="out"/>
 </method>
+<method name="synchronouslyAlwaysThrowException">
+    <arg type="a{sv}" direction="in"/>
+    <arg type="a{sv}" direction="out"/>
+</method>
+<method name="asynchronouslyAlwaysThrowExceptionSync">
+    <arg type="a{sv}" direction="in"/>
+    <arg type="a{sv}" direction="out"/>
+</method>
+<method name="asynchronouslyAlwaysThrowException">
+    <arg type="a{sv}" direction="in"/>
+    <arg type="a{sv}" direction="out"/>
+</method>
+<method name="returnThenThrowException">
+    <arg type="s" direction="out"/>
+</method>
+<method name="returnThenThrowExceptionSync">
+    <arg type="s" direction="out"/>
+</method>
 <method name="thisDoesNotExist"/>
 <method name="noInParameter">
     <arg type="s" direction="out"/>
@@ -71,6 +92,12 @@ var TestIface = `<node>
     <arg type="s" direction="out"/>
     <arg type="i" direction="out"/>
 </method>
+<method name="asynchronouslyEchoSync">
+    <arg type="s" direction="in"/>
+    <arg type="i" direction="in"/>
+    <arg type="s" direction="out"/>
+    <arg type="i" direction="out"/>
+</method>
 <method name="structArray">
     <arg type="a(ii)" direction="out"/>
 </method>
@@ -104,7 +131,7 @@ const PROP_READ_ONLY_INITIAL_VALUE = Math.random();
 const PROP_READ_WRITE_INITIAL_VALUE = 58;
 const PROP_WRITE_ONLY_INITIAL_VALUE = 'Initial value';
 
-/* Test is the actual object exporting the dbus methods */
+// Test is the actual object exporting the dbus methods
 class Test {
     constructor() {
         this._propReadOnly = PROP_READ_ONLY_INITIAL_VALUE;
@@ -130,8 +157,41 @@ class Test {
         throw Error('Exception!');
     }
 
+    synchronouslyAlwaysThrowExceptionAsync() {
+        throw Error('Exception!');
+    }
+
+    async asynchronouslyAlwaysThrowExceptionSync() {
+        await this.asynchronouslyAlwaysThrowExceptionAsync();
+    }
+
+    async asynchronouslyAlwaysThrowExceptionAsync() {
+        await (() => new Promise(() => {
+            throw Error('Async Exception!');
+        }))();
+    }
+
+    returnThenThrowExceptionSyncAsync(_parameters, invocation) {
+        invocation.return_value(new GLib.Variant('(s)', ['I\'m going to fail soon!']));
+
+        // These should be a no-op!
+        invocation.return_value(new GLib.Variant('(s)', ['And returning again..!']));
+        invocation.return_error_literal(Gio.DBusError, Gio.DBusError.NOT_SUPPORTED,
+            'Calling multiple times should not be supported');
+
+        // And let's throw on JS side only.
+        throw Error('Oh no!');
+    }
+
+    async returnThenThrowExceptionAsync(_parameters, invocation) {
+        invocation.return_value(new GLib.Variant('(s)', ['I\'m going to fail soon!']));
+        await (() => new Promise(() => {
+            throw Error('Oh no!');
+        }))();
+    }
+
     thisDoesNotExist() {
-        /* We'll remove this later! */
+        // We'll remove this later!
     }
 
     noInParameter() {
@@ -151,12 +211,12 @@ class Test {
     }
 
     noReturnValue() {
-        /* Empty! */
+        // Empty!
     }
 
-    /* The following two functions have identical return values
-     * in JS, but the bus message will be different.
-     * multipleOutValues is "sss", while oneArrayOut is "as"
+    /* The following two functions have identical return values in JS, but the
+     * bus message will be different. multipleOutValues() is "sss", while
+     * oneArrayOut() is "as"
      */
     multipleOutValues() {
         return ['Hello', 'World', '!'];
@@ -166,8 +226,8 @@ class Test {
         return ['Hello', 'World', '!'];
     }
 
-    /* Same thing again. In this case multipleArrayOut is "asas",
-     * while arrayOfArrayOut is "aas".
+    /* Same thing again. In this case multipleArrayOut() is "asas", while
+     * arrayOfArrayOut() is "aas".
      */
     multipleArrayOut() {
         return [['Hello', 'World'], ['World', 'Hello']];
@@ -193,8 +253,7 @@ class Test {
         return dict;
     }
 
-    /* This one is implemented asynchronously. Returns
-     * the input arguments */
+    // This one is implemented asynchronously. Returns the input arguments
     echoAsync(parameters, invocation) {
         var [someString, someInt] = parameters;
         GLib.idle_add(GLib.PRIORITY_DEFAULT, function () {
@@ -203,6 +262,16 @@ class Test {
         });
     }
 
+    async asynchronouslyEchoSync(someString, someInt) {
+        const ret = await new Promise(resolve => {
+            GLib.idle_add(GLib.PRIORITY_LOW, () => {
+                resolve([someString, someInt]);
+                return GLib.SOURCE_REMOVE;
+            });
+        });
+        return ret;
+    }
+
     // double
     get PropReadOnly() {
         return this._propReadOnly;
@@ -375,8 +444,7 @@ describe('Exported DBus object', function () {
         loop.run();
     });
 
-    /* excp must be exactly the exception thrown by the remote method
-       (more or less) */
+    // excp must be the exception thrown by the remote method (more or less)
     it('can handle an exception thrown by a remote method', function () {
         GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
             'JS ERROR: Exception in method call: alwaysThrowException: *');
@@ -395,6 +463,112 @@ describe('Exported DBus object', function () {
         await expectAsync(proxy.alwaysThrowExceptionAsync({})).toBeRejected();
     });
 
+    it('can handle an exception thrown by an async remote method that is implemented synchronously', function () {
+        GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+            'JS ERROR: Exception in method call: asynchronouslyAlwaysThrowExceptionSync: *Async Exception!*');
+
+        proxy.asynchronouslyAlwaysThrowExceptionSyncRemote({}, function (_, e) {
+            expect(e).not.toBeNull();
+            expect(e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.DBUS_ERROR)).toBeTrue();
+            expect(e.message.includes('asynchronouslyAlwaysThrowExceptionSync'));
+            loop.quit();
+        });
+        loop.run();
+    });
+
+    it('can handle an exception thrown by an async method that is implemented synchronously with async/await', async function () {
+        GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+            'JS ERROR: Exception in method call: asynchronouslyAlwaysThrowExceptionSync: *Async Exception!*');
+
+        await expectAsync(proxy.asynchronouslyAlwaysThrowExceptionSyncAsync({})).toBeRejected();
+    });
+
+    it('can handle an exception thrown by a sync remote method that is implemented asynchronously', function () {
+        GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+            'JS ERROR: Exception in method call: synchronouslyAlwaysThrowException: *');
+
+        proxy.synchronouslyAlwaysThrowExceptionRemote({}, function (result, excp) {
+            expect(excp).not.toBeNull();
+            loop.quit();
+        });
+        loop.run();
+    });
+
+    it('can handle an exception thrown by a sync method that is implemented asynchronously with async/await', async function () {
+        GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+            'JS ERROR: Exception in method call: synchronouslyAlwaysThrowException: *');
+
+        await expectAsync(proxy.synchronouslyAlwaysThrowExceptionAsync({})).toBeRejected();
+    });
+
+    it('can handle an exception thrown by an async remote method that is implemented asynchronously', function () {
+        GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+            'JS ERROR: Exception in method call: asynchronouslyAlwaysThrowException: *Async Exception!*');
+
+        proxy.asynchronouslyAlwaysThrowExceptionRemote({}, function (_, e) {
+            expect(e).not.toBeNull();
+            expect(e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.DBUS_ERROR)).toBeTrue();
+            expect(e.message.includes('asynchronouslyAlwaysThrowException'));
+            loop.quit();
+        });
+        loop.run();
+    });
+
+    it('can handle an exception thrown by an async method that is implemented asynchronously with async/await', async function () {
+        GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+            'JS ERROR: Exception in method call: asynchronouslyAlwaysThrowException: *Async Exception!*');
+
+        await expectAsync(proxy.asynchronouslyAlwaysThrowExceptionAsync({})).toBeRejected();
+    });
+
+    it('can handle an exception thrown by a sync remote method that is implemented asynchronously if invocation is already consumed', function () {
+        GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+            'JS ERROR: [object *] (returnThenThrowExceptionSync) already returned*');
+        GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+            'JS ERROR: [object *] (returnThenThrowExceptionSync) already returned*');
+        GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+            'JS ERROR: Exception in method call: returnThenThrowExceptionSync: *Oh no!*');
+
+        proxy.returnThenThrowExceptionSyncRemote(function ([result], e) {
+            expect(e).toBeNull();
+            expect(result).toBe('I\'m going to fail soon!');
+            loop.quit();
+        });
+        loop.run();
+    });
+
+    it('can handle an exception thrown by an sync method that is implemented asynchronously with async/await if invocation is already consumed', async function () {
+        GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+            'JS ERROR: [object *] (returnThenThrowExceptionSync) already returned*');
+        GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+            'JS ERROR: [object *] (returnThenThrowExceptionSync) already returned*');
+        GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+            'JS ERROR: Exception in method call: returnThenThrowExceptionSync: *Oh no!*');
+
+        const [result] = await proxy.returnThenThrowExceptionSyncAsync();
+        expect(result).toBe('I\'m going to fail soon!');
+    });
+
+    it('can handle an exception thrown by an async remote method that is implemented asynchronously if invocation is already consumed', function () {
+        GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+            'JS ERROR: Exception in method call: returnThenThrowException: *Oh no!*');
+
+        proxy.returnThenThrowExceptionRemote(function ([result], e) {
+            expect(e).toBeNull();
+            expect(result).toBe('I\'m going to fail soon!');
+            loop.quit();
+        });
+        loop.run();
+    });
+
+    it('can handle an exception thrown by an async method that is implemented asynchronously with async/await if invocation is already consumed', async function () {
+        GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+            'JS ERROR: Exception in method call: returnThenThrowException: *Oh no!*');
+
+        const [result] = await proxy.returnThenThrowExceptionAsync();
+        expect(result).toBe('I\'m going to fail soon!');
+    });
+
     it('can still destructure the return value when an exception is thrown', function () {
         GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
             'JS ERROR: Exception in method call: alwaysThrowException: *');
@@ -415,9 +589,12 @@ describe('Exported DBus object', function () {
     });
 
     it('throws an exception when trying to call a method that does not exist', function () {
-        /* First remove the method from the object! */
+        // First remove the method from the object!
         delete Test.prototype.thisDoesNotExist;
 
+        GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+            'JS ERROR: Missing handler for DBus method thisDoesNotExist: *');
+
         proxy.thisDoesNotExistRemote(function (result, excp) {
             expect(excp).not.toBeNull();
             loop.quit();
@@ -427,6 +604,10 @@ describe('Exported DBus object', function () {
 
     it('throws an exception when trying to call an async method that does not exist', async function () {
         delete Test.prototype.thisDoesNotExist;
+
+        GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+            'JS ERROR: Missing handler for DBus method thisDoesNotExist: *');
+
         await expectAsync(proxy.thisDoesNotExistAsync()).toBeRejected();
     });
 
@@ -575,6 +756,10 @@ describe('Exported DBus object', function () {
     });
 
     it('handles a bad signature by throwing an exception', function () {
+        GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+            'JS ERROR: Exception in method call: arrayOutBadSig: ' +
+            'TypeError: can\'t convert symbol to number*');
+
         proxy.arrayOutBadSigRemote(function (result, excp) {
             expect(excp).not.toBeNull();
             loop.quit();
@@ -583,6 +768,10 @@ describe('Exported DBus object', function () {
     });
 
     it('handles a bad signature in async/await by rejecting the promise', async function () {
+        GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+            'JS ERROR: Exception in method call: arrayOutBadSig: ' +
+            'TypeError: can\'t convert symbol to number*');
+
         await expectAsync(proxy.arrayOutBadSigAsync()).toBeRejected();
     });
 
@@ -607,6 +796,27 @@ describe('Exported DBus object', function () {
         expect(results).toEqual([someString, someInt]);
     });
 
+    it('can call a remote async method that is implemented synchronously', function () {
+        let someString = 'Hello world!';
+        let someInt = 42;
+
+        proxy.asynchronouslyEchoSyncRemote(someString, someInt,
+            function (result, excp) {
+                expect(excp).toBeNull();
+                expect(result).toEqual([someString, someInt]);
+                loop.quit();
+            });
+        loop.run();
+    });
+
+    it('can call an async/await async method that is implemented synchronously', async function () {
+        const someString = 'Hello world!';
+        const someInt = 42;
+
+        const results = await proxy.asynchronouslyEchoSyncAsync(someString, someInt);
+        expect(results).toEqual([someString, someInt]);
+    });
+
     it('can send and receive bytes from a remote method', function () {
         let someBytes = [0, 63, 234];
         someBytes.forEach(b => {
