@@ -2,7 +2,12 @@
 // SPDX-FileCopyrightText: 2011 Giovanni Campagna <gcampagna@src.gnome.org>
 // SPDX-FileCopyrightText: 2019, 2023 Philip Chimento <philip.chimento@gmail.com>
 
-const GLib = imports.gi.GLib;
+import GLib from 'gi://GLib';
+
+let GLibUnix;
+try {
+    GLibUnix = (await import('gi://GLibUnix')).default;
+} catch {}
 
 describe('GVariant constructor', function () {
     it('constructs a string variant', function () {
@@ -140,7 +145,37 @@ describe('GLib spawn processes', function () {
         expect(stdout).toEqual(new Uint8Array());
         expect(stderr).toEqual(new Uint8Array());
         expect(exit_status).toBe(0);
-    }).pend('https://gitlab.gnome.org/GNOME/glib/-/merge_requests/3523');
+    });
+});
+
+describe('GLib source function overrides', function () {
+    let loop, spy;
+
+    beforeEach(function () {
+        loop = new GLib.MainLoop(null, false);
+        spy = jasmine.createSpy('sourceFunc');
+    });
+
+    it('GLib.idle_add_once', function () {
+        GLib.idle_add_once(GLib.PRIORITY_DEFAULT, spy);
+        GLib.idle_add(GLib.PRIORITY_LOW, () => loop.quit());
+        loop.run();
+        expect(spy).toHaveBeenCalledTimes(1);
+    });
+
+    it('GLib.timeout_add_once', function () {
+        GLib.timeout_add_once(GLib.PRIORITY_DEFAULT, 50, spy);
+        GLib.timeout_add(GLib.PRIORITY_DEFAULT, 150, () => loop.quit());
+        loop.run();
+        expect(spy).toHaveBeenCalledTimes(1);
+    });
+
+    it('GLib.timeout_add_seconds_once', function () {
+        GLib.timeout_add_seconds_once(GLib.PRIORITY_DEFAULT, 1, spy);
+        GLib.timeout_add_seconds(GLib.PRIORITY_DEFAULT, 3, () => loop.quit());
+        loop.run();
+        expect(spy).toHaveBeenCalledTimes(1);
+    });
 });
 
 describe('GLib string function overrides', function () {
@@ -168,7 +203,7 @@ describe('GLib string function overrides', function () {
 
     // TODO: Add Regress.func_not_nullable_untyped_gpointer_in and move to testRegress.js
     it('GLib.str_hash errors when marshalling null to a not-nullable parameter', function () {
-        // This tests that we don't marshal null to a not-nullable untyped gpointer.
+        // This tests that we don't marshal null to a not-nullable untyped pointer.
         expect(() => GLib.str_hash(null)).toThrowError(
             /Argument [a-z]+ may not be null/
         );
@@ -396,11 +431,6 @@ describe('GLib.MatchInfo', function () {
 });
 
 describe('GLibUnix functionality', function () {
-    let GLibUnix;
-    try {
-        GLibUnix = imports.gi.GLibUnix;
-    } catch {}
-
     beforeEach(function () {
         if (!GLibUnix)
             pending('Not supported platform');
@@ -421,11 +451,8 @@ describe('GLibUnix functionality', function () {
 });
 
 describe('GLibUnix compatibility fallback', function () {
-    // Only test this if GLibUnix is available
-    const skip = imports.gi.versions.GLibUnix !== '2.0';
-
     beforeEach(function () {
-        if (skip)
+        if (!GLibUnix)
             pending('Not supported platform');
         GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
             '*GLib.* has been moved to a separate platform-specific library. ' +
