@@ -3,8 +3,8 @@
 // SPDX-FileCopyrightText: 2013 Giovanni Campagna <gcampagna@src.gnome.org>
 
 // We use Gio to have some objects that we know exist
-const Gio = imports.gi.Gio;
-const GObject = imports.gi.GObject;
+import Gio from 'gi://Gio';
+import GObject from 'gi://GObject';
 
 describe('Looking up param specs', function () {
     let p1, p2;
@@ -38,7 +38,7 @@ describe('GType object', function () {
     it('has a read-only name', function () {
         try {
             GObject.TYPE_STRING.name = 'foo';
-        } catch (e) {
+        } catch {
         }
         expect(GObject.TYPE_STRING.name).toEqual('gchararray');
     });
@@ -46,7 +46,7 @@ describe('GType object', function () {
     it('has an undeletable name', function () {
         try {
             delete GObject.TYPE_STRING.name;
-        } catch (e) {
+        } catch {
         }
         expect(GObject.TYPE_STRING.name).toEqual('gchararray');
     });
@@ -63,13 +63,3 @@ describe('GType marshalling', function () {
         expect(GObject.type_parent(GObject.TYPE_STRING)).toBeNull();
     });
 });
-
-describe('GType prototype object', function () {
-    it('has no name', function () {
-        expect(GIRepositoryGType.name).toBeNull();
-    });
-
-    it('has a string representation', function () {
-        expect(GIRepositoryGType.toString()).toEqual('[object GType prototype]');
-    });
-});
