@@ -2,11 +2,13 @@
 // SPDX-FileCopyrightText: 2017 Patrick Griffis <tingping@tingping.se>
 // SPDX-FileCopyrightText: 2019 Philip Chimento <philip.chimento@gmail.com>
 
-const {GLib, Gio, GObject} = imports.gi;
+import Gio from 'gi://Gio';
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
 
 let GioUnix;
 try {
-    GioUnix = imports.gi.GioUnix;
+    GioUnix = (await import('gi://GioUnix')).default;
 } catch {}
 
 const Foo = GObject.registerClass({
@@ -237,7 +239,7 @@ describe('Gio.Settings overrides', function () {
 });
 
 describe('Gio.content_type_set_mime_dirs', function () {
-    it('can be called with NULL argument', function () {
+    it('can be called with null argument', function () {
         expect(() => Gio.content_type_set_mime_dirs(null)).not.toThrow();
     });
 });
@@ -253,8 +255,20 @@ describe('Gio.add_action_entries override', function () {
             },
             {
                 name: 'bar',
+                parameter_type: new GLib.VariantType('s'),
+            },
+            {
+                name: 'baz',
                 state: 'false',
             },
+            {
+                name: 'qux',
+                state: GLib.Variant.new_boolean(true),
+            },
+            {
+                name: 'quux',
+                state: true,
+            },
         ];
 
         app.add_action_entries(entries);
@@ -263,7 +277,16 @@ describe('Gio.add_action_entries override', function () {
         expect(app.lookup_action('foo').parameter_type.dup_string()).toEqual(entries[0].parameter_type);
 
         expect(app.lookup_action('bar').name).toEqual(entries[1].name);
-        expect(app.lookup_action('bar').state.print(true)).toEqual(entries[1].state);
+        expect(app.lookup_action('bar').parameter_type.dup_string()).toEqual(entries[1].parameter_type.dup_string());
+
+        expect(app.lookup_action('baz').name).toEqual(entries[2].name);
+        expect(app.lookup_action('baz').state.print(true)).toEqual(entries[2].state);
+
+        expect(app.lookup_action('qux').name).toEqual(entries[3].name);
+        expect(app.lookup_action('qux').state.print(true)).toEqual(entries[3].state.print(true));
+
+        expect(app.lookup_action('quux').name).toEqual(entries[4].name);
+        expect(app.lookup_action('quux').state.get_boolean()).toEqual(entries[4].state);
     });
 
     it('connects and binds the activate handler', function (done) {
