@@ -5,10 +5,17 @@
 
 // Various tests having to do with how introspection is implemented in GJS
 
-imports.gi.versions.Gdk = '3.0';
-imports.gi.versions.Gtk = '3.0';
-const {Gdk, Gio, GLib, GObject, Gtk} = imports.gi;
-const System = imports.system;
+import Gdk from 'gi://Gdk?version=3.0';
+import Gio from 'gi://Gio';
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
+import Gtk from 'gi://Gtk?version=3.0';
+import System from 'system';
+
+let GioUnix;
+try {
+    GioUnix = (await import('gi://GioUnix')).default;
+} catch {}
 
 describe('GLib.DestroyNotify parameter', function () {
     it('throws when encountering a GDestroyNotify not associated with a callback', function () {
@@ -185,13 +192,32 @@ describe('Gdk.Atom', function () {
 });
 
 describe('Complete enumeration (boxed types)', function () {
-    it('enumerates all properties', function () {
+    it('enumerates all properties of a struct', function () {
         // Note: this test breaks down if other code access all the methods of Rectangle
         const rect = new Gdk.Rectangle();
         const names = Object.getOwnPropertyNames(Object.getPrototypeOf(rect));
         const expectAtLeast = ['equal', 'intersect', 'union', 'x', 'y', 'width', 'height'];
         expect(names).toEqual(jasmine.arrayContaining(expectAtLeast));
     });
+
+    it('enumerates all properties of a union', function () {
+        const event = new Gdk.Event(Gdk.EventType.KEY_PRESS);
+        const names = Object.getOwnPropertyNames(Object.getPrototypeOf(event));
+        const expectAtLeast = ['_get_angle', '_get_center', '_get_distance',
+            'any', 'button', 'configure', 'copy', 'crossing', 'dnd', 'expose',
+            'focus_change', 'free', 'get_axis', 'get_button', 'get_click_count',
+            'get_coords', 'get_device_tool', 'get_device', 'get_event_sequence',
+            'get_event_type', 'get_keycode', 'get_keyval', 'get_pointer_emulated',
+            'get_root_coords', 'get_scancode', 'get_screen', 'get_scroll_deltas',
+            'get_scroll_direction', 'get_seat', 'get_source_device', 'get_state',
+            'get_time', 'get_window', 'grab_broken', 'is_scroll_stop_event',
+            'key', 'motion', 'owner_change', 'pad_axis', 'pad_button',
+            'pad_group_mode', 'property', 'proximity', 'put', 'scroll', 'selection',
+            'set_device_tool', 'set_device', 'set_screen', 'set_source_device',
+            'setting', 'touch', 'touchpad_pinch', 'touchpad_swipe',
+            'triggers_context_menu', 'type', 'visibility', 'window_state'];
+        expect(names).toEqual(jasmine.arrayContaining(expectAtLeast));
+    });
 });
 
 describe('Complete enumeration of GIRepositoryNamespace (new_enumerate)', function () {
@@ -212,11 +238,8 @@ describe('Complete enumeration of GIRepositoryNamespace (new_enumerate)', functi
 });
 
 describe('Backwards compatibility for GLib/Gio platform specific GIRs', function () {
-    // Only test this if GioUnix is available
-    const skip = imports.gi.versions.GioUnix !== '2.0';
-
     it('GioUnix objects are looked up in GioUnix, not Gio', function () {
-        if (skip) {
+        if (!GioUnix) {
             pending('GioUnix required for this test');
             return;
         }
@@ -233,7 +256,7 @@ describe('Backwards compatibility for GLib/Gio platform specific GIRs', function
     });
 
     it('GioUnix functions are looked up in GioUnix, not Gio', function () {
-        if (skip) {
+        if (!GioUnix) {
             pending('GioUnix required for this test');
             return;
         }
@@ -249,7 +272,7 @@ describe('Backwards compatibility for GLib/Gio platform specific GIRs', function
     });
 
     it("doesn't print the message if the type isn't resolved directly", function () {
-        if (skip) {
+        if (!GioUnix) {
             pending('GioUnix required for this test');
             return;
         }
