@@ -5,8 +5,7 @@
 
 imports.gi.versions.Gtk = '3.0';
 
-const ByteArray = imports.byteArray;
-const {GjsTestTools, Gtk} = imports.gi;
+const {GLib, Gtk} = imports.gi;
 const Lang = imports.lang;
 const System = imports.system;
 
@@ -42,7 +41,7 @@ const template = `
 const MyComplexGtkSubclass = new Lang.Class({
     Name: 'MyComplexGtkSubclass',
     Extends: Gtk.Grid,
-    Template: ByteArray.fromString(template),
+    Template: new TextEncoder().encode(template),
     Children: ['label-child', 'label-child2'],
     InternalChildren: ['internal-label-child'],
     CssName: 'complex-subclass',
@@ -114,11 +113,20 @@ describe('Legacy Gtk overrides', function () {
         expect(Gtk.Widget.get_css_name.call(MyComplexGtkSubclass)).toEqual('complex-subclass');
     });
 
-    it('does not leak instance when connecting template signal', function () {
+    function asyncIdle() {
+        return new Promise(resolve => {
+            GLib.idle_add(GLib.PRIORITY_DEFAULT, () => {
+                resolve();
+                return GLib.SOURCE_REMOVE;
+            });
+        });
+    }
+
+    it('does not leak instance when connecting template signal', async function () {
         const LeakTestWidget = new Lang.Class({
             Name: 'LeakTestWidget',
             Extends: Gtk.Button,
-            Template: ByteArray.fromString(`
+            Template: new TextEncoder().encode(`
                 <interface>
                     <template class="Gjs_LeakTestWidget" parent="GtkButton">
                         <signal name="clicked" handler="buttonClicked"/>
@@ -128,14 +136,14 @@ describe('Legacy Gtk overrides', function () {
             buttonClicked() {},
         });
 
-        let widget = new LeakTestWidget();
-        GjsTestTools.save_weak(widget);
-        widget = null;
+        const weakRef = new WeakRef(new LeakTestWidget());
+
+        await asyncIdle();
         // It takes two GC cycles to free the widget, because of the tardy sweep
         // problem (https://gitlab.gnome.org/GNOME/gjs/-/issues/217)
         System.gc();
         System.gc();
 
-        expect(GjsTestTools.get_weak()).toBeNull();
+        expect(weakRef.deref()).toBeUndefined();
     });
 });
