@@ -3,8 +3,7 @@
 // SPDX-FileCopyrightText: 2010 litl, LLC.
 // SPDX-FileCopyrightText: 2020 Philip Chimento <philip.chimento@gmail.com>
 
-#ifndef MODULES_CAIRO_PRIVATE_H_
-#define MODULES_CAIRO_PRIVATE_H_
+#pragma once
 
 #include <config.h>
 
@@ -14,7 +13,6 @@
 #include <glib-object.h>
 
 #include <js/Class.h>
-#include <js/PropertySpec.h>
 #include <js/TypeDecls.h>
 #include <jspubtd.h>  // for JSProtoKey
 
@@ -23,14 +21,14 @@
 #include "gjs/macros.h"
 #include "util/log.h"
 
+struct JSFunctionSpec;
+struct JSPropertySpec;
 namespace JS {
 class CallArgs;
 }
 
 GJS_JSAPI_RETURN_CONVENTION
-bool             gjs_cairo_check_status                 (JSContext       *context,
-                                                         cairo_status_t   status,
-                                                         const char      *name);
+bool gjs_cairo_check_status(JSContext*, cairo_status_t, const char* name);
 
 class CairoRegion : public CWrapper<CairoRegion, cairo_region_t> {
     friend CWrapperPointerOps<CairoRegion, cairo_region_t>;
@@ -52,10 +50,9 @@ class CairoRegion : public CWrapper<CairoRegion, cairo_region_t> {
     }
 
     GJS_JSAPI_RETURN_CONVENTION
-    static cairo_region_t* constructor_impl(JSContext* cx,
-                                            const JS::CallArgs& args);
+    static cairo_region_t* constructor_impl(JSContext*, const JS::CallArgs&);
 
-    static void finalize_impl(JS::GCContext*, cairo_region_t* cr);
+    static void finalize_impl(JS::GCContext*, cairo_region_t*);
 
     static const JSFunctionSpec proto_funcs[];
     static const JSPropertySpec proto_props[];
@@ -73,7 +70,7 @@ class CairoRegion : public CWrapper<CairoRegion, cairo_region_t> {
         &CairoRegion::class_ops, &CairoRegion::class_spec};
 };
 
-void gjs_cairo_region_init(void);
+void gjs_cairo_region_init();
 
 class CairoContext : public CWrapper<CairoContext, cairo_t> {
     friend CWrapperPointerOps<CairoContext, cairo_t>;
@@ -93,9 +90,9 @@ class CairoContext : public CWrapper<CairoContext, cairo_t> {
     static cairo_t* copy_ptr(cairo_t* cr) { return cairo_reference(cr); }
 
     GJS_JSAPI_RETURN_CONVENTION
-    static cairo_t* constructor_impl(JSContext* cx, const JS::CallArgs& args);
+    static cairo_t* constructor_impl(JSContext*, const JS::CallArgs&);
 
-    static void finalize_impl(JS::GCContext*, cairo_t* cr);
+    static void finalize_impl(JS::GCContext*, cairo_t*);
 
     static const JSFunctionSpec proto_funcs[];
     static const JSPropertySpec proto_props[];
@@ -113,13 +110,13 @@ class CairoContext : public CWrapper<CairoContext, cairo_t> {
         &CairoContext::class_ops, &CairoContext::class_spec};
 
     GJS_JSAPI_RETURN_CONVENTION
-    static bool dispose(JSContext* cx, unsigned argc, JS::Value* vp);
+    static bool dispose(JSContext*, unsigned, JS::Value*);
 };
 
-void gjs_cairo_context_init(void);
-void gjs_cairo_surface_init(void);
+void gjs_cairo_context_init();
+void gjs_cairo_surface_init();
 
-/* path */
+// path
 void gjs_cairo_path_init();
 class CairoPath : public CWrapper<CairoPath, cairo_path_t> {
     friend CWrapperPointerOps<CairoPath, cairo_path_t>;
@@ -133,7 +130,7 @@ class CairoPath : public CWrapper<CairoPath, cairo_path_t> {
         GjsGlobalSlot::PROTOTYPE_cairo_path;
     static constexpr GjsDebugTopic DEBUG_TOPIC = GJS_DEBUG_CAIRO;
 
-    static void finalize_impl(JS::GCContext*, cairo_path_t* path);
+    static void finalize_impl(JS::GCContext*, cairo_path_t*);
 
     static const JSPropertySpec proto_props[];
     static constexpr js::ClassSpec class_spec = {
@@ -150,12 +147,12 @@ class CairoPath : public CWrapper<CairoPath, cairo_path_t> {
         &CairoPath::class_ops, &CairoPath::class_spec};
 
  public:
-    static cairo_path_t* copy_ptr(cairo_path_t* path);
+    static cairo_path_t* copy_ptr(cairo_path_t*);
     GJS_JSAPI_RETURN_CONVENTION
-    static JSObject* take_c_ptr(JSContext* cx, cairo_path_t* ptr);
+    static JSObject* take_c_ptr(JSContext*, cairo_path_t*);
 };
 
-/* surface */
+// surface
 
 class CairoSurface : public CWrapper<CairoSurface, cairo_surface_t> {
     friend CWrapperPointerOps<CairoSurface, cairo_surface_t>;
@@ -175,7 +172,7 @@ class CairoSurface : public CWrapper<CairoSurface, cairo_surface_t> {
 
     static GType gtype() { return CAIRO_GOBJECT_TYPE_SURFACE; }
 
-    static void finalize_impl(JS::GCContext*, cairo_surface_t* surface);
+    static void finalize_impl(JS::GCContext*, cairo_surface_t*);
 
     static const JSFunctionSpec proto_funcs[];
     static const JSPropertySpec proto_props[];
@@ -197,14 +194,14 @@ class CairoSurface : public CWrapper<CairoSurface, cairo_surface_t> {
     }
 
     GJS_JSAPI_RETURN_CONVENTION
-    static bool getType_func(JSContext* context, unsigned argc, JS::Value* vp);
+    static bool getType_func(JSContext*, unsigned, JS::Value*);
 
  public:
     GJS_JSAPI_RETURN_CONVENTION
-    static JSObject* from_c_ptr(JSContext* cx, cairo_surface_t* surface);
+    static JSObject* from_c_ptr(JSContext*, cairo_surface_t*);
 
     GJS_JSAPI_RETURN_CONVENTION
-    static cairo_surface_t* for_js(JSContext* cx,
+    static cairo_surface_t* for_js(JSContext*,
                                    JS::HandleObject surface_wrapper);
 };
 
@@ -218,7 +215,7 @@ class CairoImageSurface : public CWrapper<CairoImageSurface, cairo_surface_t> {
     static constexpr unsigned constructor_nargs = 3;
 
     GJS_JSAPI_RETURN_CONVENTION
-    static JSObject* new_proto(JSContext* cx, JSProtoKey);
+    static JSObject* new_proto(JSContext*, JSProtoKey);
 
     static const JSFunctionSpec static_funcs[];
     static const JSFunctionSpec proto_funcs[];
@@ -244,8 +241,7 @@ class CairoImageSurface : public CWrapper<CairoImageSurface, cairo_surface_t> {
     static void finalize_impl(JS::GCContext*, cairo_surface_t*) {}
 
     GJS_JSAPI_RETURN_CONVENTION
-    static cairo_surface_t* constructor_impl(JSContext* cx,
-                                             const JS::CallArgs& args);
+    static cairo_surface_t* constructor_impl(JSContext*, const JS::CallArgs&);
 };
 
 #ifdef CAIRO_HAS_PS_SURFACE
@@ -259,7 +255,7 @@ class CairoPSSurface : public CWrapper<CairoPSSurface, cairo_surface_t> {
     static constexpr unsigned constructor_nargs = 3;
 
     GJS_JSAPI_RETURN_CONVENTION
-    static JSObject* new_proto(JSContext* cx, JSProtoKey);
+    static JSObject* new_proto(JSContext*, JSProtoKey);
 
     static const JSFunctionSpec proto_funcs[];
     static const JSPropertySpec proto_props[];
@@ -284,13 +280,12 @@ class CairoPSSurface : public CWrapper<CairoPSSurface, cairo_surface_t> {
     static void finalize_impl(JS::GCContext*, cairo_surface_t*) {}
 
     GJS_JSAPI_RETURN_CONVENTION
-    static cairo_surface_t* constructor_impl(JSContext* cx,
-                                             const JS::CallArgs& args);
+    static cairo_surface_t* constructor_impl(JSContext*, const JS::CallArgs&);
 };
 #else
 class CairoPSSurface {
     GJS_JSAPI_RETURN_CONVENTION
-    static JSObject* from_c_ptr(JSContext* cx, cairo_surface_t* surface);
+    static JSObject* from_c_ptr(JSContext*, cairo_surface_t*);
 };
 #endif  // CAIRO_HAS_PS_SURFACE
 
@@ -305,7 +300,7 @@ class CairoPDFSurface : public CWrapper<CairoPDFSurface, cairo_surface_t> {
     static constexpr unsigned constructor_nargs = 3;
 
     GJS_JSAPI_RETURN_CONVENTION
-    static JSObject* new_proto(JSContext* cx, JSProtoKey);
+    static JSObject* new_proto(JSContext*, JSProtoKey);
 
     static const JSFunctionSpec proto_funcs[];
     static const JSPropertySpec proto_props[];
@@ -330,14 +325,13 @@ class CairoPDFSurface : public CWrapper<CairoPDFSurface, cairo_surface_t> {
     static void finalize_impl(JS::GCContext*, cairo_surface_t*) {}
 
     GJS_JSAPI_RETURN_CONVENTION
-    static cairo_surface_t* constructor_impl(JSContext* cx,
-                                             const JS::CallArgs& args);
+    static cairo_surface_t* constructor_impl(JSContext*, const JS::CallArgs&);
 };
 #else
 class CairoPDFSurface {
  public:
     GJS_JSAPI_RETURN_CONVENTION
-    static JSObject* from_c_ptr(JSContext* cx, cairo_surface_t* surface);
+    static JSObject* from_c_ptr(JSContext*, cairo_surface_t*);
 };
 #endif  // CAIRO_HAS_PDF_SURFACE
 
@@ -352,7 +346,7 @@ class CairoSVGSurface : public CWrapper<CairoSVGSurface, cairo_surface_t> {
     static constexpr unsigned constructor_nargs = 3;
 
     GJS_JSAPI_RETURN_CONVENTION
-    static JSObject* new_proto(JSContext* cx, JSProtoKey);
+    static JSObject* new_proto(JSContext*, JSProtoKey);
 
     static const JSPropertySpec proto_props[];
     static constexpr js::ClassSpec class_spec = {
@@ -376,18 +370,17 @@ class CairoSVGSurface : public CWrapper<CairoSVGSurface, cairo_surface_t> {
     static void finalize_impl(JS::GCContext*, cairo_surface_t*) {}
 
     GJS_JSAPI_RETURN_CONVENTION
-    static cairo_surface_t* constructor_impl(JSContext* cx,
-                                             const JS::CallArgs& args);
+    static cairo_surface_t* constructor_impl(JSContext*, const JS::CallArgs&);
 };
 #else
 class CairoSVGSurface {
  public:
     GJS_JSAPI_RETURN_CONVENTION
-    static JSObject* from_c_ptr(JSContext* cx, cairo_surface_t* surface);
+    static JSObject* from_c_ptr(JSContext*, cairo_surface_t*);
 };
 #endif  // CAIRO_HAS_SVG_SURFACE
 
-/* pattern */
+// pattern
 void gjs_cairo_pattern_init();
 
 class CairoPattern : public CWrapper<CairoPattern, cairo_pattern_t> {
@@ -429,19 +422,18 @@ class CairoPattern : public CWrapper<CairoPattern, cairo_pattern_t> {
     }
 
     GJS_JSAPI_RETURN_CONVENTION
-    static bool getType_func(JSContext* context, unsigned argc, JS::Value* vp);
+    static bool getType_func(JSContext*, unsigned, JS::Value*);
 
  protected:
-    static void finalize_impl(JS::GCContext*, cairo_pattern_t* pattern);
+    static void finalize_impl(JS::GCContext*, cairo_pattern_t*);
 
  public:
-    static cairo_pattern_t* for_js(JSContext* cx,
+    static cairo_pattern_t* for_js(JSContext*,
                                    JS::HandleObject pattern_wrapper);
 };
 
 GJS_JSAPI_RETURN_CONVENTION
-JSObject*        gjs_cairo_pattern_from_pattern         (JSContext       *context,
-                                                         cairo_pattern_t *pattern);
+JSObject* gjs_cairo_pattern_from_pattern(JSContext*, cairo_pattern_t*);
 
 class CairoGradient : public CWrapper<CairoGradient, cairo_pattern_t> {
     friend CWrapperPointerOps<CairoGradient, cairo_pattern_t>;
@@ -454,7 +446,7 @@ class CairoGradient : public CWrapper<CairoGradient, cairo_pattern_t> {
     static constexpr GjsDebugTopic DEBUG_TOPIC = GJS_DEBUG_CAIRO;
 
     GJS_JSAPI_RETURN_CONVENTION
-    static JSObject* new_proto(JSContext* cx, JSProtoKey);
+    static JSObject* new_proto(JSContext*, JSProtoKey);
 
     static const JSFunctionSpec proto_funcs[];
     static const JSPropertySpec proto_props[];
@@ -485,7 +477,7 @@ class CairoLinearGradient
     static constexpr unsigned constructor_nargs = 4;
 
     GJS_JSAPI_RETURN_CONVENTION
-    static JSObject* new_proto(JSContext* cx, JSProtoKey);
+    static JSObject* new_proto(JSContext*, JSProtoKey);
 
     static const JSFunctionSpec proto_funcs[];
     static const JSPropertySpec proto_props[];
@@ -508,8 +500,7 @@ class CairoLinearGradient
     }
 
     GJS_JSAPI_RETURN_CONVENTION
-    static cairo_pattern_t* constructor_impl(JSContext* cx,
-                                             const JS::CallArgs& args);
+    static cairo_pattern_t* constructor_impl(JSContext*, const JS::CallArgs&);
 
     static void finalize_impl(JS::GCContext*, cairo_pattern_t*) {}
 };
@@ -525,7 +516,7 @@ class CairoRadialGradient
     static constexpr unsigned constructor_nargs = 6;
 
     GJS_JSAPI_RETURN_CONVENTION
-    static JSObject* new_proto(JSContext* cx, JSProtoKey);
+    static JSObject* new_proto(JSContext*, JSProtoKey);
 
     static const JSFunctionSpec proto_funcs[];
     static const JSPropertySpec proto_props[];
@@ -548,8 +539,7 @@ class CairoRadialGradient
     }
 
     GJS_JSAPI_RETURN_CONVENTION
-    static cairo_pattern_t* constructor_impl(JSContext* cx,
-                                             const JS::CallArgs& args);
+    static cairo_pattern_t* constructor_impl(JSContext*, const JS::CallArgs&);
 
     static void finalize_impl(JS::GCContext*, cairo_pattern_t*) {}
 };
@@ -565,7 +555,7 @@ class CairoSurfacePattern
     static constexpr unsigned constructor_nargs = 1;
 
     GJS_JSAPI_RETURN_CONVENTION
-    static JSObject* new_proto(JSContext* cx, JSProtoKey);
+    static JSObject* new_proto(JSContext*, JSProtoKey);
 
     static const JSFunctionSpec proto_funcs[];
     static const JSPropertySpec proto_props[];
@@ -588,8 +578,7 @@ class CairoSurfacePattern
     }
 
     GJS_JSAPI_RETURN_CONVENTION
-    static cairo_pattern_t* constructor_impl(JSContext* cx,
-                                             const JS::CallArgs& args);
+    static cairo_pattern_t* constructor_impl(JSContext*, const JS::CallArgs&);
 
     static void finalize_impl(JS::GCContext*, cairo_pattern_t*) {}
 };
@@ -603,7 +592,7 @@ class CairoSolidPattern : public CWrapper<CairoSolidPattern, cairo_pattern_t> {
     static constexpr GjsDebugTopic DEBUG_TOPIC = GJS_DEBUG_CAIRO;
 
     GJS_JSAPI_RETURN_CONVENTION
-    static JSObject* new_proto(JSContext* cx, JSProtoKey);
+    static JSObject* new_proto(JSContext*, JSProtoKey);
 
     static const JSFunctionSpec static_funcs[];
     static const JSPropertySpec proto_props[];
@@ -627,5 +616,3 @@ class CairoSolidPattern : public CWrapper<CairoSolidPattern, cairo_pattern_t> {
 
     static void finalize_impl(JS::GCContext*, cairo_pattern_t*) {}
 };
-
-#endif  // MODULES_CAIRO_PRIVATE_H_
