@@ -7,7 +7,6 @@
 #include <cairo.h>
 
 #include <js/CallArgs.h>
-#include <js/GCPolicyAPI.h>
 #include <js/PropertyDescriptor.h>  // for JSPROP_READONLY
 #include <js/PropertySpec.h>
 #include <js/RootingAPI.h>
@@ -19,12 +18,6 @@
 #include "gjs/macros.h"
 #include "modules/cairo-private.h"
 
-// Avoid static_assert in MSVC builds
-namespace JS {
-template <>
-struct GCPolicy<void*> : public IgnoreGCPolicy<void*> {};
-}
-
 JSObject* CairoSolidPattern::new_proto(JSContext* cx, JSProtoKey) {
     JS::RootedObject parent_proto(cx, CairoPattern::prototype(cx));
     return JS_NewObjectWithGivenProto(cx, nullptr, parent_proto);
@@ -37,62 +30,46 @@ const JSPropertySpec CairoSolidPattern::proto_props[] = {
 // clang-format on
 
 GJS_JSAPI_RETURN_CONVENTION
-static bool
-createRGB_func(JSContext *context,
-               unsigned   argc,
-               JS::Value *vp)
-{
-    JS::CallArgs argv = JS::CallArgsFromVp (argc, vp);
+static bool createRGB_func(JSContext* cx, unsigned argc, JS::Value* vp) {
+    JS::CallArgs args = JS::CallArgsFromVp(argc, vp);
     double red, green, blue;
-    cairo_pattern_t *pattern;
-
-    if (!gjs_parse_call_args(context, "createRGB", argv, "fff",
-                             "red", &red,
-                             "green", &green,
-                             "blue", &blue))
+    if (!gjs_parse_call_args(cx, "createRGB", args, "fff", "red", &red, "green",
+                             &green, "blue", &blue))
         return false;
 
-    pattern = cairo_pattern_create_rgb(red, green, blue);
-    if (!gjs_cairo_check_status(context, cairo_pattern_status(pattern), "pattern"))
+    cairo_pattern_t* pattern = cairo_pattern_create_rgb(red, green, blue);
+    if (!gjs_cairo_check_status(cx, cairo_pattern_status(pattern), "pattern"))
         return false;
 
-    JSObject* pattern_wrapper = CairoSolidPattern::from_c_ptr(context, pattern);
+    JSObject* pattern_wrapper = CairoSolidPattern::from_c_ptr(cx, pattern);
     if (!pattern_wrapper)
         return false;
     cairo_pattern_destroy(pattern);
 
-    argv.rval().setObjectOrNull(pattern_wrapper);
+    args.rval().setObject(*pattern_wrapper);
 
     return true;
 }
 
 GJS_JSAPI_RETURN_CONVENTION
-static bool
-createRGBA_func(JSContext *context,
-                unsigned   argc,
-                JS::Value *vp)
-{
-    JS::CallArgs argv = JS::CallArgsFromVp (argc, vp);
+static bool createRGBA_func(JSContext* cx, unsigned argc, JS::Value* vp) {
+    JS::CallArgs args = JS::CallArgsFromVp(argc, vp);
     double red, green, blue, alpha;
-    cairo_pattern_t *pattern;
-
-    if (!gjs_parse_call_args(context, "createRGBA", argv, "ffff",
-                             "red", &red,
-                             "green", &green,
-                             "blue", &blue,
-                             "alpha", &alpha))
+    if (!gjs_parse_call_args(cx, "createRGBA", args, "ffff", "red", &red,
+                             "green", &green, "blue", &blue, "alpha", &alpha))
         return false;
 
-    pattern = cairo_pattern_create_rgba(red, green, blue, alpha);
-    if (!gjs_cairo_check_status(context, cairo_pattern_status(pattern), "pattern"))
+    cairo_pattern_t* pattern =
+        cairo_pattern_create_rgba(red, green, blue, alpha);
+    if (!gjs_cairo_check_status(cx, cairo_pattern_status(pattern), "pattern"))
         return false;
 
-    JSObject* pattern_wrapper = CairoSolidPattern::from_c_ptr(context, pattern);
+    JSObject* pattern_wrapper = CairoSolidPattern::from_c_ptr(cx, pattern);
     if (!pattern_wrapper)
         return false;
     cairo_pattern_destroy(pattern);
 
-    argv.rval().setObjectOrNull(pattern_wrapper);
+    args.rval().setObject(*pattern_wrapper);
 
     return true;
 }
