@@ -34,21 +34,18 @@ JSObject* CairoSVGSurface::new_proto(JSContext* cx, JSProtoKey) {
     return JS_NewObjectWithGivenProto(cx, nullptr, parent_proto);
 }
 
-cairo_surface_t* CairoSVGSurface::constructor_impl(JSContext* context,
-                                                   const JS::CallArgs& argv) {
+cairo_surface_t* CairoSVGSurface::constructor_impl(JSContext* cx,
+                                                   const JS::CallArgs& args) {
     Gjs::AutoChar filename;
     double width, height;
-    cairo_surface_t *surface;
-    if (!gjs_parse_call_args(context, "SVGSurface", argv, "Fff",
-                             "filename", &filename,
-                             "width", &width,
-                             "height", &height))
+    if (!gjs_parse_call_args(cx, "SVGSurface", args, "Fff", "filename",
+                             &filename, "width", &width, "height", &height))
         return nullptr;
 
-    surface = cairo_svg_surface_create(filename, width, height);
+    cairo_surface_t* surface =
+        cairo_svg_surface_create(filename, width, height);
 
-    if (!gjs_cairo_check_status(context, cairo_surface_status(surface),
-                                "surface"))
+    if (!gjs_cairo_check_status(cx, cairo_surface_status(surface), "surface"))
         return nullptr;
 
     return surface;
@@ -61,11 +58,10 @@ const JSPropertySpec CairoSVGSurface::proto_props[] = {
 // clang-format on
 
 #else
-JSObject* CairoSVGSurface::from_c_ptr(JSContext* context,
-                                      cairo_surface_t* surface) {
-    gjs_throw(context,
-        "could not create SVG surface, recompile cairo and gjs with "
-        "SVG support.");
+JSObject* CairoSVGSurface::from_c_ptr(JSContext* cx, cairo_surface_t* surface) {
+    gjs_throw(cx,
+              "could not create SVG surface, recompile cairo and gjs with SVG "
+              "support.");
     return nullptr;
 }
-#endif /* CAIRO_HAS_SVG_SURFACE */
+#endif  // CAIRO_HAS_SVG_SURFACE
