@@ -28,6 +28,7 @@
 #include <glib/gprintf.h>  // for g_fprintf
 
 #ifdef HAVE_READLINE_READLINE_H
+#    include <gio/gio.h>
 #    include <gio/gunixinputstream.h>
 #endif
 
@@ -69,18 +70,18 @@ static void gjs_console_warning_reporter(JSContext*, JSErrorReport* report) {
     JS::PrintError(stderr, report, /* reportWarnings = */ true);
 }
 
-/* Based on js::shell::AutoReportException from SpiderMonkey. */
+// Based on js::shell::AutoReportException from SpiderMonkey.
 class AutoReportException {
-    JSContext *m_cx;
+    JSContext* m_cx;
 
-public:
-    explicit AutoReportException(JSContext *cx) : m_cx(cx) {}
+ public:
+    explicit AutoReportException(JSContext* cx) : m_cx(cx) {}
 
     ~AutoReportException() {
         if (!JS_IsExceptionPending(m_cx))
             return;
 
-        /* Get exception object before printing and clearing exception. */
+        // Get exception object before printing and clearing exception.
         JS::ExceptionStack exnStack(m_cx);
         JS::ErrorReportBuilder report(m_cx);
         if (!JS::StealPendingExceptionStack(m_cx, &exnStack) ||
@@ -114,7 +115,6 @@ public:
     }
 };
 
-
 // Adapted from https://stackoverflow.com/a/17035073/172999
 class AutoCatchCtrlC {
 #ifdef HAVE_SIGNAL_H
@@ -157,7 +157,7 @@ static bool rl_async_done = true;
 static gboolean on_stdin_ready(GPollableInputStream* pollable, void*) {
     while (g_pollable_input_stream_is_readable(pollable))
         rl_callback_read_char();
-    return TRUE;  // don't remove source
+    return G_SOURCE_CONTINUE;
 }
 
 static void on_readline_complete(char* line) {
@@ -237,10 +237,9 @@ std::string print_string_value(JSContext* cx, JS::HandleValue v_string) {
  * exception. (This is because the exception should be auto-printed around the
  * invocation of this function.)
  */
-[[nodiscard]] static bool gjs_console_eval_and_print(JSContext* cx,
-                                                     JS::HandleObject global,
-                                                     const std::string& bytes,
-                                                     int lineno) {
+[[nodiscard]]
+static bool gjs_console_eval_and_print(JSContext* cx, JS::HandleObject global,
+                                       const std::string& bytes, int lineno) {
     JS::SourceText<mozilla::Utf8Unit> source;
     if (!source.init(cx, bytes.c_str(), bytes.size(),
                      JS::SourceOwnership::Borrowed))
@@ -279,23 +278,19 @@ std::string print_string_value(JSContext* cx, JS::HandleValue v_string) {
 }
 
 GJS_JSAPI_RETURN_CONVENTION
-static bool
-gjs_console_interact(JSContext *context,
-                     unsigned   argc,
-                     JS::Value *vp)
-{
-    JS::CallArgs argv = JS::CallArgsFromVp(argc, vp);
+static bool gjs_console_interact(JSContext* cx, unsigned argc, JS::Value* vp) {
+    JS::CallArgs args = JS::CallArgsFromVp(argc, vp);
     volatile bool eof, exit_warning;  // accessed after setjmp()
-    JS::RootedObject global{context, JS::CurrentGlobalOrNull(context)};
+    JS::RootedObject global{cx, JS::CurrentGlobalOrNull(cx)};
     volatile int lineno;     // accessed after setjmp()
     volatile int startline;  // accessed after setjmp()
-    GjsContextPrivate* gjs = GjsContextPrivate::from_cx(context);
+    GjsContextPrivate* gjs = GjsContextPrivate::from_cx(cx);
 
 #ifndef HAVE_READLINE_READLINE_H
     int rl_end = 0;  // nonzero if using readline and any text is typed in
 #endif
 
-    JS::SetWarningReporter(context, gjs_console_warning_reporter);
+    JS::SetWarningReporter(cx, gjs_console_warning_reporter);
 
     AutoCatchCtrlC ctrl_c;
 
@@ -346,13 +341,13 @@ gjs_console_interact(JSContext *context,
             buffer += temp_buf;
             buffer += "\n";
             lineno++;
-        } while (!JS_Utf8BufferIsCompilableUnit(context, global, buffer.c_str(),
+        } while (!JS_Utf8BufferIsCompilableUnit(cx, global, buffer.c_str(),
                                                 buffer.size()));
 
         bool ok;
         {
-            AutoReportException are(context);
-            ok = gjs_console_eval_and_print(context, global, buffer, startline);
+            AutoReportException are(cx);
+            ok = gjs_console_eval_and_print(cx, global, buffer, startline);
         }
         exit_warning = false;
 
@@ -370,17 +365,14 @@ gjs_console_interact(JSContext *context,
 
     g_fprintf(stdout, "\n");
 
-    argv.rval().setUndefined();
+    args.rval().setUndefined();
     return true;
 }
 
-bool
-gjs_define_console_stuff(JSContext              *context,
-                         JS::MutableHandleObject module)
-{
-    module.set(JS_NewPlainObject(context));
-    const GjsAtoms& atoms = GjsContextPrivate::atoms(context);
-    return JS_DefineFunctionById(context, module, atoms.interact(),
+bool gjs_define_console_stuff(JSContext* cx, JS::MutableHandleObject module) {
+    module.set(JS_NewPlainObject(cx));
+    const GjsAtoms& atoms = GjsContextPrivate::atoms(cx);
+    return JS_DefineFunctionById(cx, module, atoms.interact(),
                                  gjs_console_interact, 1,
                                  GJS_MODULE_PROP_FLAGS);
 }
