@@ -110,40 +110,32 @@ T get_random_number() {
     g_assert_not_reached();
 }
 
-static void
-gjstest_test_func_gjs_context_construct_destroy(void)
-{
-    GjsContext *context;
-
-    /* Construct twice just to possibly a case where global state from
-     * the first leaks.
+static void gjstest_test_func_gjs_context_construct_destroy() {
+    /* Construct twice just to possibly a case where global state from the first
+     * leaks.
      */
-    context = gjs_context_new ();
-    g_object_unref (context);
+    GjsContext* gjs_context = gjs_context_new();
+    g_object_unref(gjs_context);
 
-    context = gjs_context_new ();
-    g_object_unref (context);
+    gjs_context = gjs_context_new();
+    g_object_unref(gjs_context);
 }
 
-static void
-gjstest_test_func_gjs_context_construct_eval(void)
-{
-    GjsContext *context;
+static void gjstest_test_func_gjs_context_construct_eval() {
     int estatus;
     AutoError error;
 
-    context = gjs_context_new ();
-    if (!gjs_context_eval (context, "1+1", -1, "<input>", &estatus, &error))
-        g_error ("%s", error->message);
-    g_object_unref (context);
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
+    if (!gjs_context_eval(gjs_context, "1+1", -1, "<input>", &estatus, &error))
+        g_error("%s", error->message);
 }
 
 static void gjstest_test_func_gjs_context_eval_dynamic_import() {
-    AutoUnref<GjsContext> gjs{gjs_context_new()};
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     AutoError error;
     int status;
 
-    bool ok = gjs_context_eval(gjs, R"js(
+    bool ok = gjs_context_eval(gjs_context, R"js(
         import('system')
             .catch(logError)
             .finally(() => imports.mainloop.quit());
@@ -156,7 +148,7 @@ static void gjstest_test_func_gjs_context_eval_dynamic_import() {
 }
 
 static void gjstest_test_func_gjs_context_eval_dynamic_import_relative() {
-    AutoUnref<GjsContext> gjs{gjs_context_new()};
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     AutoError error;
     int status;
 
@@ -165,7 +157,7 @@ static void gjstest_test_func_gjs_context_eval_dynamic_import_relative() {
     g_assert_true(ok);
     g_assert_no_error(error);
 
-    ok = gjs_context_eval(gjs, R"js(
+    ok = gjs_context_eval(gjs_context, R"js(
         let num;
         import('./num.js')
             .then(module => (num = module.default))
@@ -184,14 +176,14 @@ static void gjstest_test_func_gjs_context_eval_dynamic_import_relative() {
 }
 
 static void gjstest_test_func_gjs_context_eval_dynamic_import_bad() {
-    AutoUnref<GjsContext> gjs{gjs_context_new()};
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     AutoError error;
     int status;
 
     g_test_expect_message("Gjs", G_LOG_LEVEL_WARNING,
                           "*ImportError*badmodule*");
 
-    bool ok = gjs_context_eval(gjs, R"js(
+    bool ok = gjs_context_eval(gjs_context, R"js(
         let isBad = false;
         import('badmodule')
             .catch(err => {
@@ -211,27 +203,26 @@ static void gjstest_test_func_gjs_context_eval_dynamic_import_bad() {
     g_test_assert_expected_messages();
 }
 
-static void gjstest_test_func_gjs_context_eval_non_zero_terminated(void) {
-    AutoUnref<GjsContext> gjs{gjs_context_new()};
+static void gjstest_test_func_gjs_context_eval_non_zero_terminated() {
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     AutoError error;
     int status;
 
     // This string is invalid JS if it is treated as zero-terminated
-    bool ok = gjs_context_eval(gjs, "77!", 2, "<input>", &status, &error);
+    bool ok =
+        gjs_context_eval(gjs_context, "77!", 2, "<input>", &status, &error);
 
     g_assert_true(ok);
     g_assert_no_error(error);
     g_assert_cmpint(status, ==, 77);
 }
 
-static void
-gjstest_test_func_gjs_context_exit(void)
-{
-    GjsContext *context = gjs_context_new();
+static void gjstest_test_func_gjs_context_exit() {
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     AutoError error;
     int status;
 
-    bool ok = gjs_context_eval(context, "imports.system.exit(0);", -1,
+    bool ok = gjs_context_eval(gjs_context, "imports.system.exit(0);", -1,
                                "<input>", &status, &error);
     g_assert_false(ok);
     g_assert_error(error, GJS_ERROR, GJS_ERROR_SYSTEM_EXIT);
@@ -239,22 +230,20 @@ gjstest_test_func_gjs_context_exit(void)
 
     error.reset();
 
-    ok = gjs_context_eval(context, "imports.system.exit(42);", -1, "<input>",
-                          &status, &error);
+    ok = gjs_context_eval(gjs_context, "imports.system.exit(42);", -1,
+                          "<input>", &status, &error);
     g_assert_false(ok);
     g_assert_error(error, GJS_ERROR, GJS_ERROR_SYSTEM_EXIT);
     g_assert_cmpuint(status, ==, 42);
-
-    g_object_unref(context);
 }
 
 static void gjstest_test_func_gjs_context_eval_module_file() {
-    AutoUnref<GjsContext> gjs{gjs_context_new()};
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     uint8_t exit_status;
     AutoError error;
 
     bool ok = gjs_context_eval_module_file(
-        gjs, "resource:///org/gnome/gjs/mock/test/modules/default.js",
+        gjs_context, "resource:///org/gnome/gjs/mock/test/modules/default.js",
         &exit_status, &error);
 
     g_assert_true(ok);
@@ -264,14 +253,14 @@ static void gjstest_test_func_gjs_context_eval_module_file() {
 }
 
 static void gjstest_test_func_gjs_context_eval_module_file_throw() {
-    AutoUnref<GjsContext> gjs{gjs_context_new()};
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     uint8_t exit_status;
     AutoError error;
 
     g_test_expect_message("Gjs", G_LOG_LEVEL_CRITICAL, "*bad module*");
 
     bool ok = gjs_context_eval_module_file(
-        gjs, "resource:///org/gnome/gjs/mock/test/modules/throws.js",
+        gjs_context, "resource:///org/gnome/gjs/mock/test/modules/throws.js",
         &exit_status, &error);
 
     g_assert_false(ok);
@@ -282,12 +271,12 @@ static void gjstest_test_func_gjs_context_eval_module_file_throw() {
 }
 
 static void gjstest_test_func_gjs_context_eval_module_file_exit() {
-    AutoUnref<GjsContext> gjs{gjs_context_new()};
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     AutoError error;
     uint8_t exit_status;
 
     bool ok = gjs_context_eval_module_file(
-        gjs, "resource:///org/gnome/gjs/mock/test/modules/exit0.js",
+        gjs_context, "resource:///org/gnome/gjs/mock/test/modules/exit0.js",
         &exit_status, &error);
 
     g_assert_false(ok);
@@ -297,7 +286,7 @@ static void gjstest_test_func_gjs_context_eval_module_file_exit() {
     error.reset();
 
     ok = gjs_context_eval_module_file(
-        gjs, "resource:///org/gnome/gjs/mock/test/modules/exit.js",
+        gjs_context, "resource:///org/gnome/gjs/mock/test/modules/exit.js",
         &exit_status, &error);
 
     g_assert_false(ok);
@@ -306,7 +295,7 @@ static void gjstest_test_func_gjs_context_eval_module_file_exit() {
 }
 
 static void gjstest_test_func_gjs_context_eval_module_file_fail_instantiate() {
-    AutoUnref<GjsContext> gjs{gjs_context_new()};
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     AutoError error;
     uint8_t exit_status;
 
@@ -315,7 +304,7 @@ static void gjstest_test_func_gjs_context_eval_module_file_fail_instantiate() {
     // evaluating this module without registering 'foo' first should make it
     // fail ModuleLink
     bool ok = gjs_context_eval_module_file(
-        gjs, "resource:///org/gnome/gjs/mock/test/modules/import.js",
+        gjs_context, "resource:///org/gnome/gjs/mock/test/modules/import.js",
         &exit_status, &error);
 
     g_assert_false(ok);
@@ -325,15 +314,16 @@ static void gjstest_test_func_gjs_context_eval_module_file_fail_instantiate() {
     g_test_assert_expected_messages();
 }
 
-static void gjstest_test_func_gjs_context_eval_module_file_exit_code_omitted_warning() {
-    AutoUnref<GjsContext> gjs{gjs_context_new()};
+static void
+gjstest_test_func_gjs_context_eval_module_file_exit_code_omitted_warning() {
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     AutoError error;
 
     g_test_expect_message("Gjs", G_LOG_LEVEL_WARNING, "*foo*");
 
     bool ok = gjs_context_eval_module_file(
-        gjs, "resource:///org/gnome/gjs/mock/test/modules/import.js", nullptr,
-        &error);
+        gjs_context, "resource:///org/gnome/gjs/mock/test/modules/import.js",
+        nullptr, &error);
 
     g_assert_false(ok);
     g_assert_error(error, GJS_ERROR, GJS_ERROR_FAILED);
@@ -343,26 +333,26 @@ static void gjstest_test_func_gjs_context_eval_module_file_exit_code_omitted_war
 
 static void
 gjstest_test_func_gjs_context_eval_module_file_exit_code_omitted_no_warning() {
-    AutoUnref<GjsContext> gjs{gjs_context_new()};
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     AutoError error;
 
     bool ok = gjs_context_eval_module_file(
-        gjs, "resource:///org/gnome/gjs/mock/test/modules/default.js", nullptr,
-        &error);
+        gjs_context, "resource:///org/gnome/gjs/mock/test/modules/default.js",
+        nullptr, &error);
 
     g_assert_true(ok);
     g_assert_no_error(error);
 }
 
 static void gjstest_test_func_gjs_context_eval_file_exit_code_omitted_throw() {
-    AutoUnref<GjsContext> gjs{gjs_context_new()};
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     AutoError error;
 
     g_test_expect_message("Gjs", G_LOG_LEVEL_CRITICAL, "*bad module*");
 
     bool ok = gjs_context_eval_file(
-        gjs, "resource:///org/gnome/gjs/mock/test/modules/throws.js", nullptr,
-        &error);
+        gjs_context, "resource:///org/gnome/gjs/mock/test/modules/throws.js",
+        nullptr, &error);
 
     g_assert_false(ok);
     g_assert_error(error, GJS_ERROR, GJS_ERROR_FAILED);
@@ -370,31 +360,32 @@ static void gjstest_test_func_gjs_context_eval_file_exit_code_omitted_throw() {
     g_test_assert_expected_messages();
 }
 
-static void gjstest_test_func_gjs_context_eval_file_exit_code_omitted_no_throw() {
-    AutoUnref<GjsContext> gjs{gjs_context_new()};
+static void
+gjstest_test_func_gjs_context_eval_file_exit_code_omitted_no_throw() {
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     AutoError error;
 
     bool ok = gjs_context_eval_file(
-        gjs, "resource:///org/gnome/gjs/mock/test/modules/nothrows.js", nullptr,
-        &error);
+        gjs_context, "resource:///org/gnome/gjs/mock/test/modules/nothrows.js",
+        nullptr, &error);
 
     g_assert_true(ok);
     g_assert_no_error(error);
 }
 
 static void gjstest_test_func_gjs_context_register_module_eval_module() {
-    AutoUnref<GjsContext> gjs{gjs_context_new()};
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     AutoError error;
 
     bool ok = gjs_context_register_module(
-        gjs, "foo", "resource:///org/gnome/gjs/mock/test/modules/default.js",
-        &error);
+        gjs_context, "foo",
+        "resource:///org/gnome/gjs/mock/test/modules/default.js", &error);
 
     g_assert_true(ok);
     g_assert_no_error(error);
 
     uint8_t exit_status;
-    ok = gjs_context_eval_module(gjs, "foo", &exit_status, &error);
+    ok = gjs_context_eval_module(gjs_context, "foo", &exit_status, &error);
 
     g_assert_true(ok);
     g_assert_no_error(error);
@@ -402,19 +393,19 @@ static void gjstest_test_func_gjs_context_register_module_eval_module() {
 }
 
 static void gjstest_test_func_gjs_context_register_module_eval_module_file() {
-    AutoUnref<GjsContext> gjs{gjs_context_new()};
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     AutoError error;
 
     bool ok = gjs_context_register_module(
-        gjs, "foo", "resource:///org/gnome/gjs/mock/test/modules/default.js",
-        &error);
+        gjs_context, "foo",
+        "resource:///org/gnome/gjs/mock/test/modules/default.js", &error);
 
     g_assert_true(ok);
     g_assert_no_error(error);
 
     uint8_t exit_status;
     ok = gjs_context_eval_module_file(
-        gjs, "resource:///org/gnome/gjs/mock/test/modules/import.js",
+        gjs_context, "resource:///org/gnome/gjs/mock/test/modules/import.js",
         &exit_status, &error);
 
     g_assert_true(ok);
@@ -487,49 +478,52 @@ static void gjstest_test_func_gjs_context_register_module_eval_jsapi_rel(
 }
 
 static void gjstest_test_func_gjs_context_register_module_non_existent() {
-    AutoUnref<GjsContext> gjs{gjs_context_new()};
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     AutoError error;
 
-    bool ok = gjs_context_register_module(gjs, "foo", "nonexist.js", &error);
+    bool ok =
+        gjs_context_register_module(gjs_context, "foo", "nonexist.js", &error);
 
     g_assert_false(ok);
     g_assert_error(error, GJS_ERROR, GJS_ERROR_FAILED);
 }
 
 static void gjstest_test_func_gjs_context_eval_module_unregistered() {
-    AutoUnref<GjsContext> gjs{gjs_context_new()};
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     AutoError error;
     uint8_t exit_status;
 
-    bool ok = gjs_context_eval_module(gjs, "foo", &exit_status, &error);
+    bool ok = gjs_context_eval_module(gjs_context, "foo", &exit_status, &error);
 
     g_assert_false(ok);
     g_assert_error(error, GJS_ERROR, GJS_ERROR_FAILED);
     g_assert_cmpuint(exit_status, ==, 1);
 }
 
-static void gjstest_test_func_gjs_context_eval_module_exit_code_omitted_throw() {
-    AutoUnref<GjsContext> gjs{gjs_context_new()};
+static void
+gjstest_test_func_gjs_context_eval_module_exit_code_omitted_throw() {
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     AutoError error;
 
-    bool ok = gjs_context_eval_module(gjs, "foo", nullptr, &error);
+    bool ok = gjs_context_eval_module(gjs_context, "foo", nullptr, &error);
 
     g_assert_false(ok);
     g_assert_error(error, GJS_ERROR, GJS_ERROR_FAILED);
 }
 
-static void gjstest_test_func_gjs_context_eval_module_exit_code_omitted_no_throw() {
-    AutoUnref<GjsContext> gjs{gjs_context_new()};
+static void
+gjstest_test_func_gjs_context_eval_module_exit_code_omitted_no_throw() {
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     AutoError error;
 
     bool ok = gjs_context_register_module(
-        gjs, "lies", "resource:///org/gnome/gjs/mock/test/modules/nothrows.js",
-        &error);
+        gjs_context, "lies",
+        "resource:///org/gnome/gjs/mock/test/modules/nothrows.js", &error);
 
     g_assert_true(ok);
     g_assert_no_error(error);
 
-    ok = gjs_context_eval_module(gjs, "lies", NULL, &error);
+    ok = gjs_context_eval_module(gjs_context, "lies", nullptr, &error);
 
     g_assert_true(ok);
     g_assert_no_error(error);
@@ -579,9 +573,10 @@ static void gjstest_test_func_gjs_context_module_eval_jsapi_throws(
 }
 
 static void gjstest_test_func_gjs_context_run_in_realm() {
-    AutoUnref<GjsContext> gjs{gjs_context_new()};
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
 
-    auto* cx = static_cast<JSContext*>(gjs_context_get_native_context(gjs));
+    auto* cx =
+        static_cast<JSContext*>(gjs_context_get_native_context(gjs_context));
     g_assert_null(JS::GetCurrentRealmOrNull(cx));
 
     struct RunInRealmData {
@@ -590,14 +585,14 @@ static void gjstest_test_func_gjs_context_run_in_realm() {
     } data{42, false};
 
     gjs_context_run_in_realm(
-        gjs,
-        [](GjsContext* gjs, void* ptr) {
-            g_assert_true(GJS_IS_CONTEXT(gjs));
+        gjs_context,
+        [](GjsContext* gjs_context, void* ptr) {
+            g_assert_true(GJS_IS_CONTEXT(gjs_context));
             auto* data = static_cast<RunInRealmData*>(ptr);
             g_assert_cmpint(data->sentinel, ==, 42);
 
-            auto* cx =
-                static_cast<JSContext*>(gjs_context_get_native_context(gjs));
+            auto* cx = static_cast<JSContext*>(
+                gjs_context_get_native_context(gjs_context));
             g_assert_nonnull(JS::GetCurrentRealmOrNull(cx));
 
             data->has_run = true;
@@ -608,46 +603,46 @@ static void gjstest_test_func_gjs_context_run_in_realm() {
     g_assert_true(data.has_run);
 }
 
-#define JS_CLASS "\
-const GObject = imports.gi.GObject; \
-const FooBar = GObject.registerClass(class FooBar extends GObject.Object {}); \
-"
-
-static void
-gjstest_test_func_gjs_gobject_js_defined_type(void)
-{
-    GjsContext *context = gjs_context_new();
+static void gjstest_test_func_gjs_gobject_js_defined_type() {
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     AutoError error;
     int status;
-    bool ok = gjs_context_eval(context, JS_CLASS, -1, "<input>", &status, &error);
+    static const char js_class[] = R"js(
+        const GObject = imports.gi.GObject;
+        const FooBar = GObject.registerClass(
+            class FooBar extends GObject.Object {});
+    )js";
+    bool ok =
+        gjs_context_eval(gjs_context, js_class, -1, "<input>", &status, &error);
     g_assert_no_error(error);
     g_assert_true(ok);
 
     GType foo_type = g_type_from_name("Gjs_FooBar");
     g_assert_cmpuint(foo_type, !=, G_TYPE_INVALID);
 
-    gpointer foo = g_object_new(foo_type, NULL);
+    void* foo = g_object_new(foo_type, nullptr);
     g_assert_true(G_IS_OBJECT(foo));
 
     g_object_unref(foo);
-    g_object_unref(context);
 }
 
-static void gjstest_test_func_gjs_gobject_without_introspection(void) {
-    AutoUnref<GjsContext> context{gjs_context_new()};
+static void gjstest_test_func_gjs_gobject_without_introspection() {
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     AutoError error;
     int status;
 
-    /* Ensure class */
+    // Ensure class
     g_type_class_ref(GJSTEST_TYPE_NO_INTROSPECTION_OBJECT);
 
-#define TESTJS                                                         \
-    "const {GObject} = imports.gi;"                                    \
-    "var obj = GObject.Object.newv("                                   \
-    "    GObject.type_from_name('GjsTestNoIntrospectionObject'), []);" \
-    "obj.a_int = 1234;"
+    static const char testjs[] = R"js(
+        const {GObject} = imports.gi;
+        var obj = GObject.Object.newv(
+            GObject.type_from_name('GjsTestNoIntrospectionObject'), []);
+        obj.a_int = 1234;
+    )js";
 
-    bool ok = gjs_context_eval(context, TESTJS, -1, "<input>", &status, &error);
+    bool ok =
+        gjs_context_eval(gjs_context, testjs, -1, "<input>", &status, &error);
     g_assert_true(ok);
     g_assert_no_error(error);
 
@@ -655,21 +650,22 @@ static void gjstest_test_func_gjs_gobject_without_introspection(void) {
     g_assert_nonnull(obj);
 
     int val = 0;
-    g_object_get(obj, "a-int", &val, NULL);
+    g_object_get(obj, "a-int", &val, nullptr);
     g_assert_cmpint(val, ==, 1234);
 
 #undef TESTJS
 }
 
 static void gjstest_test_func_gjs_context_eval_exit_code_omitted_throw() {
-    AutoUnref<GjsContext> context{gjs_context_new()};
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     AutoError error;
 
     g_test_expect_message("Gjs", G_LOG_LEVEL_CRITICAL, "*wrong code*");
 
     const char bad_js[] = "throw new Error('wrong code');";
 
-    bool ok = gjs_context_eval(context, bad_js, -1, "<input>", nullptr, &error);
+    bool ok =
+        gjs_context_eval(gjs_context, bad_js, -1, "<input>", nullptr, &error);
 
     g_assert_false(ok);
     g_assert_error(error, GJS_ERROR, GJS_ERROR_FAILED);
@@ -678,13 +674,13 @@ static void gjstest_test_func_gjs_context_eval_exit_code_omitted_throw() {
 }
 
 static void gjstest_test_func_gjs_context_eval_exit_code_omitted_no_throw() {
-    AutoUnref<GjsContext> context{gjs_context_new()};
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     AutoError error;
 
     const char good_js[] = "let num = 77;";
 
     bool ok =
-        gjs_context_eval(context, good_js, -1, "<input>", nullptr, &error);
+        gjs_context_eval(gjs_context, good_js, -1, "<input>", nullptr, &error);
 
     g_assert_true(ok);
     g_assert_no_error(error);
@@ -705,7 +701,7 @@ static void gjstest_test_func_gjs_jsapi_util_error_throw(GjsUnitTestFixture* fx,
                                                          const void*) {
     JS::RootedValue exc(fx->cx), value(fx->cx);
 
-    /* Test that we can throw */
+    // Test that we can throw
 
     gjs_throw(fx->cx, "This is an exception %d", 42);
 
@@ -723,14 +719,14 @@ static void gjstest_test_func_gjs_jsapi_util_error_throw(GjsUnitTestFixture* fx,
     g_assert_nonnull(s);
     g_assert_cmpstr(s.get(), ==, "This is an exception 42");
 
-    /* keep this around before we clear it */
+    // keep this around before we clear it
     JS::RootedValue previous(fx->cx, exc);
 
     JS_ClearPendingException(fx->cx);
 
     g_assert_false(JS_IsExceptionPending(fx->cx));
 
-    /* Check that we don't overwrite a pending exception */
+    // Check that we don't overwrite a pending exception
     JS_SetPendingException(fx->cx, previous);
 
     g_assert_true(JS_IsExceptionPending(fx->cx));
@@ -786,7 +782,7 @@ static void test_jsapi_util_string_utf8_nchars_to_js(GjsUnitTestFixture* fx,
 
 static void test_jsapi_util_string_char16_data(GjsUnitTestFixture* fx,
                                                const void*) {
-    char16_t *chars;
+    char16_t* chars;
     size_t len;
 
     JS::ConstUTF8CharsZ jschars(VALID_UTF8_STRING, strlen(VALID_UTF8_STRING));
@@ -796,7 +792,7 @@ static void test_jsapi_util_string_char16_data(GjsUnitTestFixture* fx,
     g_assert_true(result == u"\xc9\xd6 foobar \u30df");
     g_free(chars);
 
-    /* Try with a string that is likely to be stored as Latin-1 */
+    // Try with a string that is likely to be stored as Latin-1
     str = JS_NewStringCopyZ(fx->cx, "abcd");
     bool ok = gjs_string_get_char16_data(fx->cx, str, &chars, &len);
     g_assert_true(ok);
@@ -808,7 +804,7 @@ static void test_jsapi_util_string_char16_data(GjsUnitTestFixture* fx,
 
 static void test_jsapi_util_string_to_ucs4(GjsUnitTestFixture* fx,
                                            const void*) {
-    gunichar *chars;
+    gunichar* chars;
     size_t len;
 
     JS::ConstUTF8CharsZ jschars(VALID_UTF8_STRING, strlen(VALID_UTF8_STRING));
@@ -819,7 +815,7 @@ static void test_jsapi_util_string_to_ucs4(GjsUnitTestFixture* fx,
     g_assert_true(result == U"\xc9\xd6 foobar \u30df");
     g_free(chars);
 
-    /* Try with a string that is likely to be stored as Latin-1 */
+    // Try with a string that is likely to be stored as Latin-1
     str = JS_NewStringCopyZ(fx->cx, "abcd");
     bool ok = gjs_string_to_ucs4(fx->cx, str, &chars, &len);
     g_assert_true(ok);
@@ -861,7 +857,7 @@ static void test_gjs_debug_value_bigint_uint64(GjsUnitTestFixture* fx,
                                                const void*) {
     // gjs_debug_value(BigIntValue) prints whatever fits into int64_t, because
     // more complicated operations might be fallible
-    JS::BigInt* bi = JS::NumberToBigInt(fx->cx, G_MAXUINT64);
+    JS::BigInt* bi = JS::NumberToBigInt(fx->cx, UINT64_MAX);
     std::string debug_output = gjs_debug_bigint(bi);
 
     g_assert_cmpstr(debug_output.c_str(), ==,
@@ -895,64 +891,50 @@ static void test_gjs_debug_value_string_quotes(GjsUnitTestFixture* fx,
     g_assert_cmpstr(debug_output.c_str(), ==, "\"a string\"");
 }
 
-static void
-gjstest_test_func_util_misc_strv_concat_null(void)
-{
-    char **ret;
-
-    ret = gjs_g_strv_concat(NULL, 0);
+static void gjstest_test_func_util_misc_strv_concat_null() {
+    char** ret = gjs_g_strv_concat(nullptr, 0);
     g_assert_nonnull(ret);
     g_assert_null(ret[0]);
 
     g_strfreev(ret);
 }
 
-static void
-gjstest_test_func_util_misc_strv_concat_pointers(void)
-{
-    char  *strv0[2] = {(char*)"foo", NULL};
-    char  *strv1[1] = {NULL};
-    char **strv2    = NULL;
-    char  *strv3[2] = {(char*)"bar", NULL};
-    char **stuff[4];
-    char **ret;
+static void gjstest_test_func_util_misc_strv_concat_pointers() {
+    const char* strv0[2] = {"foo", nullptr};
+    const char* strv1[1] = {nullptr};
+    const char** strv2 = nullptr;
+    const char* strv3[2] = {"bar", nullptr};
+    const char** stuff[4];
 
     stuff[0] = strv0;
     stuff[1] = strv1;
     stuff[2] = strv2;
     stuff[3] = strv3;
 
-    ret = gjs_g_strv_concat(stuff, 4);
+    AutoStrv ret = gjs_g_strv_concat(stuff, 4);
     g_assert_nonnull(ret);
-    g_assert_cmpstr(ret[0], ==, strv0[0]);  /* same string */
+    g_assert_cmpstr(ret[0], ==, strv0[0]);  // same string
     g_assert_true(ret[0] != strv0[0]);      // different pointer
     g_assert_cmpstr(ret[1], ==, strv3[0]);
     g_assert_true(ret[1] != strv3[0]);
     g_assert_null(ret[2]);
-
-    g_strfreev(ret);
 }
 
-static void
-gjstest_test_profiler_start_stop(void)
-{
-    AutoUnref<GjsContext> context{GJS_CONTEXT(
+static void gjstest_test_profiler_start_stop() {
+    AutoUnref<GjsContext> gjs_context{GJS_CONTEXT(
         g_object_new(GJS_TYPE_CONTEXT, "profiler-enabled", TRUE, nullptr))};
-    GjsProfiler *profiler = gjs_context_get_profiler(context);
+    GjsProfiler* profiler = gjs_context_get_profiler(gjs_context);
 
     gjs_profiler_set_filename(profiler, "dont-conflict-with-other-test.syscap");
     gjs_profiler_start(profiler);
 
+    static const char testjs[] = "[1,5,7,1,2,3,67,8].sort()";
     for (size_t ix = 0; ix < 100; ix++) {
         AutoError error;
         int estatus;
-
-#define TESTJS "[1,5,7,1,2,3,67,8].sort()"
-
-        if (!gjs_context_eval(context, TESTJS, -1, "<input>", &estatus, &error))
+        if (!gjs_context_eval(gjs_context, testjs, -1, "<input>", &estatus,
+                              &error))
             g_printerr("ERROR: %s", error->message);
-
-#undef TESTJS
     }
 
     gjs_profiler_stop(profiler);
@@ -1082,6 +1064,8 @@ static void gjstest_test_args_set_get_unset() {
 
     GType random_gtype = get_random_number<GType>();
     gjs_arg_set<Gjs::Tag::GType>(&arg, random_gtype);
+    // Don't replace gsize and gulong with size_t and unsigned long, since
+    // GLib may define them differently on some platforms.
     if constexpr (std::is_same_v<GType, gsize>)
         assert_equal(static_cast<GType>(arg.v_size), random_gtype);
     else if constexpr (std::is_same_v<GType, gulong>)
@@ -1132,17 +1116,18 @@ static void gjstest_test_args_rounded_values() {
 }
 
 static void gjstest_test_func_gjs_context_argv_array() {
-    AutoUnref<GjsContext> gjs{gjs_context_new()};
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     AutoError error;
     int status;
 
     const char* argv[1] = {"test"};
-    bool ok = gjs_context_define_string_array(gjs, "ARGV", 1, argv, &error);
+    bool ok =
+        gjs_context_define_string_array(gjs_context, "ARGV", 1, argv, &error);
 
     g_assert_no_error(error);
     g_assert_true(ok);
 
-    ok = gjs_context_eval(gjs, R"js(
+    ok = gjs_context_eval(gjs_context, R"js(
         imports.system.exit(ARGV[0] === "test" ? 0 : 1)
     )js",
                           -1, "<main>", &status, &error);
@@ -1153,7 +1138,7 @@ static void gjstest_test_func_gjs_context_argv_array() {
 }
 
 static void gjstest_test_func_gjs_context_eval_module_source_map() {
-    AutoUnref<GjsContext> gjs = gjs_context_new();
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     uint8_t exit_status;
     AutoError error;
     const char* pattern =
@@ -1161,7 +1146,7 @@ static void gjstest_test_func_gjs_context_eval_module_source_map() {
         "numberWork.ts:3:13*";
 
     // separate source map
-    bool ok = gjs_context_register_module(gjs,
+    bool ok = gjs_context_register_module(gjs_context,
                                           "resource:///org/gnome/gjs/mock/test/"
                                           "source-maps/separate/numberWork.js",
                                           "resource:///org/gnome/gjs/mock/test/"
@@ -1170,7 +1155,7 @@ static void gjstest_test_func_gjs_context_eval_module_source_map() {
     g_assert_true(ok);
 
     g_test_expect_message("Gjs", G_LOG_LEVEL_CRITICAL, pattern);
-    ok = gjs_context_eval_module(gjs,
+    ok = gjs_context_eval_module(gjs_context,
                                  "resource:///org/gnome/gjs/mock/test/"
                                  "source-maps/separate/numberWork.js",
                                  &exit_status, &error);
@@ -1182,7 +1167,7 @@ static void gjstest_test_func_gjs_context_eval_module_source_map() {
 
     // inlined source maps
     error = nullptr;
-    ok = gjs_context_register_module(gjs,
+    ok = gjs_context_register_module(gjs_context,
                                      "resource:///org/gnome/gjs/mock/test/"
                                      "source-maps/inlined/numberWork.js",
                                      "resource:///org/gnome/gjs/mock/test/"
@@ -1190,7 +1175,7 @@ static void gjstest_test_func_gjs_context_eval_module_source_map() {
                                      &error);
     g_assert_true(ok);
     g_test_expect_message("Gjs", G_LOG_LEVEL_CRITICAL, pattern);
-    ok = gjs_context_eval_module(gjs,
+    ok = gjs_context_eval_module(gjs_context,
                                  "resource:///org/gnome/gjs/mock/test/"
                                  "source-maps/inlined/numberWork.js",
                                  &exit_status, &error);
@@ -1202,7 +1187,7 @@ static void gjstest_test_func_gjs_context_eval_module_source_map() {
 }
 
 static void gjstest_test_func_gjs_context_eval_file_source_map() {
-    AutoUnref<GjsContext> gjs = gjs_context_new();
+    AutoUnref<GjsContext> gjs_context{gjs_context_new()};
     int exit_status;
     AutoError error;
     const char* pattern = "*noModule.js:2:9 -> noModule.ts:6:11*";
@@ -1213,8 +1198,8 @@ static void gjstest_test_func_gjs_context_eval_file_source_map() {
 
     // separate source map
     g_test_expect_message("Gjs", G_LOG_LEVEL_CRITICAL, pattern);
-    bool ok =
-        gjs_context_eval_file(gjs, separate_test_file, &exit_status, &error);
+    bool ok = gjs_context_eval_file(gjs_context, separate_test_file,
+                                    &exit_status, &error);
 
     g_assert_false(ok);
     g_assert_error(error, GJS_ERROR, GJS_ERROR_FAILED);
@@ -1224,7 +1209,8 @@ static void gjstest_test_func_gjs_context_eval_file_source_map() {
     // inlined source map
     error = nullptr;
     g_test_expect_message("Gjs", G_LOG_LEVEL_CRITICAL, pattern);
-    ok = gjs_context_eval_file(gjs, inlined_test_file, &exit_status, &error);
+    ok = gjs_context_eval_file(gjs_context, inlined_test_file, &exit_status,
+                               &error);
     g_assert_false(ok);
     g_assert_error(error, GJS_ERROR, GJS_ERROR_FAILED);
     g_assert_cmpuint(exit_status, ==, 1);
@@ -1233,13 +1219,10 @@ static void gjstest_test_func_gjs_context_eval_file_source_map() {
 }  // namespace Test
 }  // namespace Gjs
 
-int
-main(int    argc,
-     char **argv)
-{
+int main(int argc, char** argv) {
     using namespace Gjs::Test;  // NOLINT(build/namespaces)
 
-    /* Avoid interference in the tests from stray environment variable */
+    // Avoid interference in the tests from stray environment variable
     g_unsetenv("GJS_ENABLE_PROFILER");
     g_unsetenv("GJS_TRACE_FD");
 
@@ -1262,8 +1245,10 @@ main(int    argc,
 
     g_message("Using C++ random seed %u\n", cpp_random_seed);
 
-    g_test_add_func("/gjs/context/construct/destroy", gjstest_test_func_gjs_context_construct_destroy);
-    g_test_add_func("/gjs/context/construct/eval", gjstest_test_func_gjs_context_construct_eval);
+    g_test_add_func("/gjs/context/construct/destroy",
+                    gjstest_test_func_gjs_context_construct_destroy);
+    g_test_add_func("/gjs/context/construct/eval",
+                    gjstest_test_func_gjs_context_construct_eval);
     g_test_add_func("/gjs/context/argv",
                     gjstest_test_func_gjs_context_argv_array);
     g_test_add_func("/gjs/context/eval/dynamic-import",
@@ -1301,10 +1286,12 @@ main(int    argc,
                     gjstest_test_func_gjs_context_register_module_non_existent);
     g_test_add_func("/gjs/context/eval-module/unregistered",
                     gjstest_test_func_gjs_context_eval_module_unregistered);
-    g_test_add_func("/gjs/gobject/js_defined_type", gjstest_test_func_gjs_gobject_js_defined_type);
+    g_test_add_func("/gjs/gobject/js_defined_type",
+                    gjstest_test_func_gjs_gobject_js_defined_type);
     g_test_add_func("/gjs/gobject/without_introspection",
                     gjstest_test_func_gjs_gobject_without_introspection);
-    g_test_add_func("/gjs/profiler/start_stop", gjstest_test_profiler_start_stop);
+    g_test_add_func("/gjs/profiler/start_stop",
+                    gjstest_test_profiler_start_stop);
     g_test_add_func("/util/misc/strv/concat/null",
                     gjstest_test_func_util_misc_strv_concat_null);
     g_test_add_func("/util/misc/strv/concat/pointers",
@@ -1320,16 +1307,20 @@ main(int    argc,
     g_test_add_func(
         "/gjs/context/eval-module-file/exit-code-omitted-no-warning",
         gjstest_test_func_gjs_context_eval_module_file_exit_code_omitted_no_warning);
-    g_test_add_func("/gjs/context/eval-file/exit-code-omitted-no-throw",
-                    gjstest_test_func_gjs_context_eval_file_exit_code_omitted_no_throw);
-    g_test_add_func("/gjs/context/eval-file/exit-code-omitted-throw",
-                    gjstest_test_func_gjs_context_eval_file_exit_code_omitted_throw);
+    g_test_add_func(
+        "/gjs/context/eval-file/exit-code-omitted-no-throw",
+        gjstest_test_func_gjs_context_eval_file_exit_code_omitted_no_throw);
+    g_test_add_func(
+        "/gjs/context/eval-file/exit-code-omitted-throw",
+        gjstest_test_func_gjs_context_eval_file_exit_code_omitted_throw);
     g_test_add_func("/gjs/context/eval/exit-code-omitted-throw",
                     gjstest_test_func_gjs_context_eval_exit_code_omitted_throw);
-    g_test_add_func("/gjs/context/eval/exit-code-omitted-no-throw",
-                    gjstest_test_func_gjs_context_eval_exit_code_omitted_no_throw);
-    g_test_add_func("/gjs/context/eval-module/exit-code-omitted-throw",
-                    gjstest_test_func_gjs_context_eval_module_exit_code_omitted_throw);
+    g_test_add_func(
+        "/gjs/context/eval/exit-code-omitted-no-throw",
+        gjstest_test_func_gjs_context_eval_exit_code_omitted_no_throw);
+    g_test_add_func(
+        "/gjs/context/eval-module/exit-code-omitted-throw",
+        gjstest_test_func_gjs_context_eval_module_exit_code_omitted_throw);
     g_test_add_func(
         "/gjs/context/eval-module/exit-code-omitted-no-throw",
         gjstest_test_func_gjs_context_eval_module_exit_code_omitted_no_throw);
@@ -1345,9 +1336,9 @@ main(int    argc,
     g_test_add_func("/gjs/context/eval-file/source-map",
                     gjstest_test_func_gjs_context_eval_file_source_map);
 
-#define ADD_JSAPI_UTIL_TEST(path, func)                            \
-    g_test_add("/gjs/jsapi/util/" path, GjsUnitTestFixture, NULL,  \
-               gjs_unit_test_fixture_setup, func,                  \
+#define ADD_JSAPI_UTIL_TEST(path, func)                              \
+    g_test_add("/gjs/jsapi/util/" path, GjsUnitTestFixture, nullptr, \
+               gjs_unit_test_fixture_setup, func,                    \
                gjs_unit_test_fixture_teardown)
 
     ADD_JSAPI_UTIL_TEST("error/throw",
@@ -1381,7 +1372,7 @@ main(int    argc,
 
 #undef ADD_JSAPI_UTIL_TEST
 
-    gjs_test_add_tests_for_coverage ();
+    gjs_test_add_tests_for_coverage();
 
     g_test_run();
 
