@@ -2,27 +2,34 @@
 // SPDX-License-Identifier: MIT OR LGPL-2.0-or-later
 // SPDX-FileCopyrightText: 2008 litl, LLC
 
-#ifndef UTIL_MISC_H_
-#define UTIL_MISC_H_
+#pragma once
 
 #include <config.h>
 
 #include <errno.h>
+#include <stdint.h>
 #include <stdio.h>  // for FILE, stdout
 #include <string.h>  // for memcpy
 
+#include <charconv>
+#include <string>
+
+#include <mozilla/Result.h>
+#include <mozilla/ResultVariant.h>  // IWYU pragma: keep
+
 #ifdef G_DISABLE_ASSERT
 #    define GJS_USED_ASSERT [[maybe_unused]]
 #else
 #    define GJS_USED_ASSERT
 #endif
 
-bool    gjs_environment_variable_is_set   (const char *env_variable_name);
+bool gjs_environment_variable_is_set(const char* env_variable_name);
 
-char** gjs_g_strv_concat(char*** strv_array, int len);
+char** gjs_g_strv_concat(const char** strv_array[], int len);
 
-/*
+/**
  * LogFile:
+ *
  * RAII class encapsulating access to a FILE* pointer that must be closed,
  * unless it is an already-open fallback file such as stdout or stderr.
  */
@@ -58,4 +65,21 @@ class LogFile {
     const char* errmsg() { return m_errmsg; }
 };
 
-#endif  // UTIL_MISC_H_
+namespace Gjs {
+
+class StatmParseError {
+    std::string m_message;
+
+ public:
+    // NOLINTNEXTLINE(runtime/explicit) - explicit ctor won't work with Err()
+    StatmParseError(const char* message) : m_message(message) {}
+    StatmParseError(const char* message, std::from_chars_result result);
+
+    explicit operator std::string() const { return m_message; }
+};
+
+using StatmParseResult = mozilla::Result<uint64_t, StatmParseError>;
+
+StatmParseResult parse_statm_file_rss(const char* file_contents);
+
+}  // namespace Gjs
